@@ -1,8 +1,8 @@
 # --
 # Kernel/Config/Defaults.pm - Default Config file for OTRS kernel
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Defaults.pm,v 1.251 2006/12/07 15:43:23 mh Exp $
+# $Id: Defaults.pm,v 1.272 2007/07/26 14:15:30 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -23,7 +23,7 @@ package Kernel::Config::Defaults;
 use strict;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.251 $';
+$VERSION = '$Revision: 1.272 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub LoadDefaults {
@@ -107,9 +107,18 @@ sub LoadDefaults {
 #    $ENV{ORACLE_HOME} = '/opt/ora9/product/9.2';
 #    $ENV{ORACLE_HOME} = '/oracle/Ora92';
 #    $ENV{NLS_DATE_FORMAT} = 'YYYY-MM-DD HH24:MI:SS';
+#    $ENV{NLS_LANG} = "german_germany.utf8";
 #    $ENV{NLS_LANG} = "german_germany.we8iso8859p15";
 #    $ENV{NLS_LANG} = "american_america.we8iso8859p1";
 
+    # If you want to use an init sql after connect, use this hier.
+    # (e. g. can be used for mysql encoding between client and server)
+#    $Self->{'Database::Connect'} = 'SET NAMES utf8';
+
+    # If you want to use the sql slow log feature, enable this here.
+    # (To log every sql query which takes longer the 8 sec.)
+#    $Self->{'Database::SlowLog'} = 0;
+
     # --------------------------------------------------- #
     # default values                                      #
     # (default values for GUIs)                           #
@@ -129,33 +138,35 @@ sub LoadDefaults {
     # (short name = long name and file)
     $Self->{DefaultUsedLanguages} = {
 #            bb => 'Bavarian',
-            en => 'English',
+            ar_SA => 'Arabic (Saudi Arabia)',
+            bg => 'Bulgarian (&#x0411;&#x044a;&#x043b;&#x0433;&#x0430;&#x0440;&#x0441;&#x043a;&#x0438;)',
+            cz => 'Czech (&#x010c;esky)',
+            da => 'Dansk',
             de => 'Deutsch',
-            nl => 'Nederlands',
-            fa => 'Persian',
-            fr => 'Fran&ccedil;ais',
-            bg => 'Bulgarian',
-            fi => 'Suomi',
-            el => 'Greek',
+            en => 'English',
+            el => 'Greek (&#x0395;&#x03bb;&#x03bb;&#x03b7;&#x03bd;&#x03b9;&#x03ba;&#x03ac;)',
             es => 'Espa&ntilde;ol',
+            fa => 'Persian (&#x0641;&#x0627;&#x0631;&#x0633;&#x0649;)',
+            fr => 'Fran&ccedil;ais',
+            fi => 'Suomi',
+            hu => 'Magyar',
+            it => 'Italiano',
+            nl => 'Nederlands',
+            nb_NO => 'Norsk bokm&aring;l',
             pt_BR => 'Portugu&ecirc;s Brasileiro',
             pt => 'Portugu&ecirc;s',
-            it => 'Italiano',
-            sk_SK => 'Slovak',
-            ru => 'Russian',
-            cz => 'Czech',
             pl => 'Polski',
-            nb_NO => 'Norsk bokm&aring;l',
+            ru => 'Russian (&#x0420;&#x0443;&#x0441;&#x0441;&#x043a;&#x0438;&#x0439;)',
+            sk_SK => 'Slovak (Sloven&#x010d;ina)',
             sv => 'Svenska',
-            hu => 'Hungarian',
-            zh_CN => 'Simplified Chinese',
-#            th => 'Thai',
-            da => 'Dansk',
-#            ro => 'Romanian',
+            zh_CN => 'Chinese (Sim.) (&#x7b80;&#x4f53;&#x4e2d;&#x6587;)',
+#            th => 'Thai (&#x0e44;&#x0e17;&#x0e22;)',
+#            ro => 'Rom&acirc;n&auml;',
 #            hr => 'Croatian',
-#            sl => 'Slovenian',
-#            tr => 'tr',
-#            jp => 'jp',
+#            sl => 'Slovenian (Sloven&#x0161;&#x010d;ina)',
+#            tr => 'T&uuml;rk&ccedil;e',
+#            uk => 'Ukrainian (&#x0423;&#x043a;&#x0440;&#x0430;&#x0457;&#x043d;&#x0441;&#x044c;&#x043a;&#x0430;)',
+#            jp => 'Japanese (&#x65e5;&#x672c;&#x8a9e;)',
     };
     # default theme
     # (the default html theme) [default: Standard]
@@ -175,7 +186,7 @@ sub LoadDefaults {
     # DefaultViewNewLine
     # (insert new line in text messages after max x chars and
     # the next word)
-    $Self->{DefaultViewNewLine} = 85;
+    $Self->{DefaultViewNewLine} = 90;
 
     # DefaultPreViewLines
     # (Max viewable lines in pre view text messages (like ticket
@@ -283,7 +294,7 @@ sub LoadDefaults {
     # This is the auth. module againt the otrs db
     $Self->{'AuthModule'} = 'Kernel::System::Auth::DB';
 
-    # password crypt type (crypt|md5)
+    # password crypt type (crypt|md5|plain)
 #    $Self->{'AuthModule::DB::CryptType'} = 'crypt';
 
     # This is an example configuration for an LDAP auth. backend.
@@ -331,34 +342,40 @@ sub LoadDefaults {
 #        version => 3,
 #    };
 
+    # Die if backend can't work, e. g. can't connect to server.
+#    $Self->{'AuthModule::LDAP::Die'} = 1;
+
     # This is an example configuration for an apache ($ENV{REMOTE_USER})
     # auth. backend. Use it if you want to have a singe login through
-    # apache http-basic-auth
+    # apache http-basic-auth.
 #   $Self->{'AuthModule'} = 'Kernel::System::Auth::HTTPBasicAuth';
     # In case there is a leading domain in the REMOTE_USER, you can
     # replace it by the next config option.
 #   $Self->{'AuthModule::HTTPBasicAuth::Replace'} = 'example_domain\\';
     # Note:
     # If you use this module, you should use as fallback the following
-    # config settings if user isn't login through apache ($ENV{REMOTE_USER})
+    # config settings if user isn't login through apache ($ENV{REMOTE_USER}).
 #   $Self->{LoginURL} = 'http://host.example.com/not-authorised-for-otrs.html';
 #   $Self->{LogoutURL} = 'http://host.example.com/thanks-for-using-otrs.html';
 
-    # This is example configuration to auth. agents against a radius server
+    # This is example configuration to auth. agents against a radius server.
 #    $Self->{'AuthModule'} = 'Kernel::System::Auth::Radius';
 #    $Self->{'AuthModule::Radius::Host'} = 'radiushost';
 #    $Self->{'AuthModule::Radius::Password'} = 'radiussecret';
 
+    # Die if backend can't work, e. g. can't connect to server.
+#    $Self->{'AuthModule::Radius::Die'} = 1;
+
     # UserSyncLDAPMap
     # (map if agent should create/synced from LDAP to DB after login)
 #    $Self->{UserSyncLDAPMap} = {
 #        # DB -> LDAP
-#        Firstname => 'givenName',
-#        Lastname => 'sn',
-#        Email => 'mail',
+#        UserFirstname => 'givenName',
+#        UserLastname => 'sn',
+#        UserEmail => 'mail',
 #    };
     # UserSyncLDAPGroups
-    # (If "LDAP" was selected for AuthModule, you can specify inital
+    # (If "LDAP" was selected for AuthModule, you can specify initial
     # user groups for first login.)
 #    $Self->{UserSyncLDAPGroups} = [
 #        'users',
@@ -501,19 +518,21 @@ sub LoadDefaults {
     # show online agents
 #    $Self->{'Frontend::NotifyModule'}->{'3-ShowAgentOnline'} = {
 #        Module => 'Kernel::Output::HTML::NotificationAgentOnline',
+#        ShowEmail => 1,
 #    };
     # show online customers
 #    $Self->{'Frontend::NotifyModule'}->{'4-ShowCustomerOnline'} = {
 #        Module => 'Kernel::Output::HTML::NotificationCustomerOnline',
+#        ShowEmail => 1,
 #    };
 
     # --------------------------------------------------- #
-    # Frontend::Output::PostFilter
+    # Frontend::Output::FilterElementPost
     # --------------------------------------------------- #
-    # Frontend::Output::PostFilter
+    # Frontend::Output::FilterElementPost
     # (a output filter for application html output, e. g. to filter
     # java script, java applets, ...)
-#    $Self->{'Frontend::Output::PostFilter'}->{'ActiveElementFilter'} = {
+#    $Self->{'Frontend::Output::FilterElementPost'}->{'ActiveElementFilter'} = {
 #        Module => 'Kernel::Output::HTML::OutputFilterActiveElement',
 #        Debug => 0,
 #    };
@@ -552,7 +571,7 @@ sub LoadDefaults {
 
     # SessionMaxTime
     # (Max valid time of one session id in second (8h = 28800).)
-    $Self->{SessionMaxTime} = 10*60*60;
+    $Self->{SessionMaxTime} = 14*60*60;
 
     # SessionMaxIdleTime
     # (After this time (in seconds) without new http request, then
@@ -655,8 +674,8 @@ sub LoadDefaults {
     # Web Settings
     # --------------------------------------------------- #
     # WebMaxFileUpload
-    # (Max size for browser file uploads - default 5 MB)
-    $Self->{WebMaxFileUpload} = 1024 * 1024 * 5;
+    # (Max size for browser file uploads - default 10 MB)
+    $Self->{WebMaxFileUpload} = 1024 * 1024 * 10;
 
     # WebUploadCacheModule
     # (select you WebUploadCacheModule module, default DB [DB|FS])
@@ -739,9 +758,9 @@ sub LoadDefaults {
 
     # Package::RepositoryList
     # (repository list)
-    $Self->{'Package::RepositoryList'} = {
+#    $Self->{'Package::RepositoryList'} = {
 #        'ftp://ftp.example.com/pub/otrs/misc/packages/' => '[Example] ftp://ftp.example.com/',
-    };
+#    };
 
     # Package::Timeout
     # (http/ftp timeout to get packages)
@@ -927,6 +946,7 @@ Your OTRS Notification Master
     # show online agents
 #    $Self->{'CustomerFrontend::NotifyModule'}->{'1-ShowAgentOnline'} = {
 #        Module => 'Kernel::Output::HTML::NotificationAgentOnline',
+#        ShowEmail => 1,
 #    };
 
     # --------------------------------------------------- #
@@ -1014,6 +1034,10 @@ Your OTRS Notification Master
 #    $Self->{'Customer::AuthModule::DB::DSN'} = "DBI:mysql:database=customerdb;host=customerdbhost";
 #    $Self->{'Customer::AuthModule::DB::User'} = "some_user";
 #    $Self->{'Customer::AuthModule::DB::Password'} = "some_password";
+    # if you use odbc or you want to define a database type (without autodetection)
+#    $Self->{'Customer::AuthModule::DB::Type'} = 'mysql';
+    # password crypt type (crypt|md5|plain)
+#    $Self->{'Customer::AuthModule::DB::CryptType'} = 'crypt';
 
     # This is an example configuration for an LDAP auth. backend.
     # (take care that Net::LDAP is installed!)
@@ -1053,6 +1077,9 @@ Your OTRS Notification Master
 #        version => 3,
 #    };
 
+    # Die if backend can't work, e. g. can't connect to server.
+#    $Self->{'Customer::AuthModule::LDAP::Die'} = 1;
+
     # This is an example configuration for an apache ($ENV{REMOTE_USER})
     # auth. backend. Use it if you want to have a singe login through
     # apache http-basic-auth
@@ -1114,6 +1141,10 @@ Your OTRS Notification Master
 #        AutoLoginCreationPrefix => 'auto',
 #        # admin can change customer preferences
 #        AdminSetPreferences => 1,
+#        # use customer company support (reference to company, See CustomerCompany settings)
+#        CustomerCompanySupport => 1,
+#        # cache time to life in sec. - cache any database queris
+#        CacheTTL => 0,
 #        # just a read only source
 #        ReadOnly => 1,
         Map => [
@@ -1163,6 +1194,8 @@ Your OTRS Notification Master
 #            # ldap server is utf-8, use this options (if not, ignore it)
 #            SourceCharset => 'utf-8',
 #            DestCharset => 'iso-8859-1',
+#            # die if backend can't work, e. g. can't connect to server
+#            Die => 1,
 #            # Net::LDAP new params (if needed - for more info see perldoc Net::LDAP)
 #            Params => {
 #                port => 389,
@@ -1188,6 +1221,8 @@ Your OTRS Notification Master
 #        # CustomerUserValidFilter => '(!(description=gesperrt))',
 #        # admin can't change customer preferences
 #        AdminSetPreferences => 0,
+#        # cache time to life in sec. - cache any ldap queris
+#        CacheTTL => 0,
 #        Map => [
 #            # note: Login, Email and CustomerID needed!
 #            # var, frontend, storage, shown (1=always,2=lite), required, storage-type, http-link, readonly
@@ -1204,6 +1239,279 @@ Your OTRS Notification Master
 #        ],
 #    };
 
+    $Self->{CustomerCompany} = {
+        Params => {
+            # if you want to use an external database, add the
+            # required settings
+#            DSN => 'DBI:odbc:yourdsn',
+#            DSN => 'DBI:mysql:database=customerdb;host=customerdbhost',
+#            User => '',
+#            Password => '',
+            Table => 'customer_company',
+        },
+        # customer uniq id
+        CustomerCompanyKey => 'customer_id',
+        CustomerCompanyValid => 'valid_id',
+        CustomerCompanyListFields => ['customer_id', 'name'],
+        Map => [
+            # var, frontend, storage, shown (1=always,2=lite), required, storage-type, http-link, readonly
+            [ 'CustomerID',              'CustomerID',  'customer_id',  0, 1, 'var', '', 0 ],
+            [ 'CustomerCompanyName',     'Name',        'name',         1, 1, 'var', '', 0 ],
+            [ 'CustomerCompanyStreet',   'Street',      'street',       1, 0, 'var', '', 0 ],
+            [ 'CustomerCompanyZIP',      'Zip',         'zip',          1, 0, 'var', '', 0 ],
+            [ 'CustomerCompanyCity',     'City',        'city',     1, 0, 'var', '', 0 ],
+            [ 'CustomerCompanyCountry',  'Country',     'country',      1, 0, 'var', '', 0 ],
+            [ 'CustomerCompanyURL',      'URL',         'url',          1, 0, 'var', '$Data{"CustomerCompanyURL"}', 0 ],
+            [ 'CustomerCompanyComment',  'Comment',     'comments',     1, 0, 'var', '', 0 ],
+            [ 'ValidID',                 'Valid',       'valid_id',     0, 1, 'int', '', 0 ],
+        ],
+        # default selections
+        Selections => {
+            CustomerCompanyCountry => {
+                '-' => '-',
+                'Afghanistan'  =>  'Afghanistan',
+                'Albania'  =>  'Albania',
+                'Algeria'  =>  'Algeria',
+                'American Samoa'  =>  'American Samoa',
+                'Andorra'  =>  'Andorra',
+                'Angola'  =>  'Angola',
+                'Anguilla'  =>  'Anguilla',
+                'Antarctica'  =>  'Antarctica',
+                'Antigua and Barbuda'  =>  'Antigua and Barbuda',
+                'Argentina'  =>  'Argentina',
+                'Armenia'  =>  'Armenia',
+                'Aruba'  =>  'Aruba',
+                'Australia'  =>  'Australia',
+                'Austria'  =>  'Austria',
+                'Azerbaijan'  =>  'Azerbaijan',
+                'Bahamas'  =>  'Bahamas',
+                'Bahrain'  =>  'Bahrain',
+                'Bangladesh'  =>  'Bangladesh',
+                'Barbados'  =>  'Barbados',
+                'Belarus'  =>  'Belarus',
+                'Belgium'  =>  'Belgium',
+                'Belize'  =>  'Belize',
+                'Benin'  =>  'Benin',
+                'Bermuda'  =>  'Bermuda',
+                'Bhutan'  =>  'Bhutan',
+                'Bolivia'  =>  'Bolivia',
+                'Bosnia and Herzegowina'  =>  'Bosnia and Herzegowina',
+                'Botswana'  =>  'Botswana',
+                'Bouvet Island'  =>  'Bouvet Island',
+                'Brazil'  =>  'Brazil',
+                'British Indian Ocean Territory'  =>  'British Indian Ocean Territory',
+                'Brunei Darussalam'  =>  'Brunei Darussalam',
+                'Bulgaria'  =>  'Bulgaria',
+                'Burkina Faso'  =>  'Burkina Faso',
+                'Burundi'  =>  'Burundi',
+                'Cambodia'  =>  'Cambodia',
+                'Cameroon'  =>  'Cameroon',
+                'Canada'  =>  'Canada',
+                'Cape Verde'  =>  'Cape Verde',
+                'Cayman Islands'  =>  'Cayman Islands',
+                'Central African Republic'  =>  'Central African Republic',
+                'Chad'  =>  'Chad',
+                'Chile'  =>  'Chile',
+                'China'  =>  'China',
+                'Christmas Island'  =>  'Christmas Island',
+                'Cocos (Keeling) Islands'  =>  'Cocos (Keeling) Islands',
+                'Colombia'  =>  'Colombia',
+                'Comoros'  =>  'Comoros',
+                'Congo, Democratic Republic of'  =>  'Congo, Democratic Republic of',
+                'Congo, Republic of'  =>  'Congo, Republic of',
+                'Cook Islands'  =>  'Cook Islands',
+                'Costa Rica'  =>  'Costa Rica',
+                'Cote d\'Ivoire'  =>  'Cote d\'Ivoire',
+                'Croatia'  =>  'Croatia',
+                'Cuba'  =>  'Cuba',
+                'Cyprus'  =>  'Cyprus',
+                'Czech Republic'  =>  'Czech Republic',
+                'Denmark'  =>  'Denmark',
+                'Djibouti'  =>  'Djibouti',
+                'Dominica'  =>  'Dominica',
+                'Dominican Republic'  =>  'Dominican Republic',
+                'Ecuador'  =>  'Ecuador',
+                'Egypt'  =>  'Egypt',
+                'El Salvador'  =>  'El Salvador',
+                'Equatorial Guinea'  =>  'Equatorial Guinea',
+                'Eritrea'  =>  'Eritrea',
+                'Estonia'  =>  'Estonia',
+                'Ethiopia'  =>  'Ethiopia',
+                'Falkland Islands (Malvinas)'  =>  'Falkland Islands (Malvinas)',
+                'Faroe Islands'  =>  'Faroe Islands',
+                'Fiji'  =>  'Fiji',
+                'Finland'  =>  'Finland',
+                'France'  =>  'France',
+                'French Guiana'  =>  'French Guiana',
+                'French Polynesia'  =>  'French Polynesia',
+                'French Southern Territories'  =>  'French Southern Territories',
+                'Gabon'  =>  'Gabon',
+                'Gambia'  =>  'Gambia',
+                'Georgia'  =>  'Georgia',
+                'Germany'  =>  'Germany',
+                'Ghana'  =>  'Ghana',
+                'Gibraltar'  =>  'Gibraltar',
+                'Greece'  =>  'Greece',
+                'Greenland'  =>  'Greenland',
+                'Grenada'  =>  'Grenada',
+                'Guadeloupe'  =>  'Guadeloupe',
+                'Guam'  =>  'Guam',
+                'Guatemala'  =>  'Guatemala',
+                'Guinea'  =>  'Guinea',
+                'Guinea-bissau'  =>  'Guinea-bissau',
+                'Guyana'  =>  'Guyana',
+                'Haiti'  =>  'Haiti',
+                'Heard and Mc Donald Islands'  =>  'Heard and Mc Donald Islands',
+                'Honduras'  =>  'Honduras',
+                'Hong Kong'  =>  'Hong Kong',
+                'Hungary'  =>  'Hungary',
+                'Iceland'  =>  'Iceland',
+                'India'  =>  'India',
+                'Indonesia'  =>  'Indonesia',
+                'Iran (Islamic Republic of)'  =>  'Iran (Islamic Republic of)',
+                'Iraq'  =>  'Iraq',
+                'Ireland'  =>  'Ireland',
+                'Israel'  =>  'Israel',
+                'Italy'  =>  'Italy',
+                'Jamaica'  =>  'Jamaica',
+                'Japan'  =>  'Japan',
+                'Jordan'  =>  'Jordan',
+                'Kazakhstan'  =>  'Kazakhstan',
+                'Kenya'  =>  'Kenya',
+                'Kiribati'  =>  'Kiribati',
+                'Korea, Democratic People\'s Republic of'  =>  'Korea, Democratic People\'s Republic of',
+                'Korea, Republic of'  =>  'Korea, Republic of',
+                'Kuwait'  =>  'Kuwait',
+                'Kyrgyzstan'  =>  'Kyrgyzstan',
+                'Lao People\'s Democratic Republic'  =>  'Lao People\'s Democratic Republic',
+                'Latvia'  =>  'Latvia',
+                'Lebanon'  =>  'Lebanon',
+                'Lesotho'  =>  'Lesotho',
+                'Liberia'  =>  'Liberia',
+                'Libyan Arab Jamahiriya'  =>  'Libyan Arab Jamahiriya',
+                'Liechtenstein'  =>  'Liechtenstein',
+                'Lithuania'  =>  'Lithuania',
+                'Luxembourg'  =>  'Luxembourg',
+                'Macau'  =>  'Macau',
+                'Macedonia, the Former Yugoslav Republic of'  =>  'Macedonia, the Former Yugoslav Republic of',
+                'Madagascar'  =>  'Madagascar',
+                'Malawi'  =>  'Malawi',
+                'Malaysia'  =>  'Malaysia',
+                'Maldives'  =>  'Maldives',
+                'Mali'  =>  'Mali',
+                'Malta'  =>  'Malta',
+                'Marshall Islands'  =>  'Marshall Islands',
+                'Martinique'  =>  'Martinique',
+                'Mauritania'  =>  'Mauritania',
+                'Mauritius'  =>  'Mauritius',
+                'Mayotte'  =>  'Mayotte',
+                'Mexico'  =>  'Mexico',
+                'Micronesia, Federated States of'  =>  'Micronesia, Federated States of',
+                'Moldova, Republic of'  =>  'Moldova, Republic of',
+                'Monaco'  =>  'Monaco',
+                'Mongolia'  =>  'Mongolia',
+                'Montserrat'  =>  'Montserrat',
+                'Morocco'  =>  'Morocco',
+                'Mozambique'  =>  'Mozambique',
+                'Myanmar'  =>  'Myanmar',
+                'Namibia'  =>  'Namibia',
+                'Nauru'  =>  'Nauru',
+                'Nepal'  =>  'Nepal',
+                'Netherlands'  =>  'Netherlands',
+                'Netherlands Antilles'  =>  'Netherlands Antilles',
+                'New Caledonia'  =>  'New Caledonia',
+                'New Zealand'  =>  'New Zealand',
+                'Nicaragua'  =>  'Nicaragua',
+                'Niger'  =>  'Niger',
+                'Nigeria'  =>  'Nigeria',
+                'Niue'  =>  'Niue',
+                'Norfolk Island'  =>  'Norfolk Island',
+                'Northern Mariana Islands'  =>  'Northern Mariana Islands',
+                'Norway'  =>  'Norway',
+                'Oman'  =>  'Oman',
+                'Pakistan'  =>  'Pakistan',
+                'Palau'  =>  'Palau',
+                'Palestinian Territory, oCCUPIED'  =>  'Palestinian Territory, oCCUPIED',
+                'Panama'  =>  'Panama',
+                'Papua New Guinea'  =>  'Papua New Guinea',
+                'Paraguay'  =>  'Paraguay',
+                'Peru'  =>  'Peru',
+                'Philippines'  =>  'Philippines',
+                'Pitcairn'  =>  'Pitcairn',
+                'Poland'  =>  'Poland',
+                'Portugal'  =>  'Portugal',
+                'Puerto Rico'  =>  'Puerto Rico',
+                'Qatar'  =>  'Qatar',
+                'Reunion'  =>  'Reunion',
+                'Romania'  =>  'Romania',
+                'Russian Federation'  =>  'Russian Federation',
+                'Rwanda'  =>  'Rwanda',
+                'Saint Helena'  =>  'Saint Helena',
+                'Saint Kitts and Nevis'  =>  'Saint Kitts and Nevis',
+                'Saint Lucia'  =>  'Saint Lucia',
+                'Saint Pierre and Miquelon'  =>  'Saint Pierre and Miquelon',
+                'Saint Vincent and the Grenadines'  =>  'Saint Vincent and the Grenadines',
+                'Samoa'  =>  'Samoa',
+                'San Marino'  =>  'San Marino',
+                'Sao tome and Principe'  =>  'Sao tome and Principe',
+                'Saudi Arabia'  =>  'Saudi Arabia',
+                'Senegal'  =>  'Senegal',
+                'Serbia and Montenegro'  =>  'Serbia and Montenegro',
+                'Seychelles'  =>  'Seychelles',
+                'Sierra Leone'  =>  'Sierra Leone',
+                'Singapore'  =>  'Singapore',
+                'Slovakia'  =>  'Slovakia',
+                'Slovenia'  =>  'Slovenia',
+                'Solomon Islands'  =>  'Solomon Islands',
+                'Somalia'  =>  'Somalia',
+                'South Africa'  =>  'South Africa',
+                'South Georgia and the South Sandwich Islands'  =>  'South Georgia and the South Sandwich Islands',
+                'Spain'  =>  'Spain',
+                'Sri Lanka'  =>  'Sri Lanka',
+                'Sudan'  =>  'Sudan',
+                'Suriname'  =>  'Suriname',
+                'Svalbard and Jan Mayen Islands'  =>  'Svalbard and Jan Mayen Islands',
+                'Swaziland'  =>  'Swaziland',
+                'Sweden'  =>  'Sweden',
+                'Switzerland'  =>  'Switzerland',
+                'Syrian Arab Republic'  =>  'Syrian Arab Republic',
+                'Taiwan'  =>  'Taiwan',
+                'Tajikistan'  =>  'Tajikistan',
+                'Thailand'  =>  'Thailand',
+                'Timor-Leste'  =>  'Timor-Leste',
+                'Togo'  =>  'Togo',
+                'Tokelau'  =>  'Tokelau',
+                'Tonga'  =>  'Tonga',
+                'Trinidad and Tobago'  =>  'Trinidad and Tobago',
+                'Tunisia'  =>  'Tunisia',
+                'Turkey'  =>  'Turkey',
+                'Turkmenistan'  =>  'Turkmenistan',
+                'Turks and Caicos Islands'  =>  'Turks and Caicos Islands',
+                'Tuvalu'  =>  'Tuvalu',
+                'Uganda'  =>  'Uganda',
+                'Ukraine'  =>  'Ukraine',
+                'United Arab Emirates'  =>  'United Arab Emirates',
+                'United Kingdom'  =>  'United Kingdom',
+                'United States'  =>  'United States',
+                'United States Minor outlying Islands'  =>  'United States Minor outlying Islands',
+                'Uruguay'  =>  'Uruguay',
+                'Uzbekistan'  =>  'Uzbekistan',
+                'Vanuatu'  =>  'Vanuatu',
+                'Vatican City State (Holy See)'  =>  'Vatican City State (Holy See)',
+                'Venezuela'  =>  'Venezuela',
+                'Viet nam'  =>  'Viet nam',
+                'Virgin Islands (British)'  =>  'Virgin Islands (British)',
+                'Virgin Islands (U.S.)'  =>  'Virgin Islands (U.S.)',
+                'Wallis and Futuna Islands'  =>  'Wallis and Futuna Islands',
+                'Western Sahara'  =>  'Western Sahara',
+                'Yemen'  =>  'Yemen',
+                'Zambia'  =>  'Zambia',
+                'Zimbabwe'  =>  'Zimbabwe',
+                'Lettland'  =>  'Lettland',
+            },
+        },
+    };
+
     # --------------------------------------------------- #
     #                                                     #
     #             Start of config options!!!              #
@@ -1216,10 +1524,10 @@ Your OTRS Notification Master
     $Self->{'CustomerPreferences'} = {
         Module => 'Kernel::System::CustomerUser::Preferences::DB',
         Params => {
-             Table => 'customer_preferences',
-             TableKey => 'preferences_key',
-             TableValue => 'preferences_value',
-             TableUserID => 'user_id',
+            Table => 'customer_preferences',
+            TableKey => 'preferences_key',
+            TableValue => 'preferences_value',
+            TableUserID => 'user_id',
         },
     };
 
@@ -1295,7 +1603,7 @@ Your OTRS Notification Master
     # --------------------------------------------------- #
     $Self->{'Frontend::CommonObject'} = {
         # key => module
-#        SomeObject => 'Kernel::System::Some',
+        # SomeObject => 'Kernel::System::Some',
     };
     $Self->{'Frontend::CommonParam'} = {
         # param => default value
@@ -1332,16 +1640,16 @@ Your OTRS Notification Master
     $Self->{'Frontend::Module'}->{'Logout'} = {
         Description => 'Logout',
         NavBar => [
-          {
-            Description => 'Logout',
-            Name => 'Logout',
-            Image => 'exit.png',
-            Link => 'Action=Logout',
-            NavBar => '',
-            Block => 'ItemPre',
-            Prio => 100,
-            AccessKey => 'l',
-          },
+            {
+                Description => 'Logout',
+                Name => 'Logout',
+                Image => 'exit.png',
+                Link => 'Action=Logout',
+                NavBar => '',
+                Block => 'ItemPre',
+                Prio => 100,
+                AccessKey => 'l',
+            },
         ],
     };
 
@@ -1349,15 +1657,18 @@ Your OTRS Notification Master
         Description => 'Agent Preferences',
         Title => 'Preferences',
         NavBar => [
-          {
-            Description => 'Agent Preferences',
-            Name => 'Preferences',
-            Image => 'prefer.png',
-            Link => 'Action=AgentPreferences',
-            Prio => 1000,
-            AccessKey => 'p',
-         },
-       ],
+            {
+                Description => 'Agent Preferences',
+                Name => 'Preferences',
+                Image => 'prefer.png',
+                Link => 'Action=AgentPreferences',
+                NavBar => 'Preferences',
+                Type => 'Menu',
+                Block => 'ItemArea',
+                Prio => 9900,
+                AccessKey => 'p',
+            },
+        ],
     };
     $Self->{'Frontend::Module'}->{'AgentSpelling'} = {
         Description => 'Spell checker',
@@ -1392,17 +1703,17 @@ Your OTRS Notification Master
         Title => '',
         NavBarName => 'Admin',
         NavBar => [
-          {
-            Description => 'Admin-Area',
-            Type => 'Menu',
-            Block => 'ItemArea',
-            Name => 'Admin',
-            Image => 'admin.png',
-            Link => 'Action=Admin',
-            NavBar => 'Admin',
-            Prio => 10000,
-            AccessKey => 'a',
-          },
+            {
+                Description => 'Admin-Area',
+                Type => 'Menu',
+                Block => 'ItemArea',
+                Name => 'Admin',
+                Image => 'admin.png',
+                Link => 'Action=Admin',
+                NavBar => 'Admin',
+                Prio => 10000,
+                AccessKey => 'a',
+            },
         ],
         NavBarModule => {
             Module => 'Kernel::Output::HTML::NavBarModuleAdmin',
@@ -1456,15 +1767,15 @@ Your OTRS Notification Master
         Title => 'Customer User',
         NavBarName => '',
         NavBar => [
-          {
-            Description => 'Edit Customer Users',
-            Name => 'Customer',
-            Image => 'folder_yellow.png',
-            Link => 'Action=AdminCustomerUser&Nav=Agent',
-            NavBar => 'Ticket',
-            Prio => 9000,
-            AccessKey => 'c',
-          }
+            {
+                Description => 'Edit Customer Users',
+                Name => 'Customer',
+                Image => 'folder_yellow.png',
+                Link => 'Action=AdminCustomerUser&Nav=Agent',
+                NavBar => 'Ticket',
+                Prio => 9000,
+                AccessKey => 'c',
+            }
         ],
         NavBarModule => {
             Module => 'Kernel::Output::HTML::NavBarModuleAdmin',
@@ -1473,6 +1784,30 @@ Your OTRS Notification Master
             Prio => 300,
         },
     };
+    $Self->{'Frontend::Module'}->{'AdminCustomerCompany'} = {
+        GroupRo => [],
+        Group => ['admin', 'users'],
+        Description => 'Edit Customer Users',
+        Title => 'Customer User',
+        NavBarName => '',
+        NavBar => [
+            {
+                Description => 'Edit Customer Company',
+                Name => 'Company',
+                Image => 'folder_yellow.png',
+                Link => 'Action=AdminCustomerCompany&Nav=Agent',
+                NavBar => 'Ticket',
+                Prio => 9000,
+                AccessKey => 'c',
+            }
+        ],
+        NavBarModule => {
+            Module => 'Kernel::Output::HTML::NavBarModuleAdmin',
+            Name => 'Customer Company',
+            Block => 'Block1',
+            Prio => 310,
+        },
+    };
     $Self->{'Frontend::Module'}->{'AdminCustomerUserGroup'} = {
         Group => ['admin'],
         Description => 'Admin',
@@ -1530,7 +1865,7 @@ Your OTRS Notification Master
             Module => 'Kernel::Output::HTML::NavBarModuleAdmin',
             Name => 'S/MIME',
             Block => 'Block3',
-            Prio => 500,
+            Prio => 1100,
         },
     };
     $Self->{'Frontend::Module'}->{'AdminPGP'} = {
@@ -1542,19 +1877,7 @@ Your OTRS Notification Master
             Module => 'Kernel::Output::HTML::NavBarModuleAdmin',
             Name => 'PGP',
             Block => 'Block3',
-            Prio => 600,
-        },
-    };
-    $Self->{'Frontend::Module'}->{'AdminSysConfig'} = {
-        Group => ['admin'],
-        Description => 'Admin',
-        Title => 'SysConfig',
-        NavBarName => 'Admin',
-        NavBarModule => {
-            Module => 'Kernel::Output::HTML::NavBarModuleAdmin',
-            Name => 'SysConfig',
-            Block => 'Block3',
-            Prio => 1100,
+            Prio => 1200,
         },
     };
     $Self->{'Frontend::Module'}->{'AdminPOP3'} = {
@@ -1629,6 +1952,18 @@ Your OTRS Notification Master
             Prio => 700,
         },
     };
+    $Self->{'Frontend::Module'}->{'AdminSysConfig'} = {
+        Group => ['admin'],
+        Description => 'Admin',
+        Title => 'SysConfig',
+        NavBarName => 'Admin',
+        NavBarModule => {
+            Module => 'Kernel::Output::HTML::NavBarModuleAdmin',
+            Name => 'SysConfig',
+            Block => 'Block4',
+            Prio => 800,
+        },
+    };
     $Self->{'Frontend::Module'}->{'AdminPackageManager'} = {
         Group => ['admin'],
         Description => 'Software Package Manager',
@@ -1650,14 +1985,14 @@ Your OTRS Notification Master
         NavBarName => '',
         Title => 'Preferences',
         NavBar => [
-          {
-            Description => 'Logout',
-            Name => 'Logout',
-            Image => 'exit.png',
-            Link => 'Action=Logout',
-            Prio => 10,
-            AccessKey => 'l',
-          },
+            {
+                Description => 'Logout',
+                Name => 'Logout',
+                Image => 'exit.png',
+                Link => 'Action=Logout',
+                Prio => 10,
+                AccessKey => 'l',
+            },
         ],
     };
     $Self->{'CustomerFrontend::Module'}->{'CustomerPreferences'} = {
@@ -1665,14 +2000,14 @@ Your OTRS Notification Master
         NavBarName => '',
         Title => 'Preferences',
         NavBar => [
-          {
-            Description => 'Preferences',
-            Name => 'Preferences',
-            Image => 'prefer.png',
-            Link => 'Action=CustomerPreferences',
-            Prio => 1000,
-            AccessKey => 'p',
-          },
+            {
+                Description => 'Preferences',
+                Name => 'Preferences',
+                Image => 'prefer.png',
+                Link => 'Action=CustomerPreferences',
+                Prio => 1000,
+                AccessKey => 'p',
+            },
         ],
     };
     $Self->{'CustomerFrontend::Module'}->{'CustomerCalendarSmall'} = {
@@ -1837,6 +2172,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.251 $ $Date: 2006/12/07 15:43:23 $
+$Revision: 1.272 $ $Date: 2007/07/26 14:15:30 $
 
 =cut
