@@ -2,7 +2,7 @@
 # Kernel/Language/de.pm - provides de language translation
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: de.pm,v 1.145 2007/07/30 18:08:16 martin Exp $
+# $Id: de.pm,v 1.147.2.2 2007/10/16 13:28:59 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,7 +13,7 @@ package Kernel::Language::de;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.145 $';
+$VERSION = '$Revision: 1.147.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub Data {
@@ -346,7 +346,7 @@ sub Data {
         'Your reporting time interval is too small, please use a larger time scale!' => 'Die Zeitskalierung ist zu klein gewhlt, bitte whlen Sie eine grere Zeitskalierung!',
         'The selected start time is before the allowed start time!' => 'Die gewhlte Startzeit ist auerhalb des erlaubten Bereichs!',
         'The selected end time is after the allowed end time!' => 'Die gewhlte Endzeit ist auerhalb des erlaubten Bereichs!',
-        'The selected time period is larger than the allowed time period!' => 'Der gewhlt Zeitraum ist grer als der erlaubte Zeitraum!',
+        'The selected time period is larger than the allowed time period!' => 'Der gewhlte Zeitraum ist grer als der erlaubte Zeitraum!',
         'Common Specification' => 'Allgemeine Angaben',
         'Xaxis' => 'X-Achse',
         'Value Series'           => 'Wertereihen',
@@ -728,7 +728,7 @@ sub Data {
         'Performance Log' => 'Performance Log',
         'This feature is enabled!' => 'Dieses Feature ist aktiv!',
         'Just use this feature if you want to log each request.' => 'Nur aktivieren wenn jede Anfrage protokolliert werden soll.',
-        'Of couse this feature will take some system performance it self!' => 'Wenn dieses Feature akitv ist, wird ist mit Leistungsdefizit zu rechnen.',
+        'Of couse this feature will take some system performance it self!' => 'Wenn dieses Feature aktiv ist, ist mit Leistungsdefizit zu rechnen.',
         'Disable it here!' => 'Hier deaktivieren!',
         'This feature is disabled!' => 'Dieses Feature ist inaktiv!',
         'Enable it here!' => 'Hier aktivieren!',
@@ -780,7 +780,7 @@ sub Data {
         '0 = no unlock' => '0 = keine Freigabe',
         'Escalation - First Response Time' => 'Eskalation - Reaktionszeit',
         '0 = no escalation' => '0 = keine Eskalation',
-        'Escalation - Update Time' => 'Eskalation - Aktuallisierungszeit',
+        'Escalation - Update Time' => 'Eskalation - Aktualisierungszeit',
         'Escalation - Solution Time' => 'Eskalation - Lsungszeit',
         'Follow up Option' => 'Nachfrage Option',
         'Ticket lock after a follow up' => 'Ticket sperren nach einem Follow-Up',
@@ -883,7 +883,7 @@ sub Data {
         'Add a new SLA.' => 'Einen neuen SLA hinzufgen.',
         'SLA' => 'SLA',
         'First Response Time' => 'Reaktionszeit',
-        'Update Time' => 'Aktuallisierungszeit',
+        'Update Time' => 'Aktualisierungszeit',
         'Solution Time' => 'Lsungszeit',
 
         # Template: AdminSMIMEForm
@@ -1278,6 +1278,7 @@ sub Data {
         # Template: CustomerTicketZoom
 
         # Template: CustomerWarning
+	'This account exists' => 'Dieser Benutzer ist bereits vorhanden',
 
         # Template: Error
         'Click here to report a bug!' => 'Klicken Sie hier, um einen Fehler zu berichten!',
