@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketBounce.pm - to bounce articles of tickets
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentTicketBounce.pm,v 1.8 2006/11/15 07:47:24 martin Exp $
+# $Id: AgentTicketBounce.pm,v 1.10 2007/01/20 18:04:49 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -18,10 +18,9 @@ use Kernel::System::CustomerUser;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.8 $';
+$VERSION = '$Revision: 1.10 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-# --
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -42,14 +41,12 @@ sub new {
     $Self->{StateObject} = Kernel::System::State->new(%Param);
     $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(%Param);
     $Self->{SystemAddress} = Kernel::System::SystemAddress->new(%Param);
-
     $Self->{ArticleID} = $Self->{ParamObject}->GetParam(Param => 'ArticleID') || '';
-
     $Self->{Config} = $Self->{ConfigObject}->Get("Ticket::Frontend::$Self->{Action}");
 
     return $Self;
 }
-# --
+
 sub Run {
     my $Self = shift;
     my %Param = @_;
@@ -57,8 +54,8 @@ sub Run {
     foreach (qw(ArticleID TicketID QueueID)) {
         if (! defined $Self->{$_}) {
             return $Self->{LayoutObject}->ErrorScreen(
-              Message => "$_ is needed!",
-              Comment => 'Please contact your admin',
+                Message => "$_ is needed!",
+                Comment => 'Please contact your admin',
             );
         }
     }
@@ -152,29 +149,33 @@ sub Run {
         else {
             $Article{To} = $Article{From};
         }
+        # get customer data
+        my %Customer = ();
+        if ($Ticket{CustomerUserID}) {
+            %Customer = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                User => $Ticket{CustomerUserID},
+            );
+        }
         # prepare salutation
         $Param{Salutation} = $Self->{QueueObject}->GetSalutation(%Article);
-        # prepare customer realname
-        if ($Param{Salutation} =~ /<OTRS_CUSTOMER_REALNAME>/) {
-            # get realname
-            my $From = '';
-            if ($Article{CustomerUserID}) {
-                $From = $Self->{CustomerUserObject}->CustomerName(UserLogin => $Article{CustomerUserID});
-            }
-            if (!$From) {
-                $From = $Article{From} || '';
-                $From =~ s/<.*>|\(.*\)|\"|;|,//g;
-                $From =~ s/( $)|(  $)//g;
-            }
-            # get realname
-            $Param{Salutation} =~ s/<OTRS_CUSTOMER_REALNAME>/$From/g;
-        }
         # prepare signature
         $Param{Signature} = $Self->{QueueObject}->GetSignature(%Article);
         foreach (qw(Signature Salutation)) {
-            $Param{$_} =~ s/<OTRS_FIRST_NAME>/$Self->{UserFirstname}/g;
-            $Param{$_} =~ s/<OTRS_LAST_NAME>/$Self->{UserLastname}/g;
-            # replace user staff
+            # get and prepare realname
+            if ($Param{$_} =~ /<OTRS_CUSTOMER_REALNAME>/) {
+                my $From = '';
+                if ($Ticket{CustomerUserID}) {
+                    $From = $Self->{CustomerUserObject}->CustomerName(UserLogin => $Ticket{CustomerUserID});
+                }
+                if (!$From) {
+                    $From = $Article{From} || '';
+                    $From =~ s/<.*>|\(.*\)|\"|;|,//g;
+                    $From =~ s/( $)|(  $)//g;
+                }
+                $Param{$_} =~ s/<OTRS_CUSTOMER_REALNAME>/$From/g;
+            }
+
+            # current user
             my %User = $Self->{UserObject}->GetUserData(
                 UserID => $Self->{UserID},
                 Cached => 1,
@@ -182,10 +183,43 @@ sub Run {
             foreach my $UserKey (keys %User) {
                 if ($User{$UserKey}) {
                     $Param{$_} =~ s/<OTRS_Agent_$UserKey>/$User{$UserKey}/gi;
+                    $Param{$_} =~ s/<OTRS_CURRENT_$UserKey>/$User{$UserKey}/gi;
                 }
             }
-            # cleanup all not needed <OTRS_Agent_tags
+            # replace other needed stuff
+            $Param{$_} =~ s/<OTRS_FIRST_NAME>/$Self->{UserFirstname}/g;
+            $Param{$_} =~ s/<OTRS_LAST_NAME>/$Self->{UserLastname}/g;
+            # cleanup
             $Param{$_} =~ s/<OTRS_Agent_.+?>/-/gi;
+            $Param{$_} =~ s/<OTRS_CURRENT_.+?>/-/gi;
+
+            # owner user
+            my %OwnerUser = $Self->{UserObject}->GetUserData(
+                UserID => $Ticket{OwnerID},
+                Cached => 1,
+            );
+            foreach my $UserKey (keys %OwnerUser) {
+                if ($OwnerUser{$UserKey}) {
+                    $Param{$_} =~ s/<OTRS_OWNER_$UserKey>/$OwnerUser{$UserKey}/gi;
+                }
+            }
+            # cleanup
+            $Param{$_} =~ s/<OTRS_OWNER_.+?>/-/gi;
+
+            # responsible user
+            my %ResponsibleUser = $Self->{UserObject}->GetUserData(
+                UserID => $Ticket{ResponsibleID},
+                Cached => 1,
+            );
+            foreach my $UserKey (keys %ResponsibleUser) {
+                if ($ResponsibleUser{$UserKey}) {
+                    $Param{$_} =~ s/<OTRS_RESPONSIBLE_$UserKey>/$ResponsibleUser{$UserKey}/gi;
+                }
+            }
+            # cleanup
+            $Param{$_} =~ s/<OTRS_RESPONSIBLE_.+?>/-/gi;
+
+            # replace ticket data
             foreach my $Key (keys %Ticket) {
                 if ($Ticket{$Key}) {
                     $Param{$_} =~ s/<OTRS_TICKET_$Key>/$Ticket{$Key}/gi;
@@ -193,6 +227,19 @@ sub Run {
             }
             # cleanup all not needed <OTRS_TICKET_ tags
             $Param{$_} =~ s/<OTRS_TICKET_.+?>/-/gi;
+            # replace customer data
+            foreach my $CustomerKey (keys %Customer) {
+                if ($Customer{$CustomerKey}) {
+                    $Param{$_} =~ s/<OTRS_CUSTOMER_$CustomerKey>/$Customer{$CustomerKey}/gi;
+                    $Param{$_} =~ s/<OTRS_CUSTOMER_DATA_$CustomerKey>/$Customer{$CustomerKey}/gi;
+                }
+            }
+            # cleanup all not needed <OTRS_CUSTOMER_ tags
+            $Param{$_} =~ s/<OTRS_CUSTOMER_.+?>/-/gi;
+            $Param{$_} =~ s/<OTRS_CUSTOMER_DATA_.+?>/-/gi;
+            # replace config options
+            $Param{$_} =~ s{<OTRS_CONFIG_(.+?)>}{$Self->{ConfigObject}->Get($1)}egx;
+            $Param{$_} =~ s/<OTRS_CONFIG_.+?>/-/gi;
         }
         # prepare body ...
         my $NewLine = $Self->{ConfigObject}->Get('Ticket::Frontend::TextAreaEmail') || 75;
@@ -251,12 +298,9 @@ sub Run {
         foreach my $Email (Mail::Address->parse($Param{BounceTo})) {
             my $Address = $Email->address();
             if ($Self->{SystemAddress}->SystemAddressIsLocalAddress(Address => $Address)) {
-                # --
                 # error page
-                # --
                 return $Self->{LayoutObject}->ErrorScreen(
-                    Message => "Can't forward ticket to $Address! It's a local ".
-                      "address! You need to move it!",
+                    Message => "Can't forward ticket to $Address! It's a local address! You need to move it!",
                     Comment => 'Please contact the admin.',
                 );
             }
@@ -277,32 +321,32 @@ sub Run {
             Email => $Param{EmailPlain},
             HistoryType => 'Bounce',
         )) {
-           # error page
-           return $Self->{LayoutObject}->ErrorScreen(
-               Message => "Can't bounce email!",
-               Comment => 'Please contact the admin.',
-           );
+            # error page
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "Can't bounce email!",
+                Comment => 'Please contact the admin.',
+            );
         }
         # send customer info?
         if ($Param{InformSender}) {
             $Param{Body} =~ s/<OTRS_TICKET>/$Param{TicketNumber}/g;
             $Param{Body} =~ s/<OTRS_BOUNCE_TO>/$Param{BounceTo}/g;
             if (my $ArticleID = $Self->{TicketObject}->ArticleSend(
-              ArticleType => 'email-external',
-              SenderType => 'agent',
-              TicketID => $Self->{TicketID},
-              HistoryType => 'Bounce',
-              HistoryComment => "Bounced info to '$Param{To}'.",
-              From => $Param{From},
-              Email => $Param{Email},
-              To => $Param{To},
-              Subject => $Param{Subject},
-              UserID => $Self->{UserID},
-              Body => $Param{Body},
-              Charset => $Self->{LayoutObject}->{UserCharset},
-              Type => 'text/plain',
+                ArticleType => 'email-external',
+                SenderType => 'agent',
+                TicketID => $Self->{TicketID},
+                HistoryType => 'Bounce',
+                HistoryComment => "Bounced info to '$Param{To}'.",
+                From => $Param{From},
+                Email => $Param{Email},
+                To => $Param{To},
+                Subject => $Param{Subject},
+                UserID => $Self->{UserID},
+                Body => $Param{Body},
+                Charset => $Self->{LayoutObject}->{UserCharset},
+                Type => 'text/plain',
             )) {
-              ###
+                # null
             }
             else {
                 # error page
@@ -321,7 +365,7 @@ sub Run {
             ArticleID => $Self->{ArticleID},
             StateID => $Param{BounceStateID},
             UserID => $Self->{UserID},
-          );
+        );
         # should i set an unlock?
         if ($StateData{TypeName} =~ /^close/i) {
             $Self->{TicketObject}->LockSet(
@@ -345,4 +389,5 @@ sub Run {
         );
     }
 }
-1;
+
+1;
\ No newline at end of file
