@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketCompose.pm - to compose and send a message
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentTicketCompose.pm,v 1.22.2.3 2007/04/05 08:02:33 martin Exp $
+# $Id: AgentTicketCompose.pm,v 1.30 2007/03/14 12:55:00 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -20,7 +20,7 @@ use Kernel::System::Web::UploadCache;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.22.2.3 $';
+$VERSION = '$Revision: 1.30 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -52,7 +52,7 @@ sub new {
     $Self->{UploadCachObject} = Kernel::System::Web::UploadCache->new(%Param);
     # get response format
     $Self->{ResponseFormat} = $Self->{ConfigObject}->Get('Ticket::Frontend::ResponseFormat') ||
-      '$Data{"Salutation"}
+        '$Data{"Salutation"}
 $Data{"OrigFrom"} $Text{"wrote"}:
 $Data{"Body"}
 
@@ -167,19 +167,22 @@ sub Run {
     }
     # get ticket free text params
     foreach (1..16) {
-        $GetParam{"TicketFreeKey$_"} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeKey$_");
-        $GetParam{"TicketFreeText$_"} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeText$_");
+        $GetParam{"TicketFreeKey$_"} = $Self->{ParamObject}->GetParam(Param => "TicketFreeKey$_");
+        $GetParam{"TicketFreeText$_"} = $Self->{ParamObject}->GetParam(Param => "TicketFreeText$_");
     }
-    # get ticket free text params
-    foreach (1..2) {
-        foreach my $Type (qw(Year Month Day Hour Minute)) {
-            $GetParam{"TicketFreeTime".$_.$Type} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+    # get ticket free time params
+    foreach (1..6) {
+        foreach my $Type (qw(Used Year Month Day Hour Minute)) {
+            $GetParam{"TicketFreeTime".$_.$Type} = $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+        }
+        if (!$Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_)) {
+            $GetParam{'TicketFreeTime'.$_.'Used'} = 1;
         }
     }
     # get article free text params
     foreach (1..3) {
-        $GetParam{"ArticleFreeKey$_"} =  $Self->{ParamObject}->GetParam(Param => "ArticleFreeKey$_");
-        $GetParam{"ArticleFreeText$_"} =  $Self->{ParamObject}->GetParam(Param => "ArticleFreeText$_");
+        $GetParam{"ArticleFreeKey$_"} = $Self->{ParamObject}->GetParam(Param => "ArticleFreeKey$_");
+        $GetParam{"ArticleFreeText$_"} = $Self->{ParamObject}->GetParam(Param => "ArticleFreeText$_");
     }
 
     # send email
@@ -194,6 +197,12 @@ sub Run {
                 $Error{"Date invalid"} = 'invalid';
             }
         }
+        # check required FreeTextField (if configured)
+        foreach (1..16) {
+            if ($Self->{Config}{'TicketFreeText'}{$_} == 2 && $GetParam{"TicketFreeText$_"} eq '') {
+                $Error{"TicketFreeTextField$_ invalid"} = 'invalid';
+            }
+        }
         # attachment delete
         foreach (1..16) {
             if ($GetParam{"AttachmentDelete$_"}) {
@@ -225,7 +234,7 @@ sub Run {
             if ($GetParam{$_}) {
                 foreach my $Email (Mail::Address->parse($GetParam{$_})) {
                     if (!$Self->{CheckItemObject}->CheckEmail(Address => $Email->address())) {
-                         $Error{"$_ invalid"} .= $Self->{CheckItemObject}->CheckError();
+                        $Error{"$_ invalid"} .= $Self->{CheckItemObject}->CheckError();
                     }
                 }
             }
@@ -391,16 +400,27 @@ sub Run {
                 }
             }
             # set ticket free time
-            foreach (1..2) {
+            foreach (1..6) {
                 if (defined($GetParam{"TicketFreeTime".$_."Year"}) &&
                     defined($GetParam{"TicketFreeTime".$_."Month"}) &&
                     defined($GetParam{"TicketFreeTime".$_."Day"}) &&
                     defined($GetParam{"TicketFreeTime".$_."Hour"}) &&
-                    defined($GetParam{"TicketFreeTime".$_."Minute"})) {
-                    my %Time = $Self->{LayoutObject}->TransfromDateSelection(
-                        %GetParam,
-                        Prefix => "TicketFreeTime".$_,
-                    );
+                    defined($GetParam{"TicketFreeTime".$_."Minute"})
+                ) {
+                    my %Time;
+                    $Time{"TicketFreeTime".$_."Year"} = 0;
+                    $Time{"TicketFreeTime".$_."Month"} = 0;
+                    $Time{"TicketFreeTime".$_."Day"} = 0;
+                    $Time{"TicketFreeTime".$_."Hour"} = 0;
+                    $Time{"TicketFreeTime".$_."Minute"} = 0;
+                    $Time{"TicketFreeTime".$_."Secunde"} = 0;
+
+                    if ($GetParam{"TicketFreeTime".$_."Used"}) {
+                        %Time = $Self->{LayoutObject}->TransfromDateSelection(
+                            %GetParam,
+                            Prefix => "TicketFreeTime".$_,
+                        );
+                    }
                     $Self->{TicketObject}->TicketFreeTimeSet(
                         %Time,
                         Prefix => "TicketFreeTime",
@@ -457,7 +477,7 @@ sub Run {
                 return $Self->{LayoutObject}->Redirect(OP => $Self->{LastScreenOverview});
             }
             else {
-                return $Self->{LayoutObject}->Redirect(OP => $Self->{LastScreenView});
+                return $Self->{LayoutObject}->Redirect(OP => "Action=AgentTicketZoom&TicketID=$Self->{TicketID}&ArticleID=$ArticleID");
             }
         }
         else {
@@ -617,7 +637,7 @@ sub Run {
                 }
                 $Data{$_} =~ s/<OTRS_CUSTOMER_REALNAME>/$From/g;
             }
-            # replace user staff
+            # current user
             my %User = $Self->{UserObject}->GetUserData(
                 UserID => $Self->{UserID},
                 Cached => 1,
@@ -625,13 +645,43 @@ sub Run {
             foreach my $UserKey (keys %User) {
                 if ($User{$UserKey}) {
                     $Data{$_} =~ s/<OTRS_Agent_$UserKey>/$User{$UserKey}/gi;
+                    $Data{$_} =~ s/<OTRS_CURRENT_$UserKey>/$User{$UserKey}/gi;
                 }
             }
-            # cleanup all not needed <OTRS_TICKET_ tags
-            $Data{$_} =~ s/<OTRS_Agent_.+?>/-/gi;
             # replace other needed stuff
             $Data{$_} =~ s/<OTRS_FIRST_NAME>/$Self->{UserFirstname}/g;
             $Data{$_} =~ s/<OTRS_LAST_NAME>/$Self->{UserLastname}/g;
+            # cleanup
+            $Data{$_} =~ s/<OTRS_Agent_.+?>/-/gi;
+            $Data{$_} =~ s/<OTRS_CURRENT_.+?>/-/gi;
+
+            # owner user
+            my %OwnerUser = $Self->{UserObject}->GetUserData(
+                UserID => $Ticket{OwnerID},
+                Cached => 1,
+            );
+            foreach my $UserKey (keys %OwnerUser) {
+                if ($OwnerUser{$UserKey}) {
+                    $Data{$_} =~ s/<OTRS_OWNER_$UserKey>/$OwnerUser{$UserKey}/gi;
+                }
+            }
+            # cleanup
+            $Data{$_} =~ s/<OTRS_OWNER_.+?>/-/gi;
+
+            # responsible user
+            my %ResponsibleUser = $Self->{UserObject}->GetUserData(
+                UserID => $Ticket{ResponsibleID},
+                Cached => 1,
+            );
+            foreach my $UserKey (keys %ResponsibleUser) {
+                if ($ResponsibleUser{$UserKey}) {
+                    $Data{$_} =~ s/<OTRS_RESPONSIBLE_$UserKey>/$ResponsibleUser{$UserKey}/gi;
+                }
+            }
+            # cleanup
+            $Data{$_} =~ s/<OTRS_RESPONSIBLE_.+?>/-/gi;
+
+            # replace other needed stuff
             # replace ticket data
             foreach my $TicketKey (keys %Ticket) {
                 if ($Ticket{$TicketKey}) {
@@ -644,12 +694,15 @@ sub Run {
             foreach my $CustomerKey (keys %Customer) {
                 if ($Customer{$CustomerKey}) {
                     $Data{$_} =~ s/<OTRS_CUSTOMER_$CustomerKey>/$Customer{$CustomerKey}/gi;
+                    $Data{$_} =~ s/<OTRS_CUSTOMER_DATA_$CustomerKey>/$Customer{$CustomerKey}/gi;
                 }
             }
             # cleanup all not needed <OTRS_CUSTOMER_ tags
             $Data{$_} =~ s/<OTRS_CUSTOMER_.+?>/-/gi;
+            $Data{$_} =~ s/<OTRS_CUSTOMER_DATA_.+?>/-/gi;
             # replace config options
             $Data{$_} =~ s{<OTRS_CONFIG_(.+?)>}{$Self->{ConfigObject}->Get($1)}egx;
+            $Data{$_} =~ s/<OTRS_CONFIG_.+?>/-/gi;
         }
 
         # check some values
@@ -657,7 +710,7 @@ sub Run {
             if ($Data{$_}) {
                 foreach my $Email (Mail::Address->parse($Data{$_})) {
                     if (!$Self->{CheckItemObject}->CheckEmail(Address => $Email->address())) {
-                         $Error{"$_ invalid"} .= $Self->{CheckItemObject}->CheckError();
+                        $Error{"$_ invalid"} .= $Self->{CheckItemObject}->CheckError();
                     }
                 }
             }
@@ -682,15 +735,26 @@ sub Run {
             Ticket => \%Ticket,
             Config => \%TicketFreeText,
         );
-        # ticket free time
+        # free time
         my %TicketFreeTime = ();
-        foreach (1..2) {
+        foreach (1..6) {
+            $TicketFreeTime{"TicketFreeTime".$_.'Optional'} = $Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_) || 0;
+            $TicketFreeTime{"TicketFreeTime".$_.'Used'} = $GetParam{'TicketFreeTime'.$_.'Used'};
+
             if ($Ticket{"TicketFreeTime".$_}) {
-                ($TicketFreeTime{"TicketFreeTime".$_.'Secunde'}, $TicketFreeTime{"TicketFreeTime".$_.'Minute'}, $TicketFreeTime{"TicketFreeTime".$_.'Hour'}, $TicketFreeTime{"TicketFreeTime".$_.'Day'}, $TicketFreeTime{"TicketFreeTime".$_.'Month'},  $TicketFreeTime{"TicketFreeTime".$_.'Year'}) = $Self->{TimeObject}->SystemTime2Date(
+                (
+                    $TicketFreeTime{"TicketFreeTime".$_.'Secunde'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Minute'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Hour'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Day'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Month'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Year'}
+                ) = $Self->{TimeObject}->SystemTime2Date(
                     SystemTime => $Self->{TimeObject}->TimeStamp2SystemTime(
                         String => $Ticket{"TicketFreeTime".$_},
                     ),
                 );
+                $TicketFreeTime{"TicketFreeTime".$_.'Used'} = 1;
             }
         }
         my %TicketFreeTimeHTML = $Self->{LayoutObject}->AgentFreeDate(
@@ -825,6 +889,7 @@ sub _Mask {
                     TicketFreeKeyField => $Param{'TicketFreeKeyField'.$Count},
                     TicketFreeTextField => $Param{'TicketFreeTextField'.$Count},
                     Count => $Count,
+                    %Param,
                 },
             );
             $Self->{LayoutObject}->Block(
@@ -837,7 +902,7 @@ sub _Mask {
         }
     }
     $Count = 0;
-    foreach (1..2) {
+    foreach (1..6) {
         $Count++;
         if ($Self->{Config}->{'TicketFreeTime'}->{$Count}) {
             $Self->{LayoutObject}->Block(
@@ -907,6 +972,18 @@ sub _Mask {
             Data => $DataRef,
         );
     }
+    # jscript check freetextfields by submit
+    foreach my $Key (keys %{$Self->{Config}->{TicketFreeText}}) {
+        if ($Self->{Config}->{TicketFreeText}->{$Key} == 2) {
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketFreeTextCheckJs',
+                Data => {
+                    TicketFreeTextField => "TicketFreeText$Key",
+                    TicketFreeKeyField => "TicketFreeKey$Key",
+                },
+            );
+        }
+    }
     # create & return output
     return $Self->{LayoutObject}->Output(TemplateFile => 'AgentTicketCompose', Data => \%Param);
 }
