@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketForward.pm - to forward a message
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentTicketForward.pm,v 1.16.2.1 2007/01/17 13:27:57 mh Exp $
+# $Id: AgentTicketForward.pm,v 1.23 2007/03/14 12:55:00 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -20,7 +20,7 @@ use Kernel::System::Web::UploadCache;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.16.2.1 $';
+$VERSION = '$Revision: 1.23 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -39,10 +39,10 @@ sub new {
     }
 
     # check all needed objects
-    foreach (qw(TicketObject ParamObject DBObject QueueObject LayoutObject
-        ConfigObject LogObject)
-    ) {
-        die "Got no $_" if (!$Self->{$_});
+    foreach (qw(TicketObject ParamObject DBObject QueueObject LayoutObject ConfigObject LogObject)) {
+        if (!$Self->{$_}) {
+            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+        }
     }
     # some new objects
     $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(%Param);
@@ -60,7 +60,6 @@ sub new {
         FormID)
     ) {
         my $Value = $Self->{ParamObject}->GetParam(Param => $_);
-#        $Self->{GetParam}->{$_} = defined $Value ? $Value : '';
         if (defined($Value)) {
             $Self->{GetParam}->{$_} = $Value;
         }
@@ -194,18 +193,14 @@ sub Form {
         FormID => $GetParam{FormID},
     );
 
-    # --
     # get customer data
-    # --
     my %Customer = ();
     if ($Ticket{CustomerUserID}) {
         %Customer = $Self->{CustomerUserObject}->CustomerUserDataGet(
             User => $Ticket{CustomerUserID},
         );
     }
-    # --
     # prepare salutation
-    # --
     $Data{Salutation} = $Self->{QueueObject}->GetSalutation(%Ticket);
     # prepare signature
     $Data{Signature} = $Self->{QueueObject}->GetSignature(%Ticket);
@@ -223,7 +218,7 @@ sub Form {
             }
             $Data{$_} =~ s/<OTRS_CUSTOMER_REALNAME>/$From/g;
         }
-        # replace user staff
+        # current user
         my %User = $Self->{UserObject}->GetUserData(
             UserID => $Self->{UserID},
             Cached => 1,
@@ -231,13 +226,42 @@ sub Form {
         foreach my $UserKey (keys %User) {
             if ($User{$UserKey}) {
                 $Data{$_} =~ s/<OTRS_Agent_$UserKey>/$User{$UserKey}/gi;
+                $Data{$_} =~ s/<OTRS_CURRENT_$UserKey>/$User{$UserKey}/gi;
             }
         }
-        # cleanup all not needed <OTRS_TICKET_ tags
-        $Data{$_} =~ s/<OTRS_Agent_.+?>/-/gi;
         # replace other needed stuff
         $Data{$_} =~ s/<OTRS_FIRST_NAME>/$Self->{UserFirstname}/g;
         $Data{$_} =~ s/<OTRS_LAST_NAME>/$Self->{UserLastname}/g;
+        # cleanup
+        $Data{$_} =~ s/<OTRS_Agent_.+?>/-/gi;
+        $Data{$_} =~ s/<OTRS_CURRENT_.+?>/-/gi;
+
+        # owner user
+        my %OwnerUser = $Self->{UserObject}->GetUserData(
+            UserID => $Ticket{OwnerID},
+            Cached => 1,
+        );
+        foreach my $UserKey (keys %OwnerUser) {
+            if ($OwnerUser{$UserKey}) {
+                $Data{$_} =~ s/<OTRS_OWNER_$UserKey>/$OwnerUser{$UserKey}/gi;
+            }
+        }
+        # cleanup
+        $Data{$_} =~ s/<OTRS_OWNER_.+?>/-/gi;
+
+        # responsible user
+        my %ResponsibleUser = $Self->{UserObject}->GetUserData(
+            UserID => $Ticket{ResponsibleID},
+            Cached => 1,
+        );
+        foreach my $UserKey (keys %ResponsibleUser) {
+            if ($ResponsibleUser{$UserKey}) {
+                $Data{$_} =~ s/<OTRS_RESPONSIBLE_$UserKey>/$ResponsibleUser{$UserKey}/gi;
+            }
+        }
+        # cleanup
+        $Data{$_} =~ s/<OTRS_RESPONSIBLE_.+?>/-/gi;
+
         # replace ticket data
         foreach my $TicketKey (keys %Ticket) {
             if ($Ticket{$TicketKey}) {
@@ -250,16 +274,17 @@ sub Form {
         foreach my $CustomerKey (keys %Customer) {
             if ($Customer{$CustomerKey}) {
                 $Data{$_} =~ s/<OTRS_CUSTOMER_$CustomerKey>/$Customer{$CustomerKey}/gi;
+                $Data{$_} =~ s/<OTRS_CUSTOMER_DATA_$CustomerKey>/$Customer{$CustomerKey}/gi;
             }
         }
         # cleanup all not needed <OTRS_CUSTOMER_ tags
         $Data{$_} =~ s/<OTRS_CUSTOMER_.+?>/-/gi;
+        $Data{$_} =~ s/<OTRS_CUSTOMER_DATA.+?>/-/gi;
         # replace config options
         $Data{$_} =~ s{<OTRS_CONFIG_(.+?)>}{$Self->{ConfigObject}->Get($1)}egx;
+        $Data{$_} =~ s/<OTRS_CONFIG_.+?>/-/gi;
     }
-    # --
     # check if original content isn't text/plain or text/html, don't use it
-    # --
     if ($Data{'ContentType'}) {
         if($Data{'ContentType'} =~ /text\/html/i) {
             $Data{Body} =~ s/\<.+?\>//gs;
@@ -268,9 +293,7 @@ sub Form {
             $Data{Body} = "-> no quotable message <-";
         }
     }
-    # --
     # prepare body, subject, ReplyTo ...
-    # --
     my $NewLine = $Self->{ConfigObject}->Get('Ticket::Frontend::TextAreaEmail') || 75;
     $Data{Body} =~ s/(^>.+|.{4,$NewLine})(?:\s|\z)/$1\n/gm;
     $Data{Body} =~ s/\t/ /g;
@@ -302,9 +325,7 @@ sub Form {
     $Data{Email} = $Address{Email};
     $Data{RealName} = $Address{RealName};
 
-    # --
     # check some values
-    # --
     foreach (qw(To Cc Bcc)) {
         if ($Data{$_}) {
             delete $Data{$_};
@@ -354,24 +375,34 @@ sub Form {
         Ticket => \%Ticket,
         Config => \%TicketFreeText,
     );
-    # get ticket free text params
-    foreach (1..2) {
-        foreach my $Type (qw(Year Month Day Hour Minute)) {
-            $GetParam{"TicketFreeTime".$_.$Type} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+    # get ticket free time params
+    foreach (1..6) {
+        if (!$Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_)) {
+            $GetParam{'TicketFreeTime'.$_.'Used'} = 1;
         }
     }
-    # get free text params
+    # free time
     my %TicketFreeTime = ();
-    foreach (1..2) {
+    foreach (1..6) {
+        $TicketFreeTime{"TicketFreeTime".$_.'Optional'} = $Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_) || 0;
+        $TicketFreeTime{"TicketFreeTime".$_.'Used'} = $GetParam{'TicketFreeTime'.$_.'Used'};
+
         if ($Ticket{"TicketFreeTime".$_}) {
-            ($TicketFreeTime{"TicketFreeTime".$_.'Secunde'}, $TicketFreeTime{"TicketFreeTime".$_.'Minute'}, $TicketFreeTime{"TicketFreeTime".$_.'Hour'}, $TicketFreeTime{"TicketFreeTime".$_.'Day'}, $TicketFreeTime{"TicketFreeTime".$_.'Month'},  $TicketFreeTime{"TicketFreeTime".$_.'Year'}) = $Self->{TimeObject}->SystemTime2Date(
+            (
+                $TicketFreeTime{"TicketFreeTime".$_.'Secunde'},
+                $TicketFreeTime{"TicketFreeTime".$_.'Minute'},
+                $TicketFreeTime{"TicketFreeTime".$_.'Hour'},
+                $TicketFreeTime{"TicketFreeTime".$_.'Day'},
+                $TicketFreeTime{"TicketFreeTime".$_.'Month'},
+                $TicketFreeTime{"TicketFreeTime".$_.'Year'}
+            ) = $Self->{TimeObject}->SystemTime2Date(
                 SystemTime => $Self->{TimeObject}->TimeStamp2SystemTime(
                     String => $Ticket{"TicketFreeTime".$_},
                 ),
             );
+            $TicketFreeTime{"TicketFreeTime".$_.'Used'} = 1;
         }
     }
-    # free time
     my %TicketFreeTimeHTML = $Self->{LayoutObject}->AgentFreeDate(
         Ticket => \%TicketFreeTime,
     );
@@ -388,7 +419,7 @@ sub Form {
         %Data,
         %GetParam,
         %TicketFreeTextHTML,
-        %TicketFreeTime,
+        %TicketFreeTimeHTML,
     );
     $Output .= $Self->{LayoutObject}->Footer();
 
@@ -444,7 +475,7 @@ sub SendEmail {
         if ($GetParam{$_}) {
             foreach my $Email (Mail::Address->parse($GetParam{$_})) {
                 if (!$Self->{CheckItemObject}->CheckEmail(Address => $Email->address())) {
-                     $Error{"$_ invalid"} .= $Self->{CheckItemObject}->CheckError();
+                    $Error{"$_ invalid"} .= $Self->{CheckItemObject}->CheckError();
                 }
             }
         }
@@ -463,8 +494,8 @@ sub SendEmail {
     # prepare free text
     my %TicketFree = ();
     foreach (1..16) {
-        $TicketFree{"TicketFreeKey$_"} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeKey$_");
-        $TicketFree{"TicketFreeText$_"} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeText$_");
+        $TicketFree{"TicketFreeKey$_"} = $Self->{ParamObject}->GetParam(Param => "TicketFreeKey$_");
+        $TicketFree{"TicketFreeText$_"} = $Self->{ParamObject}->GetParam(Param => "TicketFreeText$_");
     }
     # get free text config options
     my %TicketFreeText = ();
@@ -476,33 +507,38 @@ sub SendEmail {
             UserID => $Self->{UserID},
         );
         $TicketFreeText{"TicketFreeText$_"} = $Self->{TicketObject}->TicketFreeTextGet(
-           TicketID => $Self->{TicketID},
+            TicketID => $Self->{TicketID},
             Type => "TicketFreeText$_",
             Action => $Self->{Action},
             UserID => $Self->{UserID},
         );
+        # check required FreeTextField (if configured)
+        if ($Self->{Config}{'TicketFreeText'}{$_} == 2 && $TicketFree{"TicketFreeText$_"} eq '') {
+            $Error{"TicketFreeTextField$_ invalid"} = 'invalid';
+        }
     }
     my %TicketFreeTextHTML = $Self->{LayoutObject}->AgentFreeText(
         Config => \%TicketFreeText,
         Ticket => \%TicketFree,
     );
-    # get ticket free text params
-    foreach (1..2) {
-        foreach my $Type (qw(Year Month Day Hour Minute)) {
-            $GetParam{"TicketFreeTime".$_.$Type} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+    # get ticket free time params
+    foreach (1..6) {
+        foreach my $Type (qw(Used Year Month Day Hour Minute)) {
+            $GetParam{"TicketFreeTime".$_.$Type} = $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+        }
+        if (!$Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_)) {
+            $GetParam{'TicketFreeTime'.$_.'Used'} = 1;
         }
     }
     my %TicketFreeTimeHTML = $Self->{LayoutObject}->AgentFreeDate(
         Ticket => \%GetParam,
     );
-    # --
     # check some values
-    # --
     foreach (qw(To Cc Bcc)) {
         if ($GetParam{$_}) {
             foreach my $Email (Mail::Address->parse($GetParam{$_})) {
                 if (!$Self->{CheckItemObject}->CheckEmail(Address => $Email->address())) {
-                     $Error{"$_ invalid"} .= $Self->{CheckItemObject}->CheckError();
+                    $Error{"$_ invalid"} .= $Self->{CheckItemObject}->CheckError();
                 }
                 if ($Self->{SystemAddress}->SystemAddressIsLocalAddress(Address => $Email->address())) {
                     $Error{"$_ invalid"} .= "Can't forward ticket to ".$Email->address()."! It's a local address! Move it Tickets!"
@@ -510,6 +546,7 @@ sub SendEmail {
             }
         }
     }
+
     my %ArticleParam = ();
     # run compose modules
     if (ref($Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule')) eq 'HASH') {
@@ -537,9 +574,7 @@ sub SendEmail {
             }
         }
     }
-    # --
     # check if there is an error
-    # --
     if (%Error) {
         my $QueueID = $Self->{TicketObject}->TicketQueueID(TicketID => $Self->{TicketID});
         my $Output = $Self->{LayoutObject}->Header(Value => $Tn);
@@ -617,16 +652,27 @@ sub SendEmail {
             }
         }
         # set ticket free time
-        foreach (1..2) {
+        foreach (1..6) {
             if (defined($GetParam{"TicketFreeTime".$_."Year"}) &&
                 defined($GetParam{"TicketFreeTime".$_."Month"}) &&
                 defined($GetParam{"TicketFreeTime".$_."Day"}) &&
                 defined($GetParam{"TicketFreeTime".$_."Hour"}) &&
-                defined($GetParam{"TicketFreeTime".$_."Minute"})) {
-                my %Time = $Self->{LayoutObject}->TransfromDateSelection(
-                    %GetParam,
-                    Prefix => "TicketFreeTime".$_,
-                );
+                defined($GetParam{"TicketFreeTime".$_."Minute"})
+            ) {
+                my %Time;
+                $Time{"TicketFreeTime".$_."Year"} = 0;
+                $Time{"TicketFreeTime".$_."Month"} = 0;
+                $Time{"TicketFreeTime".$_."Day"} = 0;
+                $Time{"TicketFreeTime".$_."Hour"} = 0;
+                $Time{"TicketFreeTime".$_."Minute"} = 0;
+                $Time{"TicketFreeTime".$_."Secunde"} = 0;
+
+                if ($GetParam{"TicketFreeTime".$_."Used"}) {
+                    %Time = $Self->{LayoutObject}->TransfromDateSelection(
+                        %GetParam,
+                        Prefix => "TicketFreeTime".$_,
+                    );
+                }
                 $Self->{TicketObject}->TicketFreeTimeSet(
                     %Time,
                     Prefix => "TicketFreeTime",
@@ -670,7 +716,7 @@ sub SendEmail {
             return $Self->{LayoutObject}->Redirect(OP => $Self->{LastScreenOverview});
         }
         else {
-            return $Self->{LayoutObject}->Redirect(OP => $Self->{LastScreenView});
+            return $Self->{LayoutObject}->Redirect(OP => "Action=AgentTicketZoom&TicketID=$Self->{TicketID}&ArticleID=$ArticleID");
         }
     }
     else {
@@ -748,26 +794,41 @@ sub _Mask {
         $Count++;
         if ($Self->{Config}->{'TicketFreeText'}->{$Count}) {
             $Self->{LayoutObject}->Block(
-                Name => 'FreeText',
+                Name => 'TicketFreeText',
                 Data => {
                     TicketFreeKeyField => $Param{'TicketFreeKeyField'.$Count},
                     TicketFreeTextField => $Param{'TicketFreeTextField'.$Count},
+                    %Param,
+                },
+            );
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketFreeText'.$Count,
+                Data => {
+                    %Param,
+                    Count => $Count,
                 },
             );
         }
     }
     $Count = 0;
-    foreach (1..2) {
+    foreach (1..6) {
         $Count++;
         if ($Self->{Config}->{'TicketFreeTime'}->{$Count}) {
             $Self->{LayoutObject}->Block(
-                Name => 'FreeTime',
+                Name => 'TicketFreeTime',
                 Data => {
                     TicketFreeTimeKey => $Self->{ConfigObject}->Get('TicketFreeTimeKey'.$Count),
                     TicketFreeTime => $Param{'TicketFreeTime'.$Count},
                     Count => $Count,
                 },
             );
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketFreeTime'.$Count,
+                Data => {
+                    %Param,
+                    Count => $Count,
+                },
+            );
         }
     }
     # show time accounting box
@@ -802,6 +863,18 @@ sub _Mask {
             Data => $DataRef,
         );
     }
+    # jscript check freetextfields by submit
+    foreach my $Key (keys %{$Self->{Config}->{TicketFreeText}}) {
+        if ($Self->{Config}->{TicketFreeText}->{$Key} == 2) {
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketFreeTextCheckJs',
+                Data => {
+                    TicketFreeTextField => "TicketFreeText$Key",
+                    TicketFreeKeyField => "TicketFreeKey$Key",
+                },
+            );
+        }
+    }
     # create & return output
     return $Self->{LayoutObject}->Output(TemplateFile => 'AgentTicketForward', Data => \%Param);
 }
