@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketPhoneOutbound.pm - to handle phone calls
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentTicketPhoneOutbound.pm,v 1.6.2.1 2007/01/17 13:04:42 mh Exp $
+# $Id: AgentTicketPhoneOutbound.pm,v 1.12 2007/03/14 12:55:00 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -20,7 +20,7 @@ use Kernel::System::State;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.6.2.1 $';
+$VERSION = '$Revision: 1.12 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -54,7 +54,6 @@ sub new {
     if (!$Self->{FormID}) {
         $Self->{FormID} = $Self->{UploadCachObject}->FormIDCreate();
     }
-
     $Self->{Config} = $Self->{ConfigObject}->Get("Ticket::Frontend::$Self->{Action}");
 
     return $Self;
@@ -86,7 +85,7 @@ sub Run {
             $Self->{TicketObject}->LockSet(
                 TicketID => $Self->{TicketID},
                 Lock => 'lock',
-                UserID => $Self->{UserID}
+                UserID => $Self->{UserID},
             );
             if ($Self->{TicketObject}->OwnerSet(
                 TicketID => $Self->{TicketID},
@@ -151,24 +150,30 @@ sub Run {
     }
     # get ticket free text params
     foreach (1..16) {
-        $GetParam{"TicketFreeKey$_"} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeKey$_");
-        $GetParam{"TicketFreeText$_"} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeText$_");
+        $GetParam{"TicketFreeKey$_"} = $Self->{ParamObject}->GetParam(Param => "TicketFreeKey$_");
+        $GetParam{"TicketFreeText$_"} = $Self->{ParamObject}->GetParam(Param => "TicketFreeText$_");
     }
-    # get ticket free text params
-    foreach (1..2) {
-        foreach my $Type (qw(Year Month Day Hour Minute)) {
-            $GetParam{"TicketFreeTime".$_.$Type} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+    # get ticket free time params
+    foreach (1..6) {
+        foreach my $Type (qw(Used Year Month Day Hour Minute)) {
+            $GetParam{"TicketFreeTime".$_.$Type} = $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+        }
+        if (!$Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_)) {
+            $GetParam{'TicketFreeTime'.$_.'Used'} = 1;
         }
     }
     # get article free text params
     foreach (1..3) {
-        $GetParam{"ArticleFreeKey$_"} =  $Self->{ParamObject}->GetParam(Param => "ArticleFreeKey$_");
-        $GetParam{"ArticleFreeText$_"} =  $Self->{ParamObject}->GetParam(Param => "ArticleFreeText$_");
+        $GetParam{"ArticleFreeKey$_"} = $Self->{ParamObject}->GetParam(Param => "ArticleFreeKey$_");
+        $GetParam{"ArticleFreeText$_"} = $Self->{ParamObject}->GetParam(Param => "ArticleFreeText$_");
     }
 
     if (!$Self->{Subaction}) {
         # check it it's a agent-customer ticket
-        if ($Self->{ConfigObject}->Get('Ticket::AgentCanBeCustomer') && $Ticket{CustomerUserID} && $Ticket{CustomerUserID} eq $Self->{UserLogin}) {
+        if ($Self->{ConfigObject}->Get('Ticket::AgentCanBeCustomer') &&
+            $Ticket{CustomerUserID} &&
+            $Ticket{CustomerUserID} eq $Self->{UserLogin}
+        ) {
             # redirect for agent follow up screen
             return $Self->{LayoutObject}->Redirect(
                 OP => "Action=AgentTicketCustomerFollowUp&TicketID=$Self->{TicketID}",
@@ -208,18 +213,28 @@ sub Run {
             Ticket => \%Ticket,
             Config => \%TicketFreeText,
         );
-        # get free text params
+        # free time
         my %TicketFreeTime = ();
-        foreach (1..2) {
+        foreach (1..6) {
+            $TicketFreeTime{"TicketFreeTime".$_.'Optional'} = $Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_) || 0;
+            $TicketFreeTime{"TicketFreeTime".$_.'Used'} = $GetParam{'TicketFreeTime'.$_.'Used'};
+
             if ($Ticket{"TicketFreeTime".$_}) {
-                ($TicketFreeTime{"TicketFreeTime".$_.'Secunde'}, $TicketFreeTime{"TicketFreeTime".$_.'Minute'}, $TicketFreeTime{"TicketFreeTime".$_.'Hour'}, $TicketFreeTime{"TicketFreeTime".$_.'Day'}, $TicketFreeTime{"TicketFreeTime".$_.'Month'},  $TicketFreeTime{"TicketFreeTime".$_.'Year'}) = $Self->{TimeObject}->SystemTime2Date(
+                (
+                    $TicketFreeTime{"TicketFreeTime".$_.'Secunde'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Minute'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Hour'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Day'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Month'},
+                    $TicketFreeTime{"TicketFreeTime".$_.'Year'}
+                ) = $Self->{TimeObject}->SystemTime2Date(
                     SystemTime => $Self->{TimeObject}->TimeStamp2SystemTime(
                         String => $Ticket{"TicketFreeTime".$_},
                     ),
                 );
+                $TicketFreeTime{"TicketFreeTime".$_.'Used'} = 1;
             }
         }
-        # free time
         my %TicketFreeTimeHTML = $Self->{LayoutObject}->AgentFreeDate(
             Ticket => \%TicketFreeTime,
         );
@@ -268,6 +283,12 @@ sub Run {
         if ($GetParam{Body}) {
             $GetParam{Body} =~ s/(^>.+|.{4,$Self->{ConfigObject}->Get('Ticket::Frontend::TextAreaNote')})(?:\s|\z)/$1\n/gm;
         }
+        # check required FreeTextField (if configured)
+        foreach (1..16) {
+            if ($Self->{Config}{'TicketFreeText'}{$_} == 2 && $GetParam{"TicketFreeText$_"} eq '' && !$GetParam{AttachmentUpload}) {
+                $Error{"TicketFreeTextField$_ invalid"} = 'invalid';
+            }
+        }
         # attachment delete
         foreach (1..10) {
             if ($GetParam{"AttachmentDelete$_"}) {
@@ -290,6 +311,10 @@ sub Run {
                 %UploadStuff,
             );
         }
+        # check subject
+        if (!$GetParam{Subject} && !$GetParam{AttachmentUpload}) {
+            $Error{"Subject invalid"} = 'invalid';
+        }
         # get all attachments meta data
         my @Attachments = $Self->{UploadCachObject}->FormIDGetAllFilesMeta(
             FormID => $Self->{FormID},
@@ -370,7 +395,7 @@ sub Run {
                 }
                 elsif ($Ticket{CustomerID}) {
                     %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
-                         CustomerID => $Ticket{CustomerID},
+                        CustomerID => $Ticket{CustomerID},
                     );
                 }
             }
@@ -387,6 +412,7 @@ sub Run {
                 %TicketFreeTextHTML,
                 %TicketFreeTimeHTML,
                 %ArticleFreeTextHTML,
+                Errors => \%Error,
             );
             $Output .= $Self->{LayoutObject}->Footer();
             return $Output;
@@ -449,14 +475,29 @@ sub Run {
                     }
                 }
                 # set ticket free time
-                foreach (1..2) {
+                foreach (1..6) {
                     if (defined($GetParam{"TicketFreeTime".$_."Year"}) &&
                         defined($GetParam{"TicketFreeTime".$_."Month"}) &&
                         defined($GetParam{"TicketFreeTime".$_."Day"}) &&
                         defined($GetParam{"TicketFreeTime".$_."Hour"}) &&
-                        defined($GetParam{"TicketFreeTime".$_."Minute"})) {
+                        defined($GetParam{"TicketFreeTime".$_."Minute"})
+                    ) {
+                        my %Time;
+                        $Time{"TicketFreeTime".$_."Year"} = 0;
+                        $Time{"TicketFreeTime".$_."Month"} = 0;
+                        $Time{"TicketFreeTime".$_."Day"} = 0;
+                        $Time{"TicketFreeTime".$_."Hour"} = 0;
+                        $Time{"TicketFreeTime".$_."Minute"} = 0;
+                        $Time{"TicketFreeTime".$_."Secunde"} = 0;
+
+                        if ($GetParam{"TicketFreeTime".$_."Used"}) {
+                            %Time = $Self->{LayoutObject}->TransfromDateSelection(
+                                %GetParam,
+                                Prefix => "TicketFreeTime".$_,
+                            );
+                        }
                         $Self->{TicketObject}->TicketFreeTimeSet(
-                            %GetParam,
+                            %Time,
                             Prefix => "TicketFreeTime",
                             TicketID => $Self->{TicketID},
                             Counter => $_,
@@ -694,13 +735,20 @@ sub _MaskPhone {
                 Data => {
                     TicketFreeKeyField => $Param{'TicketFreeKeyField'.$Count},
                     TicketFreeTextField => $Param{'TicketFreeTextField'.$Count},
+                    %Param,
+                },
+            );
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketFreeText'.$Count,
+                Data => {
+                    %Param,
+                    Count => $Count,
                 },
-                Count => $Count,
             );
         }
     }
     $Count = 0;
-    foreach (1..2) {
+    foreach (1..6) {
         $Count++;
         if ($Self->{Config}->{'TicketFreeTime'}->{$Count}) {
             $Self->{LayoutObject}->Block(
@@ -711,6 +759,13 @@ sub _MaskPhone {
                     Count => $Count,
                 },
             );
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketFreeTime'.$Count,
+                Data => {
+                    %Param,
+                    Count => $Count,
+                },
+            );
         }
     }
     # article free text
@@ -760,6 +815,18 @@ sub _MaskPhone {
             Data => $DataRef,
         );
     }
+    # jscript check freetextfields by submit
+    foreach my $Key (keys %{$Self->{Config}->{TicketFreeText}}) {
+        if ($Self->{Config}->{TicketFreeText}->{$Key} == 2) {
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketFreeTextCheckJs',
+                Data => {
+                    TicketFreeTextField => "TicketFreeText$Key",
+                    TicketFreeKeyField => "TicketFreeKey$Key",
+                },
+            );
+        }
+    }
     # get output back
     return $Self->{LayoutObject}->Output(TemplateFile => 'AgentTicketPhoneOutbound', Data => \%Param);
 }
