@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketZoom.pm - to get a closer view
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentTicketZoom.pm,v 1.30.2.3 2007/02/26 14:02:09 martin Exp $
+# $Id: AgentTicketZoom.pm,v 1.37 2007/03/16 10:08:48 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -16,7 +16,7 @@ use Kernel::System::CustomerUser;
 use Kernel::System::LinkObject;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.30.2.3 $';
+$VERSION = '$Revision: 1.37 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -31,8 +31,7 @@ sub new {
         $Self->{$_} = $Param{$_};
     }
     # check needed Opjects
-    foreach (qw(ParamObject DBObject TicketObject LayoutObject LogObject
-      QueueObject ConfigObject UserObject SessionObject)) {
+    foreach (qw(ParamObject DBObject TicketObject LayoutObject LogObject QueueObject ConfigObject UserObject SessionObject)) {
         if (!$Self->{$_}) {
             $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
         }
@@ -70,30 +69,22 @@ sub Run {
     my $Self = shift;
     my %Param = @_;
     my $Output;
-    # --
     # check needed stuff
-    # --
     if (!$Self->{TicketID}) {
         return $Self->{LayoutObject}->ErrorScreen(
             Message => "No TicketID is given!",
             Comment => 'Please contact the admin.',
         );
     }
-    # --
     # check permissions
-    # --
     if (!$Self->{TicketObject}->Permission(
         Type => 'ro',
         TicketID => $Self->{TicketID},
         UserID => $Self->{UserID})) {
-        # --
         # error screen, don't show ticket
-        # --
         return $Self->{LayoutObject}->NoPermission(WithHeader => 'yes');
     }
-    # --
     # store last screen
-    # --
     if ($Self->{Subaction} ne 'ShowHTMLeMail') {
         $Self->{SessionObject}->UpdateSessionID(
             SessionID => $Self->{SessionID},
@@ -104,9 +95,7 @@ sub Run {
     # get content
     my %Ticket = $Self->{TicketObject}->TicketGet(TicketID => $Self->{TicketID});
     my @ArticleBox = $Self->{TicketObject}->ArticleContentIndex(TicketID => $Self->{TicketID});
-    # --
     # return if HTML email
-    # --
     if ($Self->{Subaction} eq 'ShowHTMLeMail') {
         # check needed ArticleID
         if (!$Self->{ArticleID}) {
@@ -131,9 +120,7 @@ sub Run {
             Content => $Article{Body},
         );
     }
-    # --
     # else show normal ticket zoom view
-    # --
     # fetch all move queues
     my %MoveQueues = $Self->{TicketObject}->MoveList(
         TicketID => $Self->{TicketID},
@@ -157,14 +144,10 @@ sub Run {
             );
         }
     }
-    # --
     # generate output
-    # --
     $Output .= $Self->{LayoutObject}->Header(Value => $Ticket{TicketNumber});
     $Output .= $Self->{LayoutObject}->NavigationBar();
-    # --
     # show ticket
-    # --
     $Output .= $Self->MaskAgentZoom(
         MoveQueues => \%MoveQueues,
         StdResponses => \%StdResponses,
@@ -250,9 +233,7 @@ sub MaskAgentZoom {
             }
         }
     }
-    # --
     # build article stuff
-    # --
     my $BaseLink = $Self->{LayoutObject}->{Baselink}."TicketID=$Self->{TicketID}&";
     my @ArticleBox = @{$Param{ArticleBox}};
     # get selected or last customer article
@@ -273,58 +254,11 @@ sub MaskAgentZoom {
             }
         }
     }
-    # --
     # build thread string
-    # --
     my $Counter = '';
     my $Space = '';
     my $LastSenderType = '';
-    my $TicketOverTime = 0;
-    my $TicketOverTimeLong = 0;
-    my $TicketOverDate = 0;
-    foreach my $ArticleTmp (@ArticleBox) {
-      my %Article = %$ArticleTmp;
-      $TicketOverTime = $Article{TicketOverTime};
-      $TicketOverTimeLong = $Article{TicketOverTimeLong};
-      $TicketOverDate = $Article{TicketOverDate};
-    }
-    # --
-    # prepare escalation time (if needed)
-    # --
-    if ($TicketOverTime) {
-        # colloring
-        if ($TicketOverTimeLong <= -60*20) {
-            $Param{TicketOverTimeFont} = "<font color='$Self->{HighlightColor2}'>";
-            $Param{TicketOverTimeFontEnd} = '</font>';
-        }
-        elsif ($TicketOverTimeLong <= -60*40) {
-            $Param{TicketOverTimeFont} = "<font color='$Self->{HighlightColor1}'>";
-            $Param{TicketOverTimeFontEnd} = '</font>';
-        }
-
-        $Param{TicketOverTime} = $Self->{LayoutObject}->CustomerAge(
-            Age => $TicketOverTime,
-            Space => ' ',
-        );
-        $Param{TicketOverTimeLong} = $Self->{LayoutObject}->CustomerAge(
-            Age => $TicketOverTimeLong,
-            Space => ' ',
-        );
-        if ($Param{TicketOverTimeFont} && $Param{TicketOverTimeFontEnd}) {
-            $Param{TicketOverTime} = $Param{TicketOverTimeFont}.$Param{TicketOverTimeLong}.'<br>'.
-                '<div title="$Text{"Service Time"}: '.$Param{TicketOverTime}.'">$TimeShort{"'.$TicketOverDate.'"}</div>'.$Param{TicketOverTimeFontEnd};
-        }
-        else {
-            $Param{TicketOverTime} = $Param{TicketOverTimeLong}.'<br>'.
-                '<div title="$Text{"Service Time"}: '.$Param{TicketOverTime}.'">$TimeShort{"'.$TicketOverDate.'"}</div>';
-        }
-    }
-    else {
-        $Param{TicketOverTime} = '-';
-    }
-    # --
     # get shown article(s)
-    # --
     my @NewArticleBox = ();
     if (!$Self->{ZoomExpand}) {
         foreach my $ArticleTmp (@ArticleBox) {
@@ -346,9 +280,7 @@ sub MaskAgentZoom {
             }
         }
     }
-    # --
     # build shown article(s)
-    # --
     my $Count = 0;
     my $BodyOutput = '';
     foreach my $ArticleTmp (@NewArticleBox) {
@@ -362,7 +294,7 @@ sub MaskAgentZoom {
         else {
             # html quoting
             $Article{"BodyHTML"} = $Self->{LayoutObject}->Ascii2Html(
-                NewLine => $Self->{ConfigObject}->Get('DefaultViewNewLine') || 90,
+                NewLine => $Self->{ConfigObject}->Get('DefaultViewNewLine'),
                 Text => $Article{Body},
                 VMax => $Self->{ConfigObject}->Get('DefaultViewLines') || 5000,
                 HTMLResultMode => 1,
@@ -377,16 +309,111 @@ sub MaskAgentZoom {
             }
         }
         $Self->{LayoutObject}->Block(
-             Name => 'Body',
-             Data => {%Param, %Article, Body => $Article{"BodyHTML"}, %AclAction},
+            Name => 'Body',
+            Data => {%Param, %Article, Body => $Article{"BodyHTML"}, %AclAction},
         );
         # show article tree
         if ($Count == 1) {
             # show status info
             $Self->{LayoutObject}->Block(
-                 Name => 'Status',
-                 Data => {%Param, %AclAction},
+                Name => 'Status',
+                Data => {%Param, %AclAction},
             );
+            # ticket type
+            if ($Self->{ConfigObject}->Get('Ticket::Type')) {
+                $Self->{LayoutObject}->Block(
+                    Name => 'Type',
+                    Data => {%Param, %AclAction},
+                );
+            }
+            # ticket service
+            if ($Self->{ConfigObject}->Get('Ticket::Service') && $Param{Service}) {
+                $Self->{LayoutObject}->Block(
+                    Name => 'Service',
+                    Data => {%Param, %AclAction},
+                );
+                if ($Param{SLA}) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'SLA',
+                        Data => {%Param, %AclAction},
+                    );
+                }
+            }
+            # show first response time if needed
+            if (defined($Param{FirstResponseTime})) {
+                $Param{FirstResponseTimeHuman} = $Self->{LayoutObject}->CustomerAgeInHours(
+                    Age => $Param{'FirstResponseTime'},
+                    Space => ' ',
+                );
+                $Param{FirstResponseTimeWorkingTime} = $Self->{LayoutObject}->CustomerAgeInHours(
+                    Age => $Param{'FirstResponseTimeWorkingTime'},
+                    Space => ' ',
+                );
+                $Self->{LayoutObject}->Block(
+                    Name => 'FirstResponseTime',
+                    Data => {%Param, %AclAction},
+                );
+                if (60*60*1 > $Param{FirstResponseTime}) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'FirstResponseTimeFontStart',
+                        Data => {%Param, %AclAction},
+                    );
+                    $Self->{LayoutObject}->Block(
+                        Name => 'FirstResponseTimeFontStop',
+                        Data => {%Param, %AclAction},
+                    );
+                }
+            }
+            # show update time if needed
+            if (defined($Param{UpdateTime})) {
+                $Param{UpdateTimeHuman} = $Self->{LayoutObject}->CustomerAgeInHours(
+                    Age => $Param{'UpdateTime'},
+                    Space => ' ',
+                );
+                $Param{UpdateTimeWorkingTime} = $Self->{LayoutObject}->CustomerAgeInHours(
+                    Age => $Param{'UpdateTimeWorkingTime'},
+                    Space => ' ',
+                );
+                $Self->{LayoutObject}->Block(
+                    Name => 'UpdateTime',
+                    Data => {%Param, %AclAction},
+                );
+                if (60*60*1 > $Param{UpdateTime}) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'UpdateTimeFontStart',
+                        Data => {%Param, %AclAction},
+                    );
+                    $Self->{LayoutObject}->Block(
+                        Name => 'UpdateTimeFontStop',
+                        Data => {%Param, %AclAction},
+                    );
+                }
+            }
+            # show solution time if needed
+            if (defined($Param{SolutionTime})) {
+                $Param{SolutionTimeHuman} = $Self->{LayoutObject}->CustomerAgeInHours(
+                    Age => $Param{'SolutionTime'},
+                    Space => ' ',
+                );
+                $Param{SolutionTimeWorkingTime} = $Self->{LayoutObject}->CustomerAgeInHours(
+                    Age => $Param{'SolutionTimeWorkingTime'},
+                    Space => ' ',
+                );
+                $Self->{LayoutObject}->Block(
+                    Name => 'SolutionTime',
+                    Data => {%Param, %AclAction},
+                );
+                if (60*60*1 > $Param{SolutionTime}) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'SolutionTimeFontStart',
+                        Data => {%Param, %AclAction},
+                    );
+                    $Self->{LayoutObject}->Block(
+                        Name => 'SolutionTimeFontStop',
+                        Data => {%Param, %AclAction},
+                    );
+                }
+            }
             # customer info string
             if ($Self->{ConfigObject}->Get('Ticket::Frontend::CustomerInfoZoom')) {
                 $Param{CustomerTable} = $Self->{LayoutObject}->AgentCustomerViewTable(
@@ -402,13 +429,13 @@ sub MaskAgentZoom {
                 );
             }
             $Self->{LayoutObject}->Block(
-                 Name => 'Owner',
-                 Data => {%Param, %UserInfo, %AclAction},
+                Name => 'Owner',
+                Data => {%Param, %UserInfo, %AclAction},
             );
             if ($Self->{ConfigObject}->Get('Ticket::Responsible')) {
                 $Self->{LayoutObject}->Block(
-                     Name => 'Responsible',
-                     Data => {%Param, %ResponsibleInfo, %AclAction},
+                    Name => 'Responsible',
+                    Data => {%Param, %ResponsibleInfo, %AclAction},
                 );
             }
             # get linked objects
@@ -429,11 +456,11 @@ sub MaskAgentZoom {
                     }
                 }
             }
-            $Self->{LayoutObject}->Block(
-                 Name => 'Tree',
-                 Data => {%Param, %Article, %AclAction},
-            );
             # build thread string
+            $Self->{LayoutObject}->Block(
+                Name => 'Tree',
+                Data => {%Param, %Article, %AclAction},
+            );
             my $CounterTree = 0;
             my $Counter = '';
             my $Space = '';
@@ -572,12 +599,12 @@ sub MaskAgentZoom {
                     my @Data = $Object->Check(Article=> \%Article, %Param, Config => $Jobs{$Job});
                     foreach my $DataRef (@Data) {
                         $Self->{LayoutObject}->Block(
-                             Name => 'ArticleOption',
-                             Data => $DataRef,
+                            Name => 'ArticleOption',
+                            Data => $DataRef,
                         );
                     }
                     # filter option
-                    $Object->Filter(Article=> \%Article, %Param, Config => $Jobs{$Job});
+                    $Object->Filter(Article => \%Article, %Param, Config => $Jobs{$Job});
                 }
                 else {
                     return $Self->{LayoutObject}->ErrorScreen();
@@ -612,8 +639,8 @@ sub MaskAgentZoom {
                     %File,
                 },
             );
-             # run article attachment modules
-             if (ref($Self->{ConfigObject}->Get('Ticket::Frontend::ArticleAttachmentModule')) eq 'HASH') {
+            # run article attachment modules
+            if (ref($Self->{ConfigObject}->Get('Ticket::Frontend::ArticleAttachmentModule')) eq 'HASH') {
                 my %Jobs = %{$Self->{ConfigObject}->Get('Ticket::Frontend::ArticleAttachmentModule')};
                 foreach my $Job (sort keys %Jobs) {
                     # load module
@@ -642,7 +669,7 @@ sub MaskAgentZoom {
                         return $Self->{LayoutObject}->ErrorScreen();
                     }
                 }
-             }
+            }
         }
 
         # select the output template
@@ -678,39 +705,144 @@ sub MaskAgentZoom {
                     Name => 'AgentAnswer',
                     Data => {%Param, %Article, %AclAction},
                 );
+                # check if compose link should be shown
                 if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketCompose} &&
                     (!defined($AclAction{AgentTicketCompose}) || $AclAction{AgentTicketCompose})) {
-                    $Self->{LayoutObject}->Block(
-                        Name => 'AgentAnswerCompose',
-                        Data => {%Param, %Article, %AclAction},
-                    );
+                    my $Access = 1;
+                    my $Config = $Self->{ConfigObject}->Get("Ticket::Frontend::AgentTicketCompose");
+                    if ($Config->{Permission}) {
+                        if (!$Self->{TicketObject}->Permission(
+                            Type => $Config->{Permission},
+                            TicketID => $Param{TicketID},
+                            UserID => $Self->{UserID},
+                            LogNo => 1,
+                        )) {
+                            $Access = 0;
+                        }
+                    }
+                    if ($Config->{RequiredLock}) {
+                        if ($Self->{TicketObject}->LockIsTicketLocked(TicketID => $Param{TicketID})) {
+                            my $AccessOk = $Self->{TicketObject}->OwnerCheck(
+                                TicketID => $Param{TicketID},
+                                OwnerID => $Self->{UserID},
+                            );
+                            if (!$AccessOk) {
+                                $Access = 0;
+                            }
+                        }
+                    }
+                    if ($Access) {
+                        $Self->{LayoutObject}->Block(
+                            Name => 'AgentAnswerCompose',
+                            Data => {%Param, %Article, %AclAction},
+                        );
+                    }
                 }
+                # check if phone link should be shown
                 if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketPhoneOutbound} &&
                     (!defined($AclAction{AgentTicketPhoneOutbound}) || $AclAction{AgentTicketPhoneOutbound})) {
-                    $Self->{LayoutObject}->Block(
-                        Name => 'AgentAnswerPhoneOutbound',
-                        Data => {%Param, %Article, %AclAction},
-                    );
+                    my $Access = 1;
+                    my $Config = $Self->{ConfigObject}->Get("Ticket::Frontend::AgentTicketPhoneOutbound");
+                    if ($Config->{Permission}) {
+                        if (!$Self->{TicketObject}->Permission(
+                            Type => $Config->{Permission},
+                            TicketID => $Param{TicketID},
+                            UserID => $Self->{UserID},
+                            LogNo => 1,
+                        )) {
+                            $Access = 0;
+                        }
+                    }
+                    if ($Config->{RequiredLock}) {
+                        if ($Self->{TicketObject}->LockIsTicketLocked(TicketID => $Param{TicketID})) {
+                            my $AccessOk = $Self->{TicketObject}->OwnerCheck(
+                                TicketID => $Param{TicketID},
+                                OwnerID => $Self->{UserID},
+                            );
+                            if (!$AccessOk) {
+                                $Access = 0;
+                            }
+                        }
+                    }
+                    if ($Access) {
+                        $Self->{LayoutObject}->Block(
+                            Name => 'AgentAnswerPhoneOutbound',
+                            Data => {%Param, %Article, %AclAction},
+                        );
+                    }
                 }
             }
             $Self->{LayoutObject}->Block(
                 Name => 'AgentArticleCom',
                 Data => {%Param, %Article, %AclAction},
             );
+            # check if forward link should be shown
             if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketForward} &&
                 (!defined($AclAction{AgentTicketForward}) || $AclAction{AgentTicketForward})) {
-                $Self->{LayoutObject}->Block(
-                    Name => 'AgentArticleComForward',
-                    Data => {%Param, %Article, %AclAction},
-                );
+                my $Access = 1;
+                my $Config = $Self->{ConfigObject}->Get("Ticket::Frontend::AgentTicketForward");
+                if ($Config->{Permission}) {
+                    if (!$Self->{TicketObject}->Permission(
+                        Type => $Config->{Permission},
+                        TicketID => $Param{TicketID},
+                        UserID => $Self->{UserID},
+                        LogNo => 1,
+                    )) {
+                        $Access = 0;
+                    }
+                }
+                if ($Config->{RequiredLock}) {
+                    if ($Self->{TicketObject}->LockIsTicketLocked(TicketID => $Param{TicketID})) {
+                        my $AccessOk = $Self->{TicketObject}->OwnerCheck(
+                            TicketID => $Param{TicketID},
+                            OwnerID => $Self->{UserID},
+                        );
+                        if (!$AccessOk) {
+                            $Access = 0;
+                        }
+                    }
+                }
+                if ($Access) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'AgentArticleComForward',
+                        Data => {%Param, %Article, %AclAction},
+                    );
+                }
             }
+            # check if bounce link should be shown
             if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketBounce} &&
                 (!defined($AclAction{AgentTicketBounce}) || $AclAction{AgentTicketBounce})) {
-                $Self->{LayoutObject}->Block(
-                    Name => 'AgentArticleComBounce',
-                    Data => {%Param, %Article, %AclAction},
-                );
+                my $Access = 1;
+                my $Config = $Self->{ConfigObject}->Get("Ticket::Frontend::AgentTicketBounce");
+                if ($Config->{Permission}) {
+                    if (!$Self->{TicketObject}->Permission(
+                        Type => $Config->{Permission},
+                        TicketID => $Param{TicketID},
+                        UserID => $Self->{UserID},
+                        LogNo => 1,
+                    )) {
+                        $Access = 0;
+                    }
+                }
+                if ($Config->{RequiredLock}) {
+                    if ($Self->{TicketObject}->LockIsTicketLocked(TicketID => $Param{TicketID})) {
+                        my $AccessOk = $Self->{TicketObject}->OwnerCheck(
+                            TicketID => $Param{TicketID},
+                            OwnerID => $Self->{UserID},
+                        );
+                        if (!$AccessOk) {
+                            $Access = 0;
+                        }
+                    }
+                }
+                if ($Access) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'AgentArticleComBounce',
+                        Data => {%Param, %Article, %AclAction},
+                    );
+                }
             }
+            # check if split link should be shown
             if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketPhone} &&
                 (!defined($AclAction{AgentTicketPhone}) || $AclAction{AgentTicketPhone})) {
                 $Self->{LayoutObject}->Block(
@@ -730,10 +862,17 @@ sub MaskAgentZoom {
     }
     if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketMove} &&
         (!defined($AclAction{AgentTicketMove}) || $AclAction{AgentTicketMove})) {
-        $Self->{LayoutObject}->Block(
-            Name => 'Move',
-            Data => {%Param, %AclAction},
-        );
+        if ($Self->{TicketObject}->Permission(
+            Type => 'move',
+            TicketID => $Param{TicketID},
+            UserID => $Self->{UserID},
+            LogNo => 1,
+            )) {
+            $Self->{LayoutObject}->Block(
+                Name => 'Move',
+                Data => {%Param, %AclAction},
+            );
+        }
     }
     $Self->{LayoutObject}->Block(
         Name => 'Footer',
