@@ -2,7 +2,7 @@
 # Kernel/Modules/CustomerTicketMessage.pm - to handle customer messages
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: CustomerTicketMessage.pm,v 1.12.2.1 2007/01/17 13:04:42 mh Exp $
+# $Id: CustomerTicketMessage.pm,v 1.24 2007/06/18 09:33:57 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -18,7 +18,7 @@ use Kernel::System::Queue;
 use Kernel::System::State;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.12.2.1 $';
+$VERSION = '$Revision: 1.24 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -32,8 +32,7 @@ sub new {
         $Self->{$_} = $Param{$_};
     }
     # check needed Opjects
-    foreach (qw(ParamObject DBObject TicketObject LayoutObject LogObject QueueObject
-       ConfigObject)) {
+    foreach (qw(ParamObject DBObject TicketObject LayoutObject LogObject QueueObject ConfigObject)) {
         if (!$Self->{$_}) {
             $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
         }
@@ -62,7 +61,7 @@ sub Run {
     # get params
     my %GetParam = ();
     foreach (qw(
-        Subject Body PriorityID
+        Subject Body PriorityID TypeID ServiceID SLAID Expand
         AttachmentUpload
         AttachmentDelete1 AttachmentDelete2 AttachmentDelete3 AttachmentDelete4
         AttachmentDelete5 AttachmentDelete6 AttachmentDelete7 AttachmentDelete8
@@ -97,15 +96,19 @@ sub Run {
             Config => \%TicketFreeText,
             Ticket => { %TicketFreeDefault },
         );
-        # get free text params
+        # get ticket free time params
         my %TicketFreeTime = ();
-        foreach (1..2) {
-            foreach my $Type (qw(Year Month Day Hour Minute)) {
-                $TicketFreeTime{"TicketFreeTime".$_.$Type} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+        foreach (1..6) {
+            foreach my $Type (qw(Used Year Month Day Hour Minute)) {
+                $TicketFreeTime{"TicketFreeTime".$_.$Type} = $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+            }
+            $TicketFreeTime{'TicketFreeTime'.$_.'Optional'} = $Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_) || 0;
+            if (!$Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_)) {
+                $TicketFreeTime{'TicketFreeTime'.$_.'Used'} = 1;
             }
         }
         # free time
-        my %FreeTime = $Self->{LayoutObject}->AgentFreeDate(
+        my %FreeTime = $Self->{LayoutObject}->CustomerFreeDate(
             %Param,
             Ticket => \%TicketFreeTime,
         );
@@ -114,8 +117,8 @@ sub Run {
         my $Output .= $Self->{LayoutObject}->CustomerHeader();
         $Output .= $Self->{LayoutObject}->CustomerNavigationBar();
         $Output .= $Self->_MaskNew(
-              %TicketFreeTextHTML,
-              %FreeTime,
+            %TicketFreeTextHTML,
+            %FreeTime,
         );
         $Output .= $Self->{LayoutObject}->CustomerFooter();
         return $Output;
@@ -127,8 +130,8 @@ sub Run {
         my $Dest = $Self->{ParamObject}->GetParam(Param => 'Dest') || '';
         my ($NewQueueID, $To) = split(/\|\|/, $Dest);
         if (!$To) {
-          $NewQueueID = $Self->{ParamObject}->GetParam(Param => 'NewQueueID') || '';
-          $To = 'System';
+            $NewQueueID = $Self->{ParamObject}->GetParam(Param => 'NewQueueID') || '';
+            $To = 'System';
         }
         # fallback, if no dest is given
         if (!$NewQueueID) {
@@ -141,8 +144,8 @@ sub Run {
         }
         my %TicketFree = ();
         foreach (1..16) {
-            $TicketFree{"TicketFreeKey$_"} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeKey$_");
-            $TicketFree{"TicketFreeText$_"} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeText$_");
+            $TicketFree{"TicketFreeKey$_"} = $Self->{ParamObject}->GetParam(Param => "TicketFreeKey$_");
+            $TicketFree{"TicketFreeText$_"} = $Self->{ParamObject}->GetParam(Param => "TicketFreeText$_");
         }
         # get free text config options
         my %TicketFreeText = ();
@@ -159,16 +162,24 @@ sub Run {
                 Type => "TicketFreeText$_",
                 CustomerUserID => $Self->{UserID},
             );
+            # check required FreeTextField (if configured)
+            if ($Self->{Config}{'TicketFreeText'}{$_} == 2 && $TicketFree{"TicketFreeText$_"} eq '') {
+                $Error{"TicketFreeTextField$_ invalid"} = '* invalid';
+            }
         }
         my %TicketFreeTextHTML = $Self->{LayoutObject}->AgentFreeText(
             Config => \%TicketFreeText,
             Ticket => { %TicketFree },
         );
-        # get free text params
+        # get ticket free time params
         my %TicketFreeTime = ();
-        foreach (1..2) {
-            foreach my $Type (qw(Year Month Day Hour Minute)) {
-                $TicketFreeTime{"TicketFreeTime".$_.$Type} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+        foreach (1..6) {
+            foreach my $Type (qw(Used Year Month Day Hour Minute)) {
+                $TicketFreeTime{"TicketFreeTime".$_.$Type} = $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
+            }
+            $TicketFreeTime{'TicketFreeTime'.$_.'Optional'} = $Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_) || 0;
+            if (!$Self->{ConfigObject}->Get('TicketFreeTimeOptional'.$_)) {
+                $TicketFreeTime{'TicketFreeTime'.$_.'Used'} = 1;
             }
         }
         # free time
@@ -206,6 +217,10 @@ sub Run {
         my @Attachments = $Self->{UploadCachObject}->FormIDGetAllFilesMeta(
             FormID => $Self->{FormID},
         );
+        # check queue
+        if (!$NewQueueID) {
+            $Error{"Queue invalid"} = '* invalid';
+        }
         # check subject
         if (!$GetParam{Subject}) {
             $Error{"Subject invalid"} = '* invalid';
@@ -214,6 +229,10 @@ sub Run {
         if (!$GetParam{Body}) {
             $Error{"Body invalid"} = '* invalid';
         }
+        if ($GetParam{Expand}) {
+            %Error = ();
+            $Error{"Expand"} = 1;
+        }
         if (%Error) {
             # html output
             my $Output .= $Self->{LayoutObject}->CustomerHeader();
@@ -222,8 +241,10 @@ sub Run {
                 Attachments => \@Attachments,
                 %GetParam,
                 ToSelected => $Dest,
+                QueueID => $NewQueueID,
                 %TicketFreeTextHTML,
                 %FreeTime,
+                Errors => \%Error,
             );
             $Output .= $Self->{LayoutObject}->CustomerFooter();
             return $Output;
@@ -236,12 +257,15 @@ sub Run {
         # create new ticket, do db insert
         my $TicketID = $Self->{TicketObject}->TicketCreate(
             QueueID => $NewQueueID,
+            TypeID => $GetParam{TypeID} || '',
+            ServiceID => $GetParam{ServiceID} || '',
+            SLAID => $GetParam{SLAID} || '',
             Title => $GetParam{Subject},
             PriorityID => $GetParam{PriorityID} || '',
             Priority => $GetParam{Priority} || '',
             Lock => 'unlock',
             State => $Self->{Config}->{StateDefault},
-            CustomerNo => $Self->{UserCustomerID},
+            CustomerID => $Self->{UserCustomerID},
             CustomerUser => $Self->{UserLogin},
             OwnerID => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
             UserID => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
@@ -258,28 +282,36 @@ sub Run {
                 );
             }
         }
-        # get free text params
-        %TicketFreeTime = ();
-        foreach (1..2) {
-              foreach my $Type (qw(Year Month Day Hour Minute)) {
-                  $TicketFreeTime{"TicketFreeTime".$_.$Type} =  $Self->{ParamObject}->GetParam(Param => "TicketFreeTime".$_.$Type);
-              }
-        }
         # set ticket free time
-        foreach (1..2) {
-              if (defined($TicketFreeTime{"TicketFreeTime".$_."Year"}) &&
-                  defined($TicketFreeTime{"TicketFreeTime".$_."Month"}) &&
-                  defined($TicketFreeTime{"TicketFreeTime".$_."Day"}) &&
-                  defined($TicketFreeTime{"TicketFreeTime".$_."Hour"}) &&
-                  defined($TicketFreeTime{"TicketFreeTime".$_."Minute"})) {
-                  $Self->{TicketObject}->TicketFreeTimeSet(
-                      %TicketFreeTime,
-                      Prefix => "TicketFreeTime",
-                      TicketID => $TicketID,
-                      Counter => $_,
-                      UserID => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
-                  );
-              }
+        foreach (1..6) {
+            if (defined($TicketFreeTime{"TicketFreeTime".$_."Year"}) &&
+                defined($TicketFreeTime{"TicketFreeTime".$_."Month"}) &&
+                defined($TicketFreeTime{"TicketFreeTime".$_."Day"}) &&
+                defined($TicketFreeTime{"TicketFreeTime".$_."Hour"}) &&
+                defined($TicketFreeTime{"TicketFreeTime".$_."Minute"})
+            ) {
+                my %Time;
+                $Time{"TicketFreeTime".$_."Year"} = 0;
+                $Time{"TicketFreeTime".$_."Month"} = 0;
+                $Time{"TicketFreeTime".$_."Day"} = 0;
+                $Time{"TicketFreeTime".$_."Hour"} = 0;
+                $Time{"TicketFreeTime".$_."Minute"} = 0;
+                $Time{"TicketFreeTime".$_."Secunde"} = 0;
+
+                if ($TicketFreeTime{"TicketFreeTime".$_."Used"}) {
+                    %Time = $Self->{LayoutObject}->TransfromDateSelection(
+                        %TicketFreeTime,
+                        Prefix => "TicketFreeTime".$_,
+                    );
+                }
+                $Self->{TicketObject}->TicketFreeTimeSet(
+                    %Time,
+                    Prefix => "TicketFreeTime",
+                    TicketID => $TicketID,
+                    Counter => $_,
+                    UserID => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
+                );
+            }
         }
         # create article
         my $From = "$Self->{UserFirstname} $Self->{UserLastname} <$Self->{UserEmail}>";
@@ -304,42 +336,42 @@ sub Run {
             },
             Queue => $Self->{QueueObject}->QueueLookup(QueueID => $NewQueueID),
         )) {
-          # get pre loaded attachment
-          my @AttachmentData = $Self->{UploadCachObject}->FormIDGetAllFilesData(
-              FormID => $Self->{FormID},
-          );
-          foreach my $Ref (@AttachmentData) {
-              $Self->{TicketObject}->ArticleWriteAttachment(
-                  %{$Ref},
-                  ArticleID => $ArticleID,
-                  UserID => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
-              );
-          }
-          # get submit attachment
-          my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
-              Param => 'file_upload',
-              Source => 'String',
-          );
-          if (%UploadStuff) {
-              $Self->{TicketObject}->ArticleWriteAttachment(
-                  %UploadStuff,
-                  ArticleID => $ArticleID,
-                  UserID => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
-              );
-          }
-          # remove pre submited attachments
-          $Self->{UploadCachObject}->FormIDRemove(FormID => $Self->{FormID});
-          # redirect
-          return $Self->{LayoutObject}->Redirect(
-              OP => "Action=$NextScreen&TicketID=$TicketID",
-          );
-      }
-      else {
-          my $Output = $Self->{LayoutObject}->CustomerHeader(Title => 'Error');
-          $Output .= $Self->{LayoutObject}->CustomerError();
-          $Output .= $Self->{LayoutObject}->CustomerFooter();
-          return $Output;
-      }
+            # get pre loaded attachment
+            my @AttachmentData = $Self->{UploadCachObject}->FormIDGetAllFilesData(
+                FormID => $Self->{FormID},
+            );
+            foreach my $Ref (@AttachmentData) {
+                $Self->{TicketObject}->ArticleWriteAttachment(
+                    %{$Ref},
+                    ArticleID => $ArticleID,
+                    UserID => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
+                );
+            }
+            # get submit attachment
+            my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
+                Param => 'file_upload',
+                Source => 'String',
+            );
+            if (%UploadStuff) {
+                $Self->{TicketObject}->ArticleWriteAttachment(
+                    %UploadStuff,
+                    ArticleID => $ArticleID,
+                    UserID => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
+                );
+            }
+            # remove pre submited attachments
+            $Self->{UploadCachObject}->FormIDRemove(FormID => $Self->{FormID});
+            # redirect
+            return $Self->{LayoutObject}->Redirect(
+                OP => "Action=$NextScreen&TicketID=$TicketID",
+            );
+        }
+        else {
+            my $Output = $Self->{LayoutObject}->CustomerHeader(Title => 'Error');
+            $Output .= $Self->{LayoutObject}->CustomerError();
+            $Output .= $Self->{LayoutObject}->CustomerFooter();
+            return $Output;
+        }
     }
     else {
         my $Output = $Self->{LayoutObject}->CustomerHeader(Title => 'Error');
@@ -356,8 +388,13 @@ sub _MaskNew {
     my $Self = shift;
     my %Param = @_;
     $Param{FormID} = $Self->{FormID};
+    # get list type
+    my $TreeView = 0;
+    if ($Self->{ConfigObject}->Get('Ticket::Frontend::ListType') eq 'tree') {
+        $TreeView = 1;
+    }
     # check own selection
-    my %NewTos = ();
+    my %NewTos = ('', '-');
     my $Module = $Self->{ConfigObject}->Get('CustomerPanel::NewTicketQueueSelectionModule') || 'Kernel::Output::HTML::CustomerNewTicketQueueSelectionGeneric';
     if ($Self->{MainObject}->Require($Module)) {
         my $Object = $Module->new(
@@ -371,7 +408,7 @@ sub _MaskNew {
                 Message => "Module: $Module loaded!",
             );
         }
-        %NewTos = $Object->Run(Env => $Self);
+        %NewTos = ($Object->Run(Env => $Self), ('', => '-'));
     }
     else {
         return $Self->{LayoutObject}->FatalError();
@@ -379,8 +416,8 @@ sub _MaskNew {
     # build to string
     if (%NewTos) {
         foreach (keys %NewTos) {
-             $NewTos{"$_||$NewTos{$_}"} = $NewTos{$_};
-             delete $NewTos{$_};
+            $NewTos{"$_||$NewTos{$_}"} = $NewTos{$_};
+            delete $NewTos{$_};
         }
     }
     $Param{'ToStrg'} = $Self->{LayoutObject}->AgentQueueListOption(
@@ -389,7 +426,7 @@ sub _MaskNew {
         Size => 0,
         Name => 'Dest',
         SelectedID => $Param{ToSelected},
-        OnChangeSubmit => 0,
+        OnChange => "document.compose.Expand.value='3'; document.compose.submit(); return false;",
     );
     # get priority
     if ($Self->{Config}->{Priority}) {
@@ -417,6 +454,80 @@ sub _MaskNew {
             },
         );
     }
+    # types
+    if ($Self->{ConfigObject}->Get('Ticket::Type')) {
+        my %Type = $Self->{TicketObject}->TicketTypeList(
+            %Param,
+            Action => $Self->{Action},
+            CustomerUserID => $Self->{UserID},
+        );
+        $Param{'TypeStrg'} = $Self->{LayoutObject}->BuildSelection(
+            Data => \%Type,
+            Name => 'TypeID',
+            SelectedID => $Param{TypeID},
+            PossibleNone => 1,
+            Sort => 'AlphanumericValue',
+            Translation => 0,
+            OnChange => "document.compose.Expand.value='3'; document.compose.submit(); return false;",
+        );
+        $Self->{LayoutObject}->Block(
+            Name => 'TicketType',
+            Data => {%Param},
+        );
+    }
+    # services
+    if ($Self->{ConfigObject}->Get('Ticket::Service')) {
+        my %Service = ();
+        if ($Param{QueueID} || $Param{TicketID}) {
+            %Service = $Self->{TicketObject}->TicketServiceList(
+                %Param,
+                Action => $Self->{Action},
+                CustomerUserID => $Self->{UserID},
+                UserID => $Self->{ConfigObject}->Get('CustomerPanelUserID'),
+            );
+        }
+        $Param{'ServiceStrg'} = $Self->{LayoutObject}->BuildSelection(
+            Data => \%Service,
+            Name => 'ServiceID',
+            SelectedID => $Param{ServiceID},
+            PossibleNone => 1,
+            TreeView => $TreeView,
+            Sort => 'TreeView',
+            Translation => 0,
+            OnChange => "document.compose.Expand.value='3'; document.compose.submit(); return false;",
+        );
+        $Self->{LayoutObject}->Block(
+            Name => 'TicketService',
+            Data => {%Param},
+        );
+        my %SLA = ();
+        if ($Param{ServiceID}) {
+            %SLA = $Self->{TicketObject}->TicketSLAList(
+                %Param,
+                Action => $Self->{Action},
+                CustomerUserID => $Self->{UserID},
+            );
+        }
+        $Param{'SLAStrg'} = $Self->{LayoutObject}->BuildSelection(
+            Data => \%SLA,
+            Name => 'SLAID',
+            SelectedID => $Param{SLAID},
+            PossibleNone => 1,
+            Sort => 'AlphanumericValue',
+            Translation => 0,
+            OnChange => "document.compose.Expand.value='3'; document.compose.submit(); return false;",
+        );
+        $Self->{LayoutObject}->Block(
+            Name => 'TicketSLA',
+            Data => {%Param},
+        );
+    }
+    # prepare errors!
+    if ($Param{Errors}) {
+        foreach (keys %{$Param{Errors}}) {
+            $Param{$_} = $Self->{LayoutObject}->Ascii2Html(Text => $Param{Errors}->{$_});
+        }
+    }
 
     # ticket free text
     my $Count = 0;
@@ -428,12 +539,21 @@ sub _MaskNew {
                 Data => {
                     TicketFreeKeyField => $Param{'TicketFreeKeyField'.$Count},
                     TicketFreeTextField => $Param{'TicketFreeTextField'.$Count},
+                    Count => $Count,
+                    %Param,
+                },
+            );
+            $Self->{LayoutObject}->Block(
+                Name => 'FreeText'.$Count,
+                Data => {
+                    %Param,
+                    Count => $Count,
                 },
             );
         }
     }
     $Count = 0;
-    foreach (1..2) {
+    foreach (1..6) {
         $Count++;
         if ($Self->{Config}->{'TicketFreeTime'}->{$Count}) {
             $Self->{LayoutObject}->Block(
@@ -444,6 +564,13 @@ sub _MaskNew {
                     Count => $Count,
                 },
             );
+            $Self->{LayoutObject}->Block(
+                Name => 'FreeTime'.$Count,
+                Data => {
+                    %Param,
+                    Count => $Count,
+                },
+            );
         }
     }
     # show attachments
@@ -453,6 +580,18 @@ sub _MaskNew {
             Data => $DataRef,
         );
     }
+    # jscript check freetextfields by submit
+    foreach my $Key (keys %{$Self->{Config}->{TicketFreeText}}) {
+        if ($Self->{Config}->{TicketFreeText}->{$Key} == 2) {
+            $Self->{LayoutObject}->Block(
+                Name => 'TicketFreeTextCheckJs',
+                Data => {
+                    TicketFreeTextField => "TicketFreeText$Key",
+                    TicketFreeKeyField => "TicketFreeKey$Key",
+                },
+            );
+        }
+    }
     # get output back
     return $Self->{LayoutObject}->Output(TemplateFile => 'CustomerTicketMessage', Data => \%Param);
 }
