@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/CustomerTicketSearch.pm - Utilities for tickets
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: CustomerTicketSearch.pm,v 1.22 2006/11/15 07:28:38 martin Exp $
+# $Id: CustomerTicketSearch.pm,v 1.27 2007/05/02 14:03:34 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::State;
 use Kernel::System::SearchProfile;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.22 $';
+$VERSION = '$Revision: 1.27 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -59,8 +59,10 @@ sub Run {
     $Self->{StartHit} = $Self->{ParamObject}->GetParam(Param => 'StartHit') || 1;
     $Self->{SearchLimit} = $Self->{ConfigObject}->Get('Ticket::CustomerTicketSearch::SearchLimit') || 200;
     $Self->{SearchPageShown} = $Self->{ConfigObject}->Get('Ticket::CustomerTicketSearch::SearchPageShown') || 40;
-    $Self->{SortBy} = $Self->{ParamObject}->GetParam(Param => 'SortBy') || $Self->{ConfigObject}->Get('Ticket::CustomerTicketSearch::SortBy::Default') || 'Age';
-    $Self->{Order} = $Self->{ParamObject}->GetParam(Param => 'Order') || $Self->{ConfigObject}->Get('Ticket::CustomerTicketSearch::Order::Default') || 'Down';
+    $Self->{SortBy} = $Self->{ParamObject}->GetParam(Param => 'SortBy') ||
+        $Self->{ConfigObject}->Get('Ticket::CustomerTicketSearch::SortBy::Default') || 'Age';
+    $Self->{Order} = $Self->{ParamObject}->GetParam(Param => 'Order') ||
+        $Self->{ConfigObject}->Get('Ticket::CustomerTicketSearch::Order::Default') || 'Down';
     $Self->{Profile} = $Self->{ParamObject}->GetParam(Param => 'Profile') || '';
     $Self->{SaveProfile} = $Self->{ParamObject}->GetParam(Param => 'SaveProfile') || '';
     $Self->{TakeLastSearch} = $Self->{ParamObject}->GetParam(Param => 'TakeLastSearch') || '';
@@ -68,7 +70,9 @@ sub Run {
     $Self->{EraseTemplate} = $Self->{ParamObject}->GetParam(Param => 'EraseTemplate') || '';
     # check request
     if ($Self->{ParamObject}->GetParam(Param => 'SearchTemplate') && $Self->{Profile}) {
-        return $Self->{LayoutObject}->Redirect(OP => "Action=CustomerTicketSearchSubaction=Search&TakeLastSearch=1&SaveProfile=1&Profile=$Self->{Profile}");
+        return $Self->{LayoutObject}->Redirect(
+            OP => "Action=CustomerTicketSearchSubaction=Search&TakeLastSearch=1&SaveProfile=1&Profile=$Self->{Profile}",
+        );
     }
     # get signle params
     my %GetParam = ();
@@ -83,22 +87,52 @@ sub Run {
     # get search string params (get submitted params)
     else {
         foreach (qw(TicketNumber From To Cc Subject Body CustomerID ResultForm TimeSearchType StateType
-          TicketFreeTime1
-          TicketFreeTime1Start TicketFreeTime1StartDay TicketFreeTime1StartMonth
-          TicketFreeTime1StartYear
-          TicketFreeTime1Stop TicketFreeTime1StopDay TicketFreeTime1StopMonth
-          TicketFreeTime1StopYear
-          TicketFreeTime2
-          TicketFreeTime2Start TicketFreeTime2StartDay TicketFreeTime2StartMonth
-          TicketFreeTime2StartYear
-          TicketFreeTime2Stop TicketFreeTime2StopDay TicketFreeTime2StopMonth
-          TicketFreeTime2StopYear
-          TicketCreateTimePointFormat TicketCreateTimePoint
-          TicketCreateTimePointStart
-          TicketCreateTimeStart TicketCreateTimeStartDay TicketCreateTimeStartMonth
-          TicketCreateTimeStartYear
-          TicketCreateTimeStop TicketCreateTimeStopDay TicketCreateTimeStopMonth
-          TicketCreateTimeStopYear
+            TicketFreeTime1
+            TicketFreeTime1Start TicketFreeTime1StartDay TicketFreeTime1StartMonth
+            TicketFreeTime1StartYear
+            TicketFreeTime1Stop TicketFreeTime1StopDay TicketFreeTime1StopMonth
+            TicketFreeTime1StopYear
+            TicketFreeTime2
+            TicketFreeTime2Start TicketFreeTime2StartDay TicketFreeTime2StartMonth
+            TicketFreeTime2StartYear
+            TicketFreeTime2Stop TicketFreeTime2StopDay TicketFreeTime2StopMonth
+            TicketFreeTime2StopYear
+            TicketFreeTime3
+            TicketFreeTime3Start TicketFreeTime3StartDay TicketFreeTime3StartMonth
+            TicketFreeTime3StartYear
+            TicketFreeTime3Stop TicketFreeTime3StopDay TicketFreeTime3StopMonth
+            TicketFreeTime3StopYear
+            TicketFreeTime4
+            TicketFreeTime4Start TicketFreeTime4StartDay TicketFreeTime4StartMonth
+            TicketFreeTime4StartYear
+            TicketFreeTime4Stop TicketFreeTime4StopDay TicketFreeTime4StopMonth
+            TicketFreeTime4StopYear
+            TicketFreeTime5
+            TicketFreeTime5Start TicketFreeTime5StartDay TicketFreeTime5StartMonth
+            TicketFreeTime5StartYear
+            TicketFreeTime5Stop TicketFreeTime5StopDay TicketFreeTime5StopMonth
+            TicketFreeTime5StopYear
+            TicketFreeTime6
+            TicketFreeTime6Start TicketFreeTime6StartDay TicketFreeTime6StartMonth
+            TicketFreeTime6StartYear
+            TicketFreeTime6Stop TicketFreeTime6StopDay TicketFreeTime6StopMonth
+            TicketFreeTime6StopYear
+            TicketFreeTime7
+            TicketFreeTime7Start TicketFreeTime7StartDay TicketFreeTime7StartMonth
+            TicketFreeTime7StartYear
+            TicketFreeTime7Stop TicketFreeTime7StopDay TicketFreeTime7StopMonth
+            TicketFreeTime7StopYear
+            TicketFreeTime8
+            TicketFreeTime8Start TicketFreeTime8StartDay TicketFreeTime8StartMonth
+            TicketFreeTime8StartYear
+            TicketFreeTime8Stop TicketFreeTime8StopDay TicketFreeTime8StopMonth
+            TicketFreeTime8StopYear
+            TicketCreateTimePointFormat TicketCreateTimePoint
+            TicketCreateTimePointStart
+            TicketCreateTimeStart TicketCreateTimeStartDay TicketCreateTimeStartMonth
+            TicketCreateTimeStartYear
+            TicketCreateTimeStop TicketCreateTimeStopDay TicketCreateTimeStopMonth
+            TicketCreateTimeStopYear
         )) {
             # get search string params (get submitted params)
             $GetParam{$_} = $Self->{ParamObject}->GetParam(Param => $_);
@@ -110,14 +144,15 @@ sub Run {
         }
         # get array params
         foreach (qw(StateIDs StateTypeIDs PriorityIDs OwnerIDs ResponsibleIDs
-          TicketFreeKey1 TicketFreeText1 TicketFreeKey2 TicketFreeText2
-          TicketFreeKey3 TicketFreeText3 TicketFreeKey4 TicketFreeText4
-          TicketFreeKey5 TicketFreeText5 TicketFreeKey6 TicketFreeText6
-          TicketFreeKey7 TicketFreeText7 TicketFreeKey8 TicketFreeText8
-          TicketFreeKey9 TicketFreeText9 TicketFreeKey10 TicketFreeText10
-          TicketFreeKey11 TicketFreeText11 TicketFreeKey12 TicketFreeText12
-          TicketFreeKey13 TicketFreeText13 TicketFreeKey14 TicketFreeText14
-          TicketFreeKey15 TicketFreeText15 TicketFreeKey16 TicketFreeText16)) {
+            TicketFreeKey1 TicketFreeText1 TicketFreeKey2 TicketFreeText2
+            TicketFreeKey3 TicketFreeText3 TicketFreeKey4 TicketFreeText4
+            TicketFreeKey5 TicketFreeText5 TicketFreeKey6 TicketFreeText6
+            TicketFreeKey7 TicketFreeText7 TicketFreeKey8 TicketFreeText8
+            TicketFreeKey9 TicketFreeText9 TicketFreeKey10 TicketFreeText10
+            TicketFreeKey11 TicketFreeText11 TicketFreeKey12 TicketFreeText12
+            TicketFreeKey13 TicketFreeText13 TicketFreeKey14 TicketFreeText14
+            TicketFreeKey15 TicketFreeText15 TicketFreeKey16 TicketFreeText16
+        )) {
             # get search array params (get submitted params)
             my @Array = $Self->{ParamObject}->GetArray(Param => $_);
             if (@Array) {
@@ -177,60 +212,69 @@ sub Run {
             # do noting ont time stuff
         }
         elsif ($GetParam{TimeSearchType} eq 'TimeSlot') {
-          foreach (qw(Month Day)) {
-              if ($GetParam{"TicketCreateTimeStart$_"} <= 9) {
-                  $GetParam{"TicketCreateTimeStart$_"} = '0'.$GetParam{"TicketCreateTimeStart$_"};
-              }
-          }
-          foreach (qw(Month Day)) {
-              if ($GetParam{"TicketCreateTimeStop$_"} <= 9) {
-                  $GetParam{"TicketCreateTimeStop$_"} = '0'.$GetParam{"TicketCreateTimeStop$_"};
-              }
-          }
-          if ($GetParam{TicketCreateTimeStartDay} && $GetParam{TicketCreateTimeStartMonth} && $GetParam{TicketCreateTimeStartYear}) {
-              $GetParam{TicketCreateTimeNewerDate} = $GetParam{TicketCreateTimeStartYear}.
-                '-'.$GetParam{TicketCreateTimeStartMonth}.
-                '-'.$GetParam{TicketCreateTimeStartDay}.
-                ' 00:00:01';
-          }
-          if ($GetParam{TicketCreateTimeStopDay} && $GetParam{TicketCreateTimeStopMonth} && $GetParam{TicketCreateTimeStopYear}) {
-              $GetParam{TicketCreateTimeOlderDate} = $GetParam{TicketCreateTimeStopYear}.
-                '-'.$GetParam{TicketCreateTimeStopMonth}.
-                '-'.$GetParam{TicketCreateTimeStopDay}.
-                ' 23:59:59';
-          }
+            foreach (qw(Month Day)) {
+                if ($GetParam{"TicketCreateTimeStart$_"} <= 9) {
+                    $GetParam{"TicketCreateTimeStart$_"} = '0'.$GetParam{"TicketCreateTimeStart$_"};
+                }
+            }
+            foreach (qw(Month Day)) {
+                if ($GetParam{"TicketCreateTimeStop$_"} <= 9) {
+                    $GetParam{"TicketCreateTimeStop$_"} = '0'.$GetParam{"TicketCreateTimeStop$_"};
+                }
+            }
+            if ($GetParam{TicketCreateTimeStartDay} &&
+                $GetParam{TicketCreateTimeStartMonth} &&
+                $GetParam{TicketCreateTimeStartYear}
+            ) {
+                $GetParam{TicketCreateTimeNewerDate} = $GetParam{TicketCreateTimeStartYear}.
+                    '-'.$GetParam{TicketCreateTimeStartMonth}.
+                    '-'.$GetParam{TicketCreateTimeStartDay}.
+                    ' 00:00:01';
+            }
+            if ($GetParam{TicketCreateTimeStopDay} &&
+                $GetParam{TicketCreateTimeStopMonth} &&
+                $GetParam{TicketCreateTimeStopYear}
+            ) {
+                $GetParam{TicketCreateTimeOlderDate} = $GetParam{TicketCreateTimeStopYear}.
+                    '-'.$GetParam{TicketCreateTimeStopMonth}.
+                    '-'.$GetParam{TicketCreateTimeStopDay}.
+                    ' 23:59:59';
+            }
         }
         elsif ($GetParam{TimeSearchType} eq 'TimePoint') {
-          if ($GetParam{TicketCreateTimePoint} && $GetParam{TicketCreateTimePointStart} && $GetParam{TicketCreateTimePointFormat}) {
-            my $Time = 0;
-            if ($GetParam{TicketCreateTimePointFormat} eq 'minute') {
-                $Time = $GetParam{TicketCreateTimePoint};
+            if ($GetParam{TicketCreateTimePoint} &&
+                $GetParam{TicketCreateTimePointStart} &&
+                $GetParam{TicketCreateTimePointFormat}
+            ) {
+                my $Time = 0;
+                if ($GetParam{TicketCreateTimePointFormat} eq 'minute') {
+                    $Time = $GetParam{TicketCreateTimePoint};
+                }
+                elsif ($GetParam{TicketCreateTimePointFormat} eq 'hour') {
+                    $Time = $GetParam{TicketCreateTimePoint} * 60;
+                }
+                elsif ($GetParam{TicketCreateTimePointFormat} eq 'day') {
+                    $Time = $GetParam{TicketCreateTimePoint} * 60 * 24;
+                }
+                elsif ($GetParam{TicketCreateTimePointFormat} eq 'week') {
+                    $Time = $GetParam{TicketCreateTimePoint} * 60 * 24 * 7;
+                }
+                elsif ($GetParam{TicketCreateTimePointFormat} eq 'month') {
+                    $Time = $GetParam{TicketCreateTimePoint} * 60 * 24 * 30;
+                }
+                elsif ($GetParam{TicketCreateTimePointFormat} eq 'year') {
+                    $Time = $GetParam{TicketCreateTimePoint} * 60 * 24 * 365;
+                }
+                if ($GetParam{TicketCreateTimePointStart} eq 'Before') {
+                    $GetParam{TicketCreateTimeOlderMinutes} = $Time;
+                }
+                else {
+                    $GetParam{TicketCreateTimeNewerMinutes} = $Time;
+                }
             }
-            elsif ($GetParam{TicketCreateTimePointFormat} eq 'hour') {
-                $Time = $GetParam{TicketCreateTimePoint} * 60;
-            }
-            elsif ($GetParam{TicketCreateTimePointFormat} eq 'day') {
-                $Time = $GetParam{TicketCreateTimePoint} * 60 * 24;
-            }
-            elsif ($GetParam{TicketCreateTimePointFormat} eq 'week') {
-                $Time = $GetParam{TicketCreateTimePoint} * 60 * 24 * 7;
-            }
-            elsif ($GetParam{TicketCreateTimePointFormat} eq 'month') {
-                $Time = $GetParam{TicketCreateTimePoint} * 60 * 24 * 30;
-            }
-            elsif ($GetParam{TicketCreateTimePointFormat} eq 'year') {
-                $Time = $GetParam{TicketCreateTimePoint} * 60 * 24 * 365;
-            }
-            if ($GetParam{TicketCreateTimePointStart} eq 'Before') {
-                $GetParam{TicketCreateTimeOlderMinutes} = $Time;
-            }
-            else {
-                $GetParam{TicketCreateTimeNewerMinutes} = $Time;
-            }
-          }
         }
         # free time
-        foreach (1..2) {
+        foreach (1..6) {
             if (!$GetParam{'TicketFreeTime'.$_}) {
                 foreach my $Type (qw(Year Month Day)) {
                     $GetParam{'TicketFreeTime'.$_.'Start'.$Type} = undef;
@@ -241,13 +285,19 @@ sub Run {
             }
             else {
                 $GetParam{'TicketFreeTime'.$_} = 'checked';
-                if ($GetParam{'TicketFreeTime'.$_.'StartDay'} && $GetParam{'TicketFreeTime'.$_.'StartMonth'} && $GetParam{'TicketFreeTime'.$_.'StartYear'}) {
+                if ($GetParam{'TicketFreeTime'.$_.'StartDay'} &&
+                    $GetParam{'TicketFreeTime'.$_.'StartMonth'} &&
+                    $GetParam{'TicketFreeTime'.$_.'StartYear'}
+                ) {
                     $GetParam{'TicketFreeTime'.$_.'NewerDate'} = $GetParam{'TicketFreeTime'.$_.'StartYear'}.
                     '-'.$GetParam{'TicketFreeTime'.$_.'StartMonth'}.
                     '-'.$GetParam{'TicketFreeTime'.$_.'StartDay'}.
                     ' 00:00:01';
                 }
-                if ($GetParam{'TicketFreeTime'.$_.'StopDay'} && $GetParam{'TicketFreeTime'.$_.'StopMonth'} && $GetParam{'TicketFreeTime'.$_.'StopYear'}) {
+                if ($GetParam{'TicketFreeTime'.$_.'StopDay'} &&
+                    $GetParam{'TicketFreeTime'.$_.'StopMonth'} &&
+                    $GetParam{'TicketFreeTime'.$_.'StopYear'}
+                ) {
                     $GetParam{'TicketFreeTime'.$_.'OlderDate'} = $GetParam{'TicketFreeTime'.$_.'StopYear'}.
                     '-'.$GetParam{'TicketFreeTime'.$_.'StopMonth'}.
                     '-'.$GetParam{'TicketFreeTime'.$_.'StopDay'}.
@@ -273,77 +323,78 @@ sub Run {
         );
 
         foreach (@ViewableIDs) {
-          $Counter++;
-          # build search result
-          if ($Counter >= $Self->{StartHit} && $Counter < ($Self->{SearchPageShown}+$Self->{StartHit}) ) {
-            # get first article data
-            my %Data = $Self->{TicketObject}->ArticleFirstArticle(TicketID => $_);
-            # get whole article (if configured!)
-            if ($Self->{ConfigObject}->Get('CustomerSearchArticleTreeCSV') && $GetParam{ResultForm} eq 'CSV') {
-                my @Article = $Self->{TicketObject}->ArticleGet(
-                    TicketID => $_
-                );
-                foreach my $Articles (@Article) {
-                    if ($Articles->{Body}) {
-                        $Data{ArticleTree} .= "\n-->||$Articles->{ArticleType}||$Articles->{From}||".$Articles->{Created}."||<--------------\n".$Articles->{Body};
+            $Counter++;
+            # build search result
+            if ($Counter >= $Self->{StartHit} && $Counter < ($Self->{SearchPageShown}+$Self->{StartHit}) ) {
+                # get first article data
+                my %Data = $Self->{TicketObject}->ArticleFirstArticle(TicketID => $_);
+                # get whole article (if configured!)
+                if ($Self->{ConfigObject}->Get('CustomerSearchArticleTreeCSV') && $GetParam{ResultForm} eq 'CSV') {
+                    my @Article = $Self->{TicketObject}->ArticleGet(
+                        TicketID => $_
+                    );
+                    foreach my $Articles (@Article) {
+                        if ($Articles->{Body}) {
+                            $Data{ArticleTree} .= "\n-->||$Articles->{ArticleType}||$Articles->{From}||".
+                                $Articles->{Created}."||<--------------\n".$Articles->{Body};
+                        }
                     }
                 }
-            }
-            # customer info
-            my %CustomerData = ();
-            if ($Data{CustomerUserID}) {
-                %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
-                    User => $Data{CustomerUserID},
-                );
-            }
-            elsif ($Data{CustomerID}) {
-                %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
-                    CustomerID => $Data{CustomerID},
-                );
-            }
-            # customer info (customer name)
-            if ($CustomerData{UserLogin}) {
-                $Data{CustomerName} = $Self->{CustomerUserObject}->CustomerName(
-                    UserLogin => $CustomerData{UserLogin},
-                );
-            }
-            # user info
-            my %UserInfo = $Self->{UserObject}->GetUserData(
-                User => $Data{Owner},
-                Cached => 1
-            );
-            # generate ticket result
-            if ($GetParam{ResultForm} eq 'CSV') {
-                # csv quote
-                foreach (keys %Data) {
-                    $Data{$_} =~ s/"/""/g if ($Data{$_});
+                # customer info
+                my %CustomerData = ();
+                if ($Data{CustomerUserID}) {
+                    %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                        User => $Data{CustomerUserID},
+                    );
                 }
-                $Param{StatusTable} .= $Self->MaskCSVResult(
-                    %Data,
-                    %UserInfo,
-                    AccountedTime => $Self->{TicketObject}->TicketAccountedTimeGet(TicketID => $_),
-                )."\n";
-            }
-            else {
-                # Condense down the subject
-                my $Subject = $Self->{TicketObject}->TicketSubjectClean(
-                    TicketNumber => $Data{TicketNumber},
-                    Subject => $Data{Subject} || '',
+                elsif ($Data{CustomerID}) {
+                    %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
+                        CustomerID => $Data{CustomerID},
+                    );
+                }
+                # customer info (customer name)
+                if ($CustomerData{UserLogin}) {
+                    $Data{CustomerName} = $Self->{CustomerUserObject}->CustomerName(
+                        UserLogin => $CustomerData{UserLogin},
+                    );
+                }
+                # user info
+                my %UserInfo = $Self->{UserObject}->GetUserData(
+                    User => $Data{Owner},
+                    Cached => 1
                 );
-                $Data{Age} = $Self->{LayoutObject}->CustomerAge(Age => $Data{Age}, Space => ' ');
-                # customer info string
-                $Data{CustomerName} = '('.$Data{CustomerName}.')' if ($Data{CustomerName});
-                # add blocks to template
-                $Self->{LayoutObject}->Block(
-                    Name => 'Record',
-                    Data => {
+                # generate ticket result
+                if ($GetParam{ResultForm} eq 'CSV') {
+                    # csv quote
+                    foreach (keys %Data) {
+                        $Data{$_} =~ s/"/""/g if ($Data{$_});
+                    }
+                    $Param{StatusTable} .= $Self->MaskCSVResult(
                         %Data,
-                        Subject => $Subject,
                         %UserInfo,
-                    },
-                );
+                        AccountedTime => $Self->{TicketObject}->TicketAccountedTimeGet(TicketID => $_),
+                    )."\n";
+                }
+                else {
+                    # Condense down the subject
+                    my $Subject = $Self->{TicketObject}->TicketSubjectClean(
+                        TicketNumber => $Data{TicketNumber},
+                        Subject => $Data{Subject} || '',
+                    );
+                    $Data{Age} = $Self->{LayoutObject}->CustomerAge(Age => $Data{Age}, Space => ' ');
+                    # customer info string
+                    $Data{CustomerName} = '('.$Data{CustomerName}.')' if ($Data{CustomerName});
+                    # add blocks to template
+                    $Self->{LayoutObject}->Block(
+                        Name => 'Record',
+                        Data => {
+                            %Data,
+                            Subject => $Subject,
+                            %UserInfo,
+                        },
+                    );
+                }
             }
-          }
         }
         # start html page
         my $Output = $Self->{LayoutObject}->CustomerHeader();
@@ -376,15 +427,11 @@ sub Run {
         elsif ($GetParam{ResultForm} eq 'CSV') {
             # return csv to download
             my $CSVFile = 'search';
-            my ($s,$m,$h, $D,$M,$Y, $wd,$yd,$dst) = localtime(time);
-            $Y = $Y+1900;
-            $M++;
-            $M = sprintf("%02d", $M);
-            $D = sprintf("%02d", $D);
-            $h = sprintf("%02d", $h);
-            $m = sprintf("%02d", $m);
+            my ($Sec, $Min, $Hour, $Day, $Month, $Year) = $Self->{TimeObject}->SystemTime2Date(
+                SystemTime => $Self->{TimeObject}->SystemTime(),
+            );
             return $Self->{LayoutObject}->Attachment(
-                Filename => $CSVFile."_"."$Y-$M-$D"."_"."$h-$m.csv",
+                Filename => $CSVFile."_"."$Year-$Month-$Day"."_"."$Hour-$Min.csv",
                 ContentType => "text/csv",
                 Content => $Param{StatusTable},
             );
@@ -412,10 +459,6 @@ sub Run {
             %GetParam = ();
             $Self->{Profile} = '';
         }
-        # set profile to zero
-        elsif (!$Self->{SelectTemplate}) {
-#            $Self->{Profile} = '';
-        }
         # get free text config options
         my %TicketFreeText = ();
         foreach (1..16) {
@@ -463,10 +506,11 @@ sub MaskForm {
         SelectedID => $Param{ResultForm} || 'Normal',
     );
     $Param{'StatesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
-        Data => { $Self->{StateObject}->StateList(
-             UserID => $Self->{UserID},
-             Action => $Self->{Action},
-             )
+        Data => {
+            $Self->{StateObject}->StateList(
+                UserID => $Self->{UserID},
+                Action => $Self->{Action},
+            )
         },
         Name => 'StateIDs',
         Multiple => 1,
@@ -482,10 +526,11 @@ sub MaskForm {
         Size => 5,
         SelectedID => $Param{StateType},
     );
-    $Param{'PriotitiesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
-        Data => { $Self->{PriorityObject}->PriorityList(
-            UserID => $Self->{UserID},
-            Action => $Self->{Action},
+    $Param{'PrioritiesStrg'} = $Self->{LayoutObject}->OptionStrgHashRef(
+        Data => {
+            $Self->{PriorityObject}->PriorityList(
+                UserID => $Self->{UserID},
+                Action => $Self->{Action},
             ),
         },
         Name => 'PriorityIDs',
@@ -589,7 +634,7 @@ sub MaskForm {
         Prefix => 'TicketCreateTimeStop',
         Format => 'DateInputFormat',
     );
-    foreach (1..2) {
+    foreach (1..6) {
         $Param{'TicketFreeTime'.$_.'Start'} = $Self->{LayoutObject}->BuildDateSelection(
             %Param,
             Prefix => 'TicketFreeTime'.$_.'Start',
@@ -624,7 +669,7 @@ sub MaskForm {
         }
     }
     $Count = 0;
-    foreach (1..2) {
+    foreach (1..6) {
         $Count++;
         if ($Self->{Config}->{'TicketFreeTime'}->{$Count}) {
             $Self->{LayoutObject}->Block(
