@@ -1,8 +1,8 @@
 # --
 # Kernel/System/CSV.pm - all csv functions
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: CSV.pm,v 1.7 2006/10/17 12:36:04 martin Exp $
+# $Id: CSV.pm,v 1.10.2.1 2007/10/19 06:14:31 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::System::CSV;
 use strict;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.7 $';
+$VERSION = '$Revision: 1.10.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -33,21 +33,21 @@ All csv functions.
 
 create a object
 
-  use Kernel::Config;
-  use Kernel::System::Log;
+    use Kernel::Config;
+    use Kernel::System::Log;
 
-  my $ConfigObject = Kernel::Config->new();
-  my $LogObject    = Kernel::System::Log->new(
-      ConfigObject => $ConfigObject,
-  );
-  my $CSVObject = Kernel::System::CSV->new(
-      LogObject => $LogObject,
-  );
+    my $ConfigObject = Kernel::Config->new();
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $CSVObject = Kernel::System::CSV->new(
+        LogObject => $LogObject,
+    );
 
 =cut
 
 sub new {
-    my $Type  = shift;
+    my $Type = shift;
     my %Param = @_;
 
     # allocate new hash for object
@@ -67,7 +67,7 @@ sub new {
 Returns a csv formatted string based on a array with head data.
 
     $CSV = $CSVObject->Array2CSV(
-        Head => ['RowA', 'RowB', ],
+        Head => ['RowA', 'RowB', ],   # optional
         Data => [
             [1,4],
             [7,3],
@@ -85,7 +85,7 @@ sub Array2CSV {
     my @Head = ();
     my @Data = (['##No Data##']);
     # check required params
-    foreach (qw(Data)){
+    foreach (qw(Data)) {
         if (!$Param{$_}) {
             $Self->{LogObject}->Log(Priority => "error", Message => "Got no $_ param!");
             return;
@@ -111,10 +111,14 @@ sub Array2CSV {
     # fill in data
     foreach my $EntryRow (@Data) {
         foreach my $Entry (@{$EntryRow}) {
-              # csv quote
-              $Entry =~ s/"/""/g if ($Entry);
-              $Entry = '' if (!defined($Entry));
-              $Output .= "\"$Entry\";";
+            # Copy $Entry because otherwise you maniplate the content
+            # of the original $Param{Data}!!!! Array in Array Referenc
+            my $Content = $Entry;
+
+            # csv quote
+            $Content =~ s/"/""/g if ($Content);
+            $Content = '' if ( !defined($Content) );
+            $Output .= "\"$Content\";";
         }
         $Output .= "\n";
     }
@@ -138,32 +142,41 @@ sub CSV2Array {
     my $Self = shift;
     my %Param = @_;
     my @Array = ();
-    my @Lines = split(/\n/, $Param{String});
 
     # get separator
     if (!defined($Param{Separator}) || $Param{Separator} eq '') {
         $Param{Separator} = ';';
     }
-    foreach (@Lines) {
-        my @Fields = split(/$Param{Separator}/, $_);
-        push(@Array, \@Fields);
+
+    # a better solution can be the use of
+    # use Text::ParseWords;
+    # for more information read "PerlKochbuch" page 32
+
+    # get separator
+    if (!defined($Param{Quote})) {
+        $Param{Quote} = '"';
     }
 
-    # text quoting
-    if (defined($Param{Quote}) && $Param{Quote} ne '') {
-        foreach my $Field (@Array) {
-            foreach my $Index (0..scalar@{$Field}) {
-                if (defined($Field->[$Index]) && $Field->[$Index] =~ /^$Param{Quote}(.*)$Param{Quote}$/) {
-                    $Field->[$Index] = $1;
-                }
-            }
+    # if you change the split options, remember that each value can include \n
+    my @Lines = split( /$Param{Quote}$Param{Separator}\n/, $Param{String} );
+    for my $Line (@Lines) {
+        my @Fields = split( /$Param{Quote}$Param{Separator}$Param{Quote}/, $Line );
+        $Fields[0] =~ s/^$Param{Quote}//mgs;
+
+        for my $Field (@Fields) {
+            $Field =~ s/$Param{Quote}$Param{Quote}/$Param{Quote}/g;
         }
+
+        push( @Array, \@Fields );
     }
 
     return \@Array;
 }
+
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -174,6 +187,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.7 $ $Date: 2006/10/17 12:36:04 $
+$Revision: 1.10.2.1 $ $Date: 2007/10/19 06:14:31 $
 
-=cut
+=cut
\ No newline at end of file
