@@ -2,7 +2,7 @@
 # Kernel/System/Cache.pm - all cache functions
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Cache.pm,v 1.2 2007/07/30 09:55:17 tr Exp $
+# $Id: Cache.pm,v 1.3.2.1 2007/10/22 16:09:42 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.2 $';
+$VERSION = '$Revision: 1.3.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -63,7 +63,7 @@ sub new {
     # allocate new hash for object
     my $Self = {};
     bless ($Self, $Type);
-    # 0=off; 1=set; 2=+get+delete;
+    # 0=off; 1=set+get_cache; 2=+delete+get_request;
     $Self->{Debug} = $Param{Debug} || 0;
     # check needed objects
     foreach (qw(MainObject ConfigObject LogObject)) {
@@ -74,7 +74,7 @@ sub new {
     my $CacheModule = $Self->{ConfigObject}->Get('Cache::Module')
         || 'Kernel::System::Cache::File';
     if (!$Self->{MainObject}->Require($CacheModule)) {
-        die "Can't load cache backend module $CacheModule! $@";
+        die "Can't load backend module $CacheModule! $@";
     }
 
     $Self->{CacheObject} = $CacheModule->new(%Param);
@@ -98,7 +98,7 @@ sub Set {
     my $Self = shift;
     my %Param = @_;
     foreach (qw(Key Value)) {
-        if (!$Param{$_}) {
+        if (!defined($Param{$_})) {
             $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
             return;
         }
@@ -140,7 +140,16 @@ sub Get {
             Message => "Get Key:$Param{Key}!",
         );
     }
-    return $Self->{CacheObject}->Get(%Param);
+    my $Value = $Self->{CacheObject}->Get(%Param);
+    if (defined($Value)) {
+        if ($Self->{Debug} > 0) {
+            $Self->{LogObject}->Log(
+                Priority => 'notice',
+                Message => "Get cached Key:$Param{Key}!",
+            );
+        }
+    }
+    return $Value;
 }
 
 =item Delete()
@@ -189,6 +198,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.2 $ $Date: 2007/07/30 09:55:17 $
+$Revision: 1.3.2.1 $ $Date: 2007/10/22 16:09:42 $
 
 =cut
