@@ -2,7 +2,7 @@
 # Kernel/System/Config.pm - all system config tool functions
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Config.pm,v 1.57.2.3 2007/03/04 23:05:11 martin Exp $
+# $Id: Config.pm,v 1.64 2007/03/27 10:12:02 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,11 +14,12 @@ package Kernel::System::Config;
 use strict;
 
 use Kernel::System::XML;
-use Kernel::System::Main;
 use Kernel::Config;
+use Digest::MD5 qw(md5_hex);
+use Data::Dumper;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.57.2.3 $';
+$VERSION = '$Revision: 1.64 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -39,24 +40,30 @@ All functions to manage config settings.
 
 create a object
 
-  use Kernel::Config;
-  use Kernel::System::Log;
-  use Kernel::System::DB;
-  use Kernel::System::Config;
+    use Kernel::Config;
+    use Kernel::System::Log;
+    use Kernel::System::DB;
+    use Kernel::System::Config;
 
-  my $ConfigObject = Kernel::Config->new();
-  my $LogObject    = Kernel::System::Log->new(
-      ConfigObject => $ConfigObject,
-  );
-  my $DBObject = Kernel::System::DB->new(
-      ConfigObject => $ConfigObject,
-      LogObject => $LogObject,
-  );
-  my $ConfigToolObject = Kernel::System::Config->new(
-      LogObject => $LogObject,
-      ConfigObject => $ConfigObject,
-      DBObject => $DBObject,
-  );
+    my $ConfigObject = Kernel::Config->new();
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+
+    my $MainObject = Kernel::System::Main->new(
+        LogObject => $LogObject,
+        ConfigObject => $ConfigObject,
+    );
+
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+    my $ConfigToolObject = Kernel::System::Config->new(
+        LogObject => $LogObject,
+        ConfigObject => $ConfigObject,
+        DBObject => $DBObject,
+    );
 
 =cut
 
@@ -69,7 +76,7 @@ sub new {
     bless ($Self, $Type);
 
     # check needed objects
-    foreach (qw(DBObject ConfigObject LogObject TimeObject)) {
+    foreach (qw(DBObject ConfigObject LogObject TimeObject MainObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
 
@@ -77,9 +84,8 @@ sub new {
 
     # create xml object
     $Self->{XMLObject} = Kernel::System::XML->new(%Param);
-    # create main object to load Data::Dumper
-    $Self->{MainObject} = Kernel::System::Main->new(%Param);
-    $Self->{MainObject}->Require('Data::Dumper');
+    # mild pretty print
+    $Data::Dumper::Indent = 1;
     # create config object
     $Self->{ConfigDefaultObject} = Kernel::Config->new(%Param, Level => 'Default');
     # create config object
@@ -89,8 +95,6 @@ sub new {
 
     # read all config files
     $Self->{ConfigCounter} = $Self->_Init();
-#    # write default file
-#    $Self->WriteDefault();
 
     return $Self;
 }
@@ -130,7 +134,6 @@ sub _Init {
             $FileCachePart =~ s/\//_/g;
             if ($ConfigFile) {
                 my $CacheFileUsed = 0;
-                use Digest::MD5 qw(md5_hex);
                 my $Digest = md5_hex($ConfigFile);
                 my $FileCache = "$Self->{Home}/var/tmp/SysConfig-Cache$FileCachePart-$Digest.pm";
                 if (-e $FileCache) {
@@ -152,7 +155,6 @@ sub _Init {
                             Message => "Can't open cache file $FileCache: $!",
                         );
                     }
-
                 }
                 else {
                     # remove all cache files
@@ -262,6 +264,10 @@ download config changes
 
     $ConfigToolObject->Download();
 
+or if you want to check if it exists (returns true or false)
+
+    $ConfigToolObject->Download(Type => 'Check');
+
 =cut
 
 sub Download {
@@ -280,15 +286,31 @@ sub Download {
         return $File;
     }
     elsif (!open(IN, "< $Home/Kernel/Config/Files/ZZZAuto.pm")) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Can't open $Home/Kernel/Config/Files/ZZZAuto.pm: $!");
-        return '';
+        if ($Param{Type}) {
+            return;
+        }
+        else {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Can't open $Home/Kernel/Config/Files/ZZZAuto.pm: $!");
+            return '';
+        }
     }
     else {
         while (<IN>) {
             $File .= $_;
         }
         close (IN);
-        return $File;
+        if ($Param{Type}) {
+            my $Length = length($File);
+            if ($Length > 25) {
+                return 1;
+            }
+            else {
+                return;
+            }
+        }
+        else {
+            return $File;
+        }
     }
 }
 
@@ -372,9 +394,9 @@ sub CreateConfig {
                 if (!defined($A1) && !defined($A2)) {
                     # do nothing
                 }
-                elsif ((defined($A1) && !defined($A2)) || (!defined($A1) && defined($A2)) || $Self->DataDiff(Data1 => $A1, Data2 => $A2) || ($Config{Valid} && !$ConfigDefault{Valid})) {
-#            my $Dump = Data::Dumper::Dumper(\%Config);
-#                    print STDERR "\$Self->{'$Name'} = $C - $Dump";
+                elsif ((defined($A1) && !defined($A2)) || (!defined($A1) && defined($A2)) ||
+                    $Self->DataDiff(Data1 => $A1, Data2 => $A2) || ($Config{Valid} && !$ConfigDefault{Valid})
+                ) {
                     $File .= "\$Self->{'$Name'} = $C";
                 }
                 else {
@@ -566,16 +588,16 @@ sub ConfigItemGet {
                 @{$ConfigItem->{Setting}->[1]->{Hash}->[1]->{Item}} = (undef);
                 my %Hash = %{$HashRef};
                 foreach my $Key (sort keys %Hash) {
-                   if (ref($Hash{$Key}) eq 'ARRAY') {
+                    if (ref($Hash{$Key}) eq 'ARRAY') {
                         my @Array = (undef,{Content => '',});
                         @{$Array[1]{Item}} = (undef);
                         foreach my $Content (@{$Hash{$Key}}) {
                             push (@{$Array[1]{Item}}, {Content => $Content});
                         }
                         push (@{$ConfigItem->{Setting}->[1]->{Hash}->[1]->{Item}}, {
-                                Key     => $Key,
+                                Key => $Key,
                                 Content => '',
-                                Array   => \@Array,
+                                Array => \@Array,
                             },
                         );
                     }
@@ -586,29 +608,29 @@ sub ConfigItemGet {
                             push (@{$Array[1]{Item}}, {Content => $Hash{$Key}{$Key2}, Key => $Key2});
                         }
                         push (@{$ConfigItem->{Setting}->[1]->{Hash}->[1]->{Item}}, {
-                                Key     => $Key,
+                                Key => $Key,
                                 Content => '',
-                                Hash    => \@Array,
+                                Hash => \@Array,
                             },
                         );
                     }
                     else {
-                       my $Option = 0;
-                       foreach my $Index (1...$#Array) {
-                           if (defined ($Array[$Index]{Key}) && $Array[$Index]{Key} eq $Key && defined ($Array[$Index]{Option})) {
+                        my $Option = 0;
+                        foreach my $Index (1...$#Array) {
+                            if (defined ($Array[$Index]{Key}) && $Array[$Index]{Key} eq $Key && defined ($Array[$Index]{Option})) {
                                 $Option = 1;
                                 $Array[$Index]{Option}[1]{SelectedID} = $Hash{$Key};
                                 push (@{$ConfigItem->{Setting}->[1]->{Hash}->[1]->{Item}}, {
-                                        Key     => $Key,
+                                        Key => $Key,
                                         Content => '',
-                                        Option  => $Array[$Index]{Option},
+                                        Option => $Array[$Index]{Option},
                                     },
                                 );
                             }
                         }
                         if ($Option == 0) {
                             push (@{$ConfigItem->{Setting}->[1]->{Hash}->[1]->{Item}}, {
-                                    Key     => $Key,
+                                    Key => $Key,
                                     Content => $Hash{$Key},
                                 },
                             );
@@ -886,12 +908,12 @@ sub ConfigSubGroupList {
             if ($Hit) {
                 foreach my $SubGroup (@{$ConfigItem->{SubGroup}}) {
                     if ($SubGroup->{Content}) {
-                         # get sub count
-                         my @List = $Self->ConfigSubGroupConfigItemList(
-                             Group => $Param{Name},
-                             SubGroup => $SubGroup->{Content},
-                         );
-                         $List{$SubGroup->{Content}} = ($#List+1);
+                        # get sub count
+                        my @List = $Self->ConfigSubGroupConfigItemList(
+                            Group => $Param{Name},
+                            SubGroup => $SubGroup->{Content},
+                        );
+                        $List{$SubGroup->{Content}} = ($#List+1);
                     }
                 }
             }
@@ -990,11 +1012,10 @@ sub ConfigItemSearch {
                         foreach (@{$Config}) {
                             if (!$Used{$Group.'::'.$SubGroup}) {
                                 if ($_ && $_ =~ /\Q$Param{Search}\E/i) {
-                                    push (@List,
-                                        {
+                                    push (@List, {
                                             SubGroup => $SubGroup,
                                             SubGroupCount => $SubGroups{$SubGroup},
-                                        Group    => $Group,
+                                            Group => $Group,
                                         },
                                     );
                                     $Used{$Group.'::'.$SubGroup} = 1;
@@ -1006,11 +1027,10 @@ sub ConfigItemSearch {
                         foreach my $Key (keys %{$Config}) {
                             if (!$Used{$Group.'::'.$SubGroup}) {
                                 if ($Config->{$Key} && $Config->{$Key} =~ /\Q$Param{Search}\E/i) {
-                                    push (@List,
-                                        {
+                                    push (@List, {
                                             SubGroup => $SubGroup,
                                             SubGroupCount => $SubGroups{$SubGroup},
-                                            Group    => $Group,
+                                            Group => $Group,
                                         },
                                     );
                                     $Used{$Group.'::'.$SubGroup} = 1;
@@ -1020,11 +1040,10 @@ sub ConfigItemSearch {
                     }
                     else {
                         if ($Config =~ /\Q$Param{Search}\E/i) {
-                            push (@List,
-                                {
+                            push (@List, {
                                     SubGroup => $SubGroup,
                                     SubGroupCount => $SubGroups{$SubGroup},
-                                    Group    => $Group,
+                                    Group => $Group,
                                 },
                             );
                             $Used{$Group.'::'.$SubGroup} = 1;
@@ -1033,11 +1052,10 @@ sub ConfigItemSearch {
                 }
                 if ($Item =~ /\Q$Param{Search}\E/i) {
                     if (!$Used{$Group.'::'.$SubGroup}) {
-                        push (@List,
-                            {
+                        push (@List, {
                                 SubGroup => $SubGroup,
                                 SubGroupCount => $SubGroups{$SubGroup},
-                                Group    => $Group,
+                                Group => $Group,
                             },
                         );
                         $Used{$Group.'::'.$SubGroup} = 1;
@@ -1049,11 +1067,10 @@ sub ConfigItemSearch {
                         if (!$Used{$Group.'::'.$SubGroup}) {
                             my $Description = $ItemHash{Description}[$Index]{Content};
                             if ($Description =~ /\Q$Param{Search}\E/i) {
-                                push (@List,
-                                    {
+                                push (@List, {
                                         SubGroup => $SubGroup,
                                         SubGroupCount => $SubGroups{$SubGroup},
-                                        Group    => $Group,
+                                        Group => $Group,
                                     },
                                 );
                                 $Used{$Group.'::'.$SubGroup} = 1;
@@ -1074,13 +1091,13 @@ sub _ModGet {
     my $ConfigObject;
     # do not use ZZZ files
     if ($Param{Level} && $Param{Level} eq 'Default') {
-         $ConfigObject = $Self->{ConfigDefaultObject};
+        $ConfigObject = $Self->{ConfigDefaultObject};
     }
     elsif ($Param{Level} && $Param{Level} eq 'Clear') {
-         $ConfigObject = $Self->{ConfigClearObject};
+        $ConfigObject = $Self->{ConfigClearObject};
     }
     else {
-         $ConfigObject = $Self->{ConfigObject};
+        $ConfigObject = $Self->{ConfigObject};
     }
     if ($Param{ConfigName} =~ /^(.*)###(.*)###(.*)$/) {
         if (defined($ConfigObject->Get($1))) {
@@ -1363,9 +1380,9 @@ sub _XML2Perl {
                 }
             }
             else {
-               if ($Key ne 'Content') {
-                   $Hash{$Key} = $Param{Data}->{Setting}->[1]->{FrontendModuleReg}->[1]->{$Key}->[1]->{Content};
-               }
+                if ($Key ne 'Content') {
+                    $Hash{$Key} = $Param{Data}->{Setting}->[1]->{FrontendModuleReg}->[1]->{$Key}->[1]->{Content};
+                }
             }
         }
         # store in config
@@ -1428,6 +1445,8 @@ sub DESTROY {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -1440,6 +1459,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.57.2.3 $ $Date: 2007/03/04 23:05:11 $
+$Revision: 1.64 $ $Date: 2007/03/27 10:12:02 $
 
 =cut
