@@ -1,8 +1,8 @@
 # --
 # Kernel/System/CustomerGroup.pm - All Groups related function should be here eventually
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: CustomerGroup.pm,v 1.8 2006/08/29 17:30:36 martin Exp $
+# $Id: CustomerGroup.pm,v 1.12 2007/02/06 23:13:55 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,9 +13,10 @@ package Kernel::System::CustomerGroup;
 
 use strict;
 use Kernel::System::Group;
+use Kernel::System::Valid;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.8 $';
+$VERSION = '$Revision: 1.12 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -32,7 +33,37 @@ All customer group functions. E. g. to add groups or to get a member list of a g
 
 =cut
 
-# --
+=item new()
+
+create a object
+
+    use Kernel::Config;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::DB;
+    use Kernel::System::CustomerGroup;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        MainObject => $MainObject,
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+    my $CustomerGroupObject = Kernel::System::CustomerGroup->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+        DBObject => $DBObject,
+    );
+
+=cut
+
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -45,8 +76,8 @@ sub new {
     foreach (qw(DBObject ConfigObject LogObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
-
     $Self->{GroupObject} = Kernel::System::Group->new(%Param);
+    $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
 
     return $Self;
 }
@@ -55,21 +86,21 @@ sub new {
 
 to add a member to a group
 
-  Permission: ro,move_into,priority,create,rw
+    Permission: ro,move_into,priority,create,rw
 
-  my $ID = $Self->{CustomerGroupObject}->GroupMemberAdd(
-      GID => 12,
-      UID => 6,
-      Permission => {
-          ro => 1,
-          move_into => 1,
-          create => 1,
-          owner => 1,
-          priority => 0,
-          rw => 0,
-      },
-      UserID => 123,
-  );
+    my $ID = $CustomerGroupObject->GroupMemberAdd(
+        GID => 12,
+        UID => 6,
+        Permission => {
+            ro => 1,
+            move_into => 1,
+            create => 1,
+            owner => 1,
+            priority => 0,
+            rw => 0,
+        },
+        UserID => 123,
+    );
 
 =cut
 
@@ -79,21 +110,21 @@ sub GroupMemberAdd {
     my $count;
     # check needed stuff
     foreach (qw(UID GID UserID Permission)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # update permission
     foreach (keys %{$Param{Permission}}) {
         # delete existing permission
         my $SQL = "DELETE FROM group_customer_user ".
-          " WHERE ".
-          " group_id = ".$Self->{DBObject}->Quote($Param{GID}).
-          " AND ".
-          " user_id = '".$Self->{DBObject}->Quote($Param{UID})."' ".
-          " AND ".
-          " permission_key = '".$Self->{DBObject}->Quote($_)."'";
+            " WHERE ".
+            " group_id = ".$Self->{DBObject}->Quote($Param{GID}).
+            " AND ".
+            " user_id = '".$Self->{DBObject}->Quote($Param{UID})."' ".
+            " AND ".
+            " permission_key = '".$Self->{DBObject}->Quote($_)."'";
         $Self->{DBObject}->Do(SQL => $SQL);
         # debug
         if ($Self->{Debug}) {
@@ -104,14 +135,14 @@ sub GroupMemberAdd {
         }
         # insert new permission
         $SQL = "INSERT INTO group_customer_user ".
-          " (user_id, group_id, permission_key, permission_value, ".
-          " create_time, create_by, change_time, change_by) ".
-          " VALUES ".
-          " ('".$Self->{DBObject}->Quote($Param{UID})."', ".
-          " ".$Self->{DBObject}->Quote($Param{GID}).", ".
-          " '".$Self->{DBObject}->Quote($_)."', ".
-          " ".$Self->{DBObject}->Quote($Param{Permission}->{$_}).",".
-          " current_timestamp, $Param{UserID}, current_timestamp, $Param{UserID})";
+            " (user_id, group_id, permission_key, permission_value, ".
+            " create_time, create_by, change_time, change_by) ".
+            " VALUES ".
+            " ('".$Self->{DBObject}->Quote($Param{UID})."', ".
+            " ".$Self->{DBObject}->Quote($Param{GID}).", ".
+            " '".$Self->{DBObject}->Quote($_)."', ".
+            " ".$Self->{DBObject}->Quote($Param{Permission}->{$_}).",".
+            " current_timestamp, $Param{UserID}, current_timestamp, $Param{UserID})";
         $Self->{DBObject}->Do(SQL => $SQL);
     }
     return 1;
@@ -121,18 +152,18 @@ sub GroupMemberAdd {
 
 returns a list of users of a group with ro/move_into/create/owner/priority/rw permissions
 
-  UserID: user id
-  GroupID: group id
-  Type: ro|move_into|priority|create|rw
-  Result: HASH -> returns a hash of key => group id, value => group name
-          Name -> returns an array of user names
-          ID   -> returns an array of user names
-  Example:
-  $Self->{CustomerGroupObject}->GroupMemberList(
-      UserID => $ID,
-      Type => 'move_into',
-      Result => 'HASH',
-  );
+    UserID: user id
+    GroupID: group id
+    Type: ro|move_into|priority|create|rw
+    Result: HASH -> returns a hash of key => group id, value => group name
+            Name -> returns an array of user names
+            ID   -> returns an array of user names
+    Example:
+    $CustomerGroupObject->GroupMemberList(
+        UserID => $ID,
+        Type => 'move_into',
+        Result => 'HASH',
+    );
 
 =cut
 
@@ -141,10 +172,10 @@ sub GroupMemberList {
     my %Param = @_;
     # check needed stuff
     foreach (qw(Result Type)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     if (!$Param{UserID} && !$Param{GroupID}) {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Need UserID or GroupID!");
@@ -164,23 +195,23 @@ sub GroupMemberList {
     }
     # if it's activ, return just the permitted groups
     my $SQL = "SELECT g.id, g.name, gu.permission_key, gu.permission_value, ".
-      " gu.user_id ".
-      " FROM ".
-      " groups g, group_customer_user gu".
-      " WHERE " .
-      " g.valid_id IN ( ${\(join ', ', $Self->{DBObject}->GetValidIDs())} ) ".
-      " AND ".
-      " g.id = gu.group_id ".
-      " AND ".
-      " gu.permission_value = 1 ".
-      " AND ".
-      " gu.permission_key IN ('".$Self->{DBObject}->Quote($Param{Type})."', 'rw') ".
-      " AND ";
+        " gu.user_id ".
+        " FROM ".
+        " groups g, group_customer_user gu".
+        " WHERE " .
+        " g.valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} ) ".
+        " AND ".
+        " g.id = gu.group_id ".
+        " AND ".
+        " gu.permission_value = 1 ".
+        " AND ".
+        " gu.permission_key IN ('".$Self->{DBObject}->Quote($Param{Type})."', 'rw') ".
+        " AND ";
     if ($Param{UserID}) {
-      $SQL .= " gu.user_id = '".$Self->{DBObject}->Quote($Param{UserID})."'";
+        $SQL .= " gu.user_id = '".$Self->{DBObject}->Quote($Param{UserID})."'";
     }
     else {
-      $SQL .= " gu.group_id = ".$Self->{DBObject}->Quote($Param{GroupID})."";
+        $SQL .= " gu.group_id = ".$Self->{DBObject}->Quote($Param{GroupID})."";
     }
     $Self->{DBObject}->Prepare(SQL => $SQL);
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
@@ -223,9 +254,11 @@ sub GroupMemberList {
         return %Data;
     }
 }
-# --
+
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -238,6 +271,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.8 $ $Date: 2006/08/29 17:30:36 $
+$Revision: 1.12 $ $Date: 2007/02/06 23:13:55 $
 
 =cut
