@@ -2,7 +2,7 @@
 # Kernel/System/DB/oracle.pm - oracle database backend
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: oracle.pm,v 1.17.2.2 2007/03/05 00:41:55 martin Exp $
+# $Id: oracle.pm,v 1.27 2007/07/23 08:57:50 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,9 +12,10 @@
 package Kernel::System::DB::oracle;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.17.2.2 $';
+$VERSION = '$Revision: 1.27 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -46,10 +47,15 @@ sub LoadPreferences {
         LongTruncOk => 1,
         LongReadLen => 4*1024*1024,
     };
+    # set current time stamp if different to "current_timestamp"
+    $Self->{'DB::CurrentTimestamp'} = '';
+    # set encoding of selected data to utf8
+    $Self->{'DB::Encode'} = 0;
 
     # shell setting
     $Self->{'DB::Comment'} = '-- ';
     $Self->{'DB::ShellCommit'} = ';';
+    $Self->{'DB::ShellConnect'} = 'SET DEFINE OFF';
 
     return 1;
 }
@@ -114,9 +120,11 @@ sub TableCreate {
     my @Return2 = ();
     foreach my $Tag (@Param) {
         if ($Tag->{Tag} eq 'Table' && $Tag->{TagType} eq 'Start') {
-            $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
-            $SQLStart .= $Self->{'DB::Comment'}." create table $Tag->{Name}\n";
-            $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+                $SQLStart .= $Self->{'DB::Comment'}." create table $Tag->{Name}\n";
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            }
         }
         if (($Tag->{Tag} eq 'Table' || $Tag->{Tag} eq 'TableCreate') && $Tag->{TagType} eq 'Start') {
             $SQLStart .= "CREATE TABLE $Tag->{Name} (\n";
@@ -175,7 +183,15 @@ sub TableCreate {
             }
             push (@Return2, "DROP SEQUENCE $Constraint"."_seq");
             push (@Return2, "CREATE SEQUENCE $Constraint"."_seq");
-            push (@Return2, "CREATE OR REPLACE TRIGGER $Constraint"."_s_t\nbefore insert on $TableName\nfor each row\nbegin\n    select $Constraint"."_seq.nextval\n    into :new.$Tag->{Name}\n    from dual;\nend;\n$Shell");
+            push (@Return2, "CREATE OR REPLACE TRIGGER $Constraint"."_s_t\n".
+                "before insert on $TableName\n".
+                "for each row\n".
+                "begin\n".
+                "    select $Constraint"."_seq.nextval\n".
+                "    into :new.$Tag->{Name}\n".
+                "    from dual;\nend;\n".
+                "$Shell",
+            );
         }
     }
     # add uniq
@@ -233,9 +249,11 @@ sub TableDrop {
     my $SQL = '';
     foreach my $Tag (@Param) {
         if ($Tag->{Tag} eq 'Table' && $Tag->{TagType} eq 'Start') {
-            $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
-            $SQL .= $Self->{'DB::Comment'}." drop table $Tag->{Name}\n";
-            $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+                $SQL .= $Self->{'DB::Comment'}." drop table $Tag->{Name}\n";
+                $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            }
         }
         $SQL .= "DROP TABLE $Tag->{Name} CASCADE CONSTRAINTS";
         return ($SQL);
@@ -248,16 +266,23 @@ sub TableAlter {
     my @Param = @_;
     my $SQLStart = '';
     my @SQL = ();
+    my $Table = '';
     foreach my $Tag (@Param) {
         if ($Tag->{Tag} eq 'TableAlter' && $Tag->{TagType} eq 'Start') {
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+                $SQLStart .= $Self->{'DB::Comment'}." alter table $Tag->{Name}\n";
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            }
             $SQLStart .= "ALTER TABLE $Tag->{Name}";
+            $Table = $Tag->{Name};
         }
         elsif ($Tag->{Tag} eq 'ColumnAdd' && $Tag->{TagType} eq 'Start') {
             # Type translation
             $Tag = $Self->_TypeTranslation($Tag);
             # normal data type
             my $SQLEnd = $SQLStart." ADD $Tag->{Name} $Tag->{Type}";
-            if ($Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
+            if (!$Tag->{Default} && $Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
                 $SQLEnd .= " NOT NULL";
             }
             # auto increment
@@ -269,6 +294,18 @@ sub TableAlter {
                 $SQLEnd .= " PRIMARY KEY($Tag->{Name})";
             }
             push (@SQL, $SQLEnd);
+            # default values
+            if ($Tag->{Default}) {
+                if ($Tag->{Type} =~ /int/i) {
+                    push (@SQL, "UPDATE $Table SET $Tag->{Name} = $Tag->{Default} WHERE $Tag->{Name} IS NULL");
+                }
+                else {
+                    push (@SQL, "UPDATE $Table SET $Tag->{Name} = $Tag->{Default} WHERE '$Tag->{Name}' IS NULL");
+                }
+                if ($Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
+                    push (@SQL, "ALTER TABLE $Table MODIFY $Tag->{Name} $Tag->{Type} NOT NULL");
+                }
+            }
         }
         elsif ($Tag->{Tag} eq 'ColumnChange' && $Tag->{TagType} eq 'Start') {
             # Type translation
@@ -277,7 +314,7 @@ sub TableAlter {
             if ($Tag->{NameOld} ne $Tag->{NameNew}) {
                 push (@SQL, $SQLStart." RENAME COLUMN $Tag->{NameOld} TO $Tag->{NameNew}");
             }
-            # alter table tabname modify
+            # alter table name modify
             if (!$Tag->{Name} && $Tag->{NameNew}) {
                 $Tag->{Name} = $Tag->{NameNew};
             }
@@ -302,7 +339,7 @@ sub TableAlter {
             push (@SQL, $SQLEnd);
         }
         elsif ($Tag->{Tag} eq 'ColumnDrop' && $Tag->{TagType} eq 'Start') {
-            my $SQLEnd = $SQLStart." DROP $Tag->{Name}";
+            my $SQLEnd = $SQLStart." DROP COLUMN $Tag->{Name}";
             push (@SQL, $SQLEnd);
         }
     }
@@ -437,35 +474,68 @@ sub Insert {
     my @Values = ();
     foreach my $Tag (@Param) {
         if ($Tag->{Tag} eq 'Insert' && $Tag->{TagType} eq 'Start') {
-            $SQL = "INSERT INTO $Tag->{Table} "
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+                $SQL .= $Self->{'DB::Comment'}." insert into table $Tag->{Table}\n";
+                $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            }
+            $SQL .= "INSERT INTO $Tag->{Table} ";
         }
         if ($Tag->{Tag} eq 'Data' && $Tag->{TagType} eq 'Start') {
             $Tag->{Key} = ${$Self->Quote(\$Tag->{Key})};
             push (@Keys, $Tag->{Key});
-            if ($Tag->{Type} && $Tag->{Type} eq 'Quote') {
-                $Tag->{Value} = "'".${$Self->Quote(\$Tag->{Value})}."'";
+            my $Value;
+            if (defined($Tag->{Value})) {
+                $Value = $Tag->{Value};
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message => "The content for inserts is not longer appreciated attribut Value, use Content from now on! Reason: You can't use new lines in attributes.",
+                );
+            }
+            elsif (defined($Tag->{Content})) {
+                $Value = $Tag->{Content};
             }
             else {
-                $Tag->{Value} = ${$Self->Quote(\$Tag->{Value})};
+                $Value = '';
             }
-            push (@Values, $Tag->{Value});
+            if ($Tag->{Type} && $Tag->{Type} eq 'Quote') {
+                $Value = "'".${$Self->Quote(\$Value)}."'";
+            }
+            else {
+                $Value = ${$Self->Quote(\$Value)};
+            }
+            push (@Values, $Value);
         }
     }
     my $Key = '';
     foreach (@Keys) {
         if ($Key ne '') {
-            $Key .= ",";
+            $Key .= ", ";
         }
         $Key .= $_;
     }
     my $Value = '';
-    foreach (@Values) {
+    foreach my $Tmp (@Values) {
         if ($Value ne '') {
-            $Value .= ",";
+            $Value .= ", ";
+        }
+        if ($Tmp eq 'current_timestamp') {
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $Value .= $Tmp;
+            }
+            else {
+                my $Timestamp = $Self->{TimeObject}->CurrentTimestamp();
+                $Value .= '\''.$Timestamp.'\'';
+            }
+        }
+        else {
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $Tmp =~ s/\n/\r/g;
+            }
+            $Value .= $Tmp;
         }
-        $Value .= $_;
     }
-    $SQL .= "($Key) VALUES ($Value)";
+    $SQL .= "($Key)\n    VALUES\n    ($Value)";
     return ($SQL);
 }
 
