@@ -2,7 +2,7 @@
 # Kernel/System/Email.pm - the global email send module
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Email.pm,v 1.29 2007/07/26 12:56:54 martin Exp $
+# $Id: Email.pm,v 1.31.2.1 2007/11/05 13:18:11 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -20,7 +20,7 @@ use Kernel::System::Encode;
 use Kernel::System::Crypt;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.29 $';
+$VERSION = '$Revision: 1.31.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -187,6 +187,7 @@ sub Send {
             DBObject => $Self->{DBObject},
             ConfigObject => $Self->{ConfigObject},
             CryptType => $Param{Sign}->{Type},
+            MainObject => $Self->{MainObject},
         );
         if (!$CryptObject) {
             return;
@@ -195,6 +196,7 @@ sub Send {
             Message => $Param{Body},
             Key => $Param{Sign}->{Key},
             Type => 'Clearsign',
+            Charset => $Param{Charset},
         );
         if ($Body) {
             $Param{Body} = $Body;
@@ -207,6 +209,7 @@ sub Send {
             DBObject => $Self->{DBObject},
             ConfigObject => $Self->{ConfigObject},
             CryptType => $Param{Crypt}->{Type},
+            MainObject => $Self->{MainObject},
         );
         if (!$CryptObject) {
             return;
@@ -243,7 +246,7 @@ sub Send {
     $Header{'X-Powered-By'} = 'OTRS - Open Ticket Request System (http://otrs.org/)';
     $Header{'Type'} = $Param{Type} || 'text/plain';
     # define email encoding
-    if ($Param{Charset} && $Param{Charset} =~ /utf(8|-8)/i) {
+    if ( $Param{Charset} && $Param{Charset} =~ /^iso/i ) {
         $Header{'Encoding'} = '8bit';
     }
     else {
@@ -322,6 +325,7 @@ sub Send {
                 Message => $T,
                 Key => $Param{Sign}->{Key},
                 Type => 'Detached',
+                Charset => $Param{Charset},
             );
             # it sign failed, remove singned multi part
             if (!$Sign) {
@@ -594,6 +598,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.29 $ $Date: 2007/07/26 12:56:54 $
+$Revision: 1.31.2.1 $ $Date: 2007/11/05 13:18:11 $
 
 =cut
