@@ -1,8 +1,8 @@
 # --
 # Kernel/System/EmailParser.pm - the global email parser module
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: EmailParser.pm,v 1.47 2006/12/11 06:47:22 martin Exp $
+# $Id: EmailParser.pm,v 1.50 2007/04/12 23:58:08 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -21,7 +21,7 @@ use Mail::Address;
 use Kernel::System::Encode;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.47 $';
+$VERSION = '$Revision: 1.50 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -42,20 +42,20 @@ A module to parse and encode a email.
 
 create a object
 
-  use Kernel::Config;
-  use Kernel::System::Log;
-  use Kernel::System::EmailParser;
+    use Kernel::Config;
+    use Kernel::System::Log;
+    use Kernel::System::EmailParser;
 
-  my $ConfigObject = Kernel::Config->new();
-  my $LogObject    = Kernel::System::Log->new(
-      ConfigObject => $ConfigObject,
-  );
-  my $ParseObject = Kernel::System::EmailParser->new(
-      ConfigObject => $ConfigObject,
-      LogObject => $LogObject,
-      Email => \@ArrayOfEmail,
-      Debug => 0,
-  );
+    my $ConfigObject = Kernel::Config->new();
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $ParseObject = Kernel::System::EmailParser->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+        Email => \@ArrayOfEmail,
+        Debug => 0,
+    );
 
 =cut
 
@@ -89,7 +89,6 @@ sub new {
         # create MIME::Parser object and get message body or body of first attachemnt
         my $Parser = new MIME::Parser;
         $Parser->output_to_core("ALL");
-#        $Parser->output_dir($Self->{ConfigObject}->Get('TempDir'));
         $Self->{ParserParts} = $Parser->parse_data($Self->{Email}->as_string());
     }
     else {
@@ -110,7 +109,7 @@ sub new {
 
 To get a email as a string back (plain email).
 
-  my $Email = $ParseObject->GetPlainEmail();
+    my $Email = $ParseObject->GetPlainEmail();
 
 =cut
 
@@ -124,7 +123,7 @@ sub GetPlainEmail {
 To get a header (e. g. Subject, To, ContentType, ...) of an email
 (mime is already done!).
 
-  my $To = $ParseObject->GetParam(WHAT => 'To');
+    my $To = $ParseObject->GetParam(WHAT => 'To');
 
 =cut
 
@@ -182,7 +181,7 @@ sub GetParam {
 
 To get the senders email address back.
 
-  my $SenderEmail = $ParseObject->GetEmailAddress(Email => 'Juergen Weber <juergen.qeber@air.com>');
+    my $SenderEmail = $ParseObject->GetEmailAddress(Email => 'Juergen Weber <juergen.qeber@air.com>');
 
 =cut
 
@@ -200,7 +199,7 @@ sub GetEmailAddress {
 
 To get an array of email addresses of an To, Cc or Bcc line back.
 
-  my @Addresses = $ParseObject->SplitAddressLine(Line => 'Juergen Weber <juergen.qeber@air.com>, me@example.com, hans@example.com (Hans Huber)');
+    my @Addresses = $ParseObject->SplitAddressLine(Line => 'Juergen Weber <juergen.qeber@air.com>, me@example.com, hans@example.com (Hans Huber)');
 
 This returns an array with ('Juergen Weber <juergen.qeber@air.com>', 'me@example.com', 'hans@example.com (Hans Huber)').
 
@@ -516,7 +515,6 @@ sub PartsAttachments {
         else {
             $PartData{Charset} = 'ISO-8859-1';
         }
-#print STDERR "$PartData{ContentType}:$PartData{MimeType}:$PartData{Charset}\n";
         # get content (if possible)
         if ($Part->bodyhandle()) {
             $PartData{Content} = $Part->bodyhandle()->as_string();
@@ -543,11 +541,23 @@ sub PartsAttachments {
         }
         else {
             $PartData{Filename} = decode_mimewords($Part->head()->recommended_filename());
+            $PartData{ContentDisposition} = $Part->head()->get('Content-Disposition');
+            if ($PartData{ContentDisposition}) {
+               my %Data = $Self->GetContentTypeParams(ContentType => $PartData{ContentDisposition});
+               if ($Data{Charset}) {
+                   $PartData{Charset} = $Data{Charset};
+               }
+            }
+            else {
+                $PartData{Charset} = '';
+            }
             # convert the file name in utf-8 if utf-8 is used
-            $PartData{Filename} = $Self->{EncodeObject}->Decode(
-                Text => $PartData{Filename},
-                From => 'utf-8',
-            );
+            if ($PartData{Charset}) {
+                $PartData{Filename} = $Self->{EncodeObject}->Decode(
+                    Text => $PartData{Filename},
+                    From => $PartData{Charset},
+                );
+            }
         }
         # debug
         if ($Self->{Debug} > 0) {
@@ -568,7 +578,7 @@ sub PartsAttachments {
 
 To get an array of reference ids of the parsed email
 
-  my @References = $ParseObject->GetReferences();
+    my @References = $ParseObject->GetReferences();
 
 This returns an array with ('fasfda@host.de', '4124.2313.1231@host.com').
 
@@ -613,12 +623,24 @@ sub GetContentTypeParams {
         $Param{Charset} =~ s/"|'//g ;
         $Param{Charset} =~ s/(.+?);.*/$1/g;
     }
+    if (!$Param{Charset}) {
+        if ($Param{ContentType} =~ /\?((iso-\d{3,4}-\d{1,2})|(utf-8|utf8))\?/i) {
+            $Param{Charset} = $1;
+        }
+        elsif ($Param{ContentType} =~ /name\*0\*=(utf-8|utf8)/i) {
+            $Param{Charset} = $1;
+        }
+        elsif ($Param{ContentType} =~ /filename\*=((iso-\d{3,4}-\d{1,2})|(utf-8|utf8))''/i) {
+            $Param{Charset} = $1;
+        }
+    }
     if ($Param{ContentType} =~ /^(\w+\/\w+)/i) {
         $Param{MimeType} = $1;
         $Param{MimeType} =~ s/"|'//g ;
     }
     return %Param;
 }
+
 # just for internal
 sub CheckMessageBody {
     my $Self = shift;
@@ -669,8 +691,7 @@ sub CheckMessageBody {
         $Self->{MessageBody} =~ s/\<style.+?\>.*\<\/style\>//gsi;
         $Self->{MessageBody} =~ s/\<br(\/|)\>/\n/gsi;
         $Self->{MessageBody} =~ s/\<(hr|hr.+?)\>/\n\n/gsi;
-        $Self->{MessageBody} =~ s/\<(\/|)(pre|pre.+?|p|p.+?|table|table.+?|code|code.+?)\>/\n\n/gsi
-;
+        $Self->{MessageBody} =~ s/\<(\/|)(pre|pre.+?|p|p.+?|table|table.+?|code|code.+?)\>/\n\n/gsi;
         $Self->{MessageBody} =~ s/\<(tr|tr.+?|th|th.+?)\>/\n\n/gsi;
         $Self->{MessageBody} =~ s/\.+?<\/(td|td.+?)\>/ /gsi;
         $Self->{MessageBody} =~ s/\<.+?\>//gs;
@@ -693,8 +714,11 @@ sub CheckMessageBody {
     }
     return;
 }
+
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -705,6 +729,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.47 $ $Date: 2006/12/11 06:47:22 $
+$Revision: 1.50 $ $Date: 2007/04/12 23:58:08 $
 
 =cut
