@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Log/File.pm - file log backend
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: File.pm,v 1.10 2006/11/02 12:20:55 tr Exp $
+# $Id: File.pm,v 1.12 2007/09/07 09:09:42 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::System::Log::File;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.10 $ ';
+$VERSION = '$Revision: 1.12 $ ';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 umask 002;
@@ -29,7 +29,7 @@ sub new {
 
     # get logfile location
     $Self->{LogFile} = $Param{ConfigObject}->Get('LogModule::LogFile')
-      || die 'Need LogModule::LogFile param in Config.pm';
+        || die 'Need LogModule::LogFile param in Config.pm';
     # get log file suffix
     if ($Param{ConfigObject}->Get('LogModule::LogFile::Date')) {
         my ($s,$m,$h, $D,$M,$Y, $wd,$yd,$dst) = localtime(time());
@@ -38,6 +38,14 @@ sub new {
         $Self->{LogFile} .= ".$Y-$M";
     }
 
+    # Fixed bug# 2265 - For IIS we need to create a own error log file.
+    # Bind stderr to log file, because iis do print stderr to web page.
+    if ($ENV{SERVER_SOFTWARE} && $ENV{SERVER_SOFTWARE} =~ /^microsoft\-iis/i) {
+        if (!open (STDERR, ">> $Self->{LogFile}.error")) {
+            print STDERR "ERROR: Can't write $Self->{LogFile}.error: $!";
+        }
+    }
+
     return $Self;
 }
 
