@@ -1,8 +1,8 @@
 # --
 # Kernel/System/PostMaster/NewTicket.pm - sub part of PostMaster.pm
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: NewTicket.pm,v 1.58 2006/12/08 09:58:22 cs Exp $
+# $Id: NewTicket.pm,v 1.63 2007/03/20 15:18:40 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -16,7 +16,7 @@ use Kernel::System::AutoResponse;
 use Kernel::System::CustomerUser;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.58 $';
+$VERSION = '$Revision: 1.63 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -92,7 +92,6 @@ sub Run {
     }
 
     # get customer user data form From: (sender address)
-
     if (!$GetParam{'X-OTRS-CustomerUser'}) {
         my %CustomerData = ();
         if ($GetParam{'From'}) {
@@ -109,7 +108,7 @@ sub Run {
             );
             foreach (keys %List) {
                 %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
-                  User => $_,
+                    User => $_,
                 );
             }
         }
@@ -120,7 +119,7 @@ sub Run {
             $Self->{LogObject}->Log(
                 Priority => 'notice',
                 Message => "Take UserLogin ($CustomerData{UserLogin}) from ".
-                   "customer source backend based on ($GetParam{'EmailForm'}).",
+                    "customer source backend based on ($GetParam{'EmailForm'}).",
             );
         }
         if ($CustomerData{UserCustomerID} && !$GetParam{'X-OTRS-CustomerNo'}) {
@@ -129,7 +128,7 @@ sub Run {
             $Self->{LogObject}->Log(
                 Priority => 'notice',
                 Message => "Take UserCustomerID ($CustomerData{UserCustomerID})".
-                   " from customer source backend based on ($GetParam{'EmailForm'}).",
+                    " from customer source backend based on ($GetParam{'EmailForm'}).",
             );
         }
     }
@@ -145,18 +144,18 @@ sub Run {
     }
 
     # create new ticket
-
-    my $NewTn = $Self->{TicketObject}->CreateTicketNr();
-
-    # do db insert
+    my $NewTn = $Self->{TicketObject}->TicketCreateNumber();
     my $TicketID = $Self->{TicketObject}->TicketCreate(
         TN => $NewTn,
         Title => $GetParam{Subject},
         QueueID => $QueueID,
-        Lock => 'unlock',
+        Lock => $GetParam{'X-OTRS-Lock'} || 'unlock',
         Priority => $Priority,
         State => $State,
-        CustomerNo => $GetParam{'X-OTRS-CustomerNo'},
+        Type => $GetParam{'X-OTRS-Type'} || '',
+        Service => $GetParam{'X-OTRS-Service'} || '',
+        SLA => $GetParam{'X-OTRS-SLA'} || '',
+        CustomerID => $GetParam{'X-OTRS-CustomerNo'},
         CustomerUser => $GetParam{'X-OTRS-CustomerUser'},
         OwnerID => $Param{InmailUserID},
         UserID => $Param{InmailUserID},
@@ -173,8 +172,25 @@ sub Run {
         print "State: $State\n";
         print "CustomerID: $GetParam{'X-OTRS-CustomerNo'}\n";
         print "CustomerUser: $GetParam{'X-OTRS-CustomerUser'}\n";
+        foreach (qw(Type Service SLA Lock)) {
+            if ($GetParam{'X-OTRS-'.$_}) {
+                print "Type: ".$GetParam{'X-OTRS-'.$_}."\n";
+            }
+        }
+    }
+    # set pending time
+    if ($GetParam{'X-OTRS-State-PendingTime'}) {
+        if ($Self->{TicketObject}->TicketPendingTimeSet(
+            String => $GetParam{'X-OTRS-State-PendingTime'},
+            TicketID => $TicketID,
+            UserID => $Param{InmailUserID},
+        )) {
+            # debug
+            if ($Self->{Debug} > 0) {
+                print "State-PendingTime: $GetParam{'X-OTRS-State-PendingTime'}\n";
+            }
+        }
     }
-
     # set free ticket text
     my @Values = ('X-OTRS-TicketKey', 'X-OTRS-TicketValue');
     my $CounterTmp = 0;
@@ -225,7 +241,7 @@ sub Run {
         $Self->{LogObject}->Log(
             Priority => 'error',
             Message => "Can't process email with MessageID <$GetParam{'Message-ID'}>! ".
-              "Please create a bug report with this email (var/spool/) on http://bugs.otrs.org/!",
+                "Please create a bug report with this email (var/spool/) on http://bugs.otrs.org/!",
         );
         return;
     }
@@ -263,7 +279,6 @@ sub Run {
             }
         }
     }
-
     # write plain email to the storage
     $Self->{TicketObject}->ArticleWritePlain(
         ArticleID => $ArticleID,
