@@ -2,7 +2,7 @@
 # Kernel/System/Ticket/Article.pm - global article module for OTRS kernel
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Article.pm,v 1.142 2007/05/24 11:57:28 martin Exp $
+# $Id: Article.pm,v 1.147 2007/08/22 13:13:52 sb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -18,7 +18,7 @@ use Mail::Internet;
 use Kernel::System::StdAttachment;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.142 $';
+$VERSION = '$Revision: 1.147 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -223,17 +223,22 @@ sub ArticleCreate {
             );
         }
     }
+    # check if latest article is sent to customer
     elsif ($Param{SenderType} eq 'agent' && $Param{ArticleType} =~ /email-ext|phone|fax|sms|note-ext/) {
-        # check if latest article is sent to customer
+        $Self->TicketEscalationResponseTimeUpdate(
+            EscalationResponseTime => $Self->{TimeObject}->SystemTime(),
+            TicketID => $Param{TicketID},
+            UserID => $Param{UserID},
+        );
         $Self->TicketEscalationStartUpdate(
             EscalationStartTime => $Self->{TimeObject}->SystemTime(),
             TicketID => $Param{TicketID},
             UserID => $Param{UserID},
         );
         $Self->TicketUnlockTimeoutUpdate(
-             UnlockTimeout => $Self->{TimeObject}->SystemTime(),
-             TicketID => $Param{TicketID},
-             UserID => $Param{UserID},
+            UnlockTimeout => $Self->{TimeObject}->SystemTime(),
+            TicketID => $Param{TicketID},
+            UserID => $Param{UserID},
         );
     }
     # send auto response
@@ -392,6 +397,12 @@ sub ArticleCreate {
             }
             else {
                 @OwnerIDs = $Self->GetSubscribedUserIDsByQueueID(QueueID => $Ticket{QueueID});
+                foreach (qw(OwnerID ResponsibleID)) {
+                    # do not notify the admin
+                    if ($Ticket{$_} && $Ticket{$_} ne 1) {
+                        push (@OwnerIDs, $Ticket{$_});
+                    }
+                }
             }
             foreach (@OwnerIDs) {
                 if (!$AlreadySent{$_}) {
@@ -978,7 +989,7 @@ sub ArticleLastCustomerArticle {
     my @Index = $Self->ArticleIndex(TicketID => $Param{TicketID}, SenderType => 'customer');
     # get article data
     if (@Index) {
-        return $Self->ArticleGet(ArticleID => $Index[$#Index], TicketOverTime => 1);
+        return $Self->ArticleGet(ArticleID => $Index[$#Index]);
     }
     else {
         my @Index = $Self->ArticleIndex(TicketID => $Param{TicketID});
@@ -987,14 +998,13 @@ sub ArticleLastCustomerArticle {
             foreach (reverse @Index) {
                 my %Article = $Self->ArticleGet(
                     ArticleID => $_,
-                    TicketOverTime => 1,
                 );
                 if ($Article{StateType} eq 'merged' || $Article{ArticleType} !~ /int/) {
                     return %Article;
                 }
             }
             # if we got no internal article, return the latest one
-            return $Self->ArticleGet(ArticleID => $Index[$#Index], TicketOverTime => 1);
+            return $Self->ArticleGet(ArticleID => $Index[$#Index]);
         }
         else {
             $Self->{LogObject}->Log(
@@ -1190,7 +1200,7 @@ sub ArticleGet {
         " st.freekey15, st.freetext15, st.freekey16, st.freetext16, ".
         " st.ticket_lock_id, st.title, st.escalation_start_time, ".
         " st.freetime1 , st.freetime2, st.freetime3, st.freetime4, st.freetime5, st.freetime6, ".
-        " st.type_id, st.service_id, st.sla_id ".
+        " st.type_id, st.service_id, st.sla_id, st.escalation_response_time, st.escalation_solution_time ".
         " FROM ".
         " article sa, ticket st ".
         " WHERE ";
@@ -1219,6 +1229,10 @@ sub ArticleGet {
         $Ticket{Title} = $Data{Title};
         $Data{EscalationStartTime} = $Row[66];
         $Ticket{EscalationStartTime} = $Data{EscalationStartTime};
+        $Data{EscalationResponseTime} = $Row[76];
+        $Ticket{EscalationResponseTime} = $Data{EscalationResponseTime};
+        $Data{EscalationSolutionTime} = $Row[77];
+        $Ticket{EscalationSolutionTime} = $Data{EscalationSolutionTime};
         $Data{From} = $Row[1];
         $Data{To} = $Row[2];
         $Data{Cc} = $Row[3];
@@ -1745,7 +1759,7 @@ sub SendAgentNotification {
     # get notify texts
     foreach (qw(Subject Body)) {
         if (!$Notification{$_}) {
-            $Notification{$_} = "No Notifiaction $_ for $Param{Type} found!";
+            $Notification{$_} = "No Notification $_ for $Param{Type} found!";
         }
     }
     # replace config options
@@ -2005,7 +2019,7 @@ sub SendCustomerNotification {
     # get notify texts
     foreach (qw(Subject Body)) {
         if (!$Notification{$_}) {
-            $Notification{$_} = "No CustomerNotifiaction $_ for $Param{Type} found!";
+            $Notification{$_} = "No CustomerNotification $_ for $Param{Type} found!";
         }
     }
 
