@@ -2,7 +2,7 @@
 # Kernel/System/Ticket/ArticleStorageFS.pm - article storage module for OTRS kernel
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: ArticleStorageFS.pm,v 1.34.2.1 2007/04/05 14:31:09 martin Exp $
+# $Id: ArticleStorageFS.pm,v 1.40 2007/07/23 09:35:09 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,6 +12,7 @@
 package Kernel::System::Ticket::ArticleStorageFS;
 
 use strict;
+use warnings;
 use File::Path;
 use File::Basename;
 use MIME::Words qw(:all);
@@ -21,7 +22,7 @@ use MIME::Base64;
 umask 002;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.34.2.1 $';
+$VERSION = '$Revision: 1.40 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub ArticleStorageInit {
@@ -29,7 +30,7 @@ sub ArticleStorageInit {
     my %Param = @_;
     # ArticleDataDir
     $Self->{ArticleDataDir} = $Self->{ConfigObject}->Get('ArticleDir')
-       || die "Got no ArticleDir!";
+        || die "Got no ArticleDir!";
     # create ArticleContentPath
     my ($Sec, $Min, $Hour, $Day, $Month, $Year) = $Self->{TimeObject}->SystemTime2Date(
         SystemTime => $Self->{TimeObject}->SystemTime(),
@@ -67,10 +68,10 @@ sub ArticleDelete {
     my %Param = @_;
     # check needed stuff
     foreach (qw(TicketID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # delete attachments and plain emails
     my @Articles = $Self->ArticleIndex(TicketID => $Param{TicketID});
@@ -144,10 +145,10 @@ sub ArticleDeletePlain {
     my %Param = @_;
     # check needed stuff
     foreach (qw(ArticleID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # delete attachments
     foreach (qw(ArticleID)) {
@@ -174,10 +175,10 @@ sub ArticleDeleteAttachment {
     my %Param = @_;
     # check needed stuff
     foreach (qw(ArticleID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # delete attachments
     foreach (qw(ArticleID)) {
@@ -190,12 +191,11 @@ sub ArticleDeleteAttachment {
     if (-e $Path) {
         my @List = glob($Path."/*");
         foreach my $File (@List) {
-            $File =~ s!^.*/!!;
-            if ($File !~ /^plain.txt$/) {
-                if (!unlink "$Path/$File") {
+            if ($File !~ /(\/|\\)plain.txt$/) {
+                if (!unlink "$File") {
                     $Self->{LogObject}->Log(
                         Priority => 'error',
-                        Message => "Can't remove: $Path/$File: $!!",
+                        Message => "Can't remove: $File: $!!",
                     );
                 }
             }
@@ -209,10 +209,10 @@ sub ArticleWritePlain {
     my %Param = @_;
     # check needed stuff
     foreach (qw(ArticleID Email UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # prepare/filter ArticleID
     $Param{ArticleID} = quotemeta($Param{ArticleID});
@@ -246,10 +246,10 @@ sub ArticleWriteAttachment {
     my %Param = @_;
     # check needed stuff
     foreach (qw(Content Filename ContentType ArticleID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # prepare/filter ArticleID
     $Param{ArticleID} = quotemeta($Param{ArticleID});
@@ -272,10 +272,10 @@ sub ArticleWriteAttachment {
     for (my $i=1; $i<=12; $i++) {
         if (exists $UsedFile{$NewFileName}) {
             if ($Param{Filename} =~ /^(.*)\.(.+?)$/) {
-               $NewFileName = "$1-$i.$2";
+                $NewFileName = "$1-$i.$2";
             }
             else {
-               $NewFileName = "$Param{Filename}-$i";
+                $NewFileName = "$Param{Filename}-$i";
             }
         }
     }
@@ -287,10 +287,22 @@ sub ArticleWriteAttachment {
             return;
         }
     }
-    # write attachment to fs
+    # write attachment content type to fs
+    if (open (DATA, "> $Param{Path}/$Param{Filename}.content_type")) {
+        binmode(DATA);
+        print DATA $Param{ContentType};
+        close (DATA);
+    }
+    else {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message => "Can't write: $Param{Path}/$Param{Filename}: $!",
+        );
+        return;
+    }
+    # write attachment content to fs
     if (open (DATA, "> $Param{Path}/$Param{Filename}")) {
         binmode(DATA);
-        print DATA "$Param{ContentType}\n";
         print DATA $Param{Content};
         close (DATA);
         return 1;
@@ -309,8 +321,8 @@ sub ArticlePlain {
     my %Param = @_;
     # check needed stuff
     if (!$Param{ArticleID}) {
-      $Self->{LogObject}->Log(Priority => 'error', Message => "Need ArticleID!");
-      return;
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need ArticleID!");
+        return;
     }
     # prepare/filter ArticleID
     $Param{ArticleID} = quotemeta($Param{ArticleID});
@@ -326,8 +338,8 @@ sub ArticlePlain {
             $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
         }
         my $SQL = "SELECT body FROM article_plain ".
-          " WHERE ".
-          " article_id = $Param{ArticleID}";
+            " WHERE ".
+            " article_id = $Param{ArticleID}";
         $Self->{DBObject}->Prepare(SQL => $SQL);
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
             $Data = $Row[0];
@@ -379,45 +391,64 @@ sub ArticleAttachmentIndex {
             Text => $Filename,
             From => 'utf-8',
         );
-        # human readable file size
-        if ($FileSize) {
-            # remove meta data in files
-            $FileSize = $FileSize - 30 if ($FileSize > 30);
-            if ($FileSize > (1024*1024)) {
-                $FileSize = sprintf "%.1f MBytes", ($FileSize/(1024*1024));
-            }
-            elsif ($FileSize > 1024) {
-                $FileSize = sprintf "%.1f KBytes", (($FileSize/1024));
-            }
-            else {
-                $FileSize = $FileSize.' Bytes';
-            }
-        }
-        # read content type
-        my $ContentType = '';
-        if (open(IN, "< $Filename")) {
-            while (<IN>) {
-                if ($ContentType) {
-                    last;
+        if ($Filename !~ /\/plain.txt$/ && $Filename !~ /\.content_type$/) {
+            # human readable file size
+            if ($FileSize) {
+                # remove meta data in files
+                $FileSize = $FileSize - 30 if ($FileSize > 30);
+                if ($FileSize > (1024*1024)) {
+                    $FileSize = sprintf "%.1f MBytes", ($FileSize/(1024*1024));
+                }
+                elsif ($FileSize > 1024) {
+                    $FileSize = sprintf "%.1f KBytes", (($FileSize/1024));
                 }
                 else {
-                    $ContentType = $_;
+                    $FileSize = $FileSize.' Bytes';
                 }
             }
-            close(IN);
+            # read content type
+            my $ContentType = '';
+            if (-e "$Filename.content_type") {
+                if (open(DATA, "$Filename.content_type")) {
+                    while (<DATA>) {
+                        $ContentType .= $_;
+                    }
+                    close(DATA);
+                }
+                else {
+                    $Self->{LogObject}->Log(
+                        Priority => 'error',
+                        Message => "$!: $Filename.content_type!",
+                    );
+                    return;
+                }
+            }
+            # read content type (old style)
+            else {
+                if (open(IN, "< $Filename")) {
+                    while (<IN>) {
+                        if ($ContentType) {
+                            last;
+                        }
+                        else {
+                            $ContentType = $_;
+                        }
+                    }
+                    close(IN);
+                }
+            }
+            # strip filename
+            $Filename =~ s!^.*/!!;
+            if ($Filename ne 'plain.txt') {
+                # add the info the the hash
+                $Counter++;
+                $Index{$Counter} = {
+                    Filename => $Filename,
+                    Filesize => $FileSize,
+                    ContentType => $ContentType,
+                };
+            }
         }
-        # strip filename
-        $Filename =~ s!^.*/!!;
-        if ($Filename ne 'plain.txt') {
-            # add the info the the hash
-            $Counter++;
-            $Index{$Counter} = {
-                Filename => $Filename,
-                Filesize => $FileSize,
-                ContentType => $ContentType,
-            };
-        }
-
     }
     # try database (if there is no index in fs)
     if (!%Index) {
@@ -425,8 +456,8 @@ sub ArticleAttachmentIndex {
             $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
         }
         my $SQL = "SELECT filename, content_type, content_size FROM article_attachment ".
-          " WHERE ".
-          " article_id = $Param{ArticleID} ORDER BY id";
+            " WHERE ".
+            " article_id = $Param{ArticleID} ORDER BY id";
         $Self->{DBObject}->Prepare(SQL => $SQL);
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
             # human readable file size
@@ -458,10 +489,10 @@ sub ArticleAttachment {
     my %Param = @_;
     # check needed stuff
     foreach (qw(ArticleID FileID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # prepare/filter ArticleID
     $Param{ArticleID} = quotemeta($Param{ArticleID});
@@ -475,45 +506,80 @@ sub ArticleAttachment {
     my @List = glob("$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/*");
     if (@List) {
         foreach my $Filename (@List) {
-            if ($Filename !~ /\/plain.txt/) {
+            if ($Filename !~ /\/plain.txt$/ && $Filename !~ /\.content_type$/) {
                 # add the info the the hash
                 $Counter++;
                 if ($Counter == $Param{FileID}) {
-                    if (open (DATA, $Filename)) {
-                        my $Counter = 0;
-                        binmode(DATA);
-                        while (<DATA>) {
-                            $Data{ContentType} = $_ if ($Counter == 0);
-                            $Data{Content} .= $_ if ($Counter > 0);
-                            $Counter++;
+                    # convert the file name in utf-8 if utf-8 is used
+                    $Filename = $Self->{EncodeObject}->Decode(
+                        Text => $Filename,
+                        From => 'utf-8',
+                    );
+                    if (-e "$Filename.content_type") {
+                        if (open(DATA, "$Filename.content_type")) {
+                            while (<DATA>) {
+                                $Data{ContentType} = $_;
+                            }
+                            close(DATA);
+                            if (open(DATA, $Filename)) {
+                                my $Counter = 0;
+                                binmode(DATA);
+                                while (<DATA>) {
+                                    $Data{Content} .= $_;
+                                }
+                                close(DATA);
+                            }
+                            else {
+                                $Self->{LogObject}->Log(
+                                    Priority => 'error',
+                                    Message => "$!: $Filename!",
+                                );
+                                return;
+
+                            }
                         }
-                        close (DATA);
-                        if ($Data{ContentType} =~ /(utf\-8|utf8)/i) {
-                            $Self->{EncodeObject}->Encode(\$Data{Content});
+                        else {
+                            $Self->{LogObject}->Log(
+                                Priority => 'error',
+                                Message => "$!: $Filename.content_type!",
+                            );
+                            return;
                         }
-                        chomp ($Data{ContentType});
-                        return %Data;
                     }
                     else {
-                        $Self->{LogObject}->Log(
-                          Priority => 'error',
-                          Message => "$!: $Filename!",
-                        );
-                        return;
+                        if (open(DATA, $Filename)) {
+                            my $Counter = 0;
+                            binmode(DATA);
+                            while (<DATA>) {
+                                if ($Counter == 0) {
+                                    $Data{ContentType} = $_;
+                                }
+                                else {
+                                    $Data{Content} .= $_;
+                                }
+                                $Counter++;
+                            }
+                            close(DATA);
+                        }
                     }
+                    if ($Data{ContentType} =~ /plain\/text/i && $Data{ContentType} =~ /(utf\-8|utf8)/i) {
+                        $Self->{EncodeObject}->Encode(\$Data{Content});
+                    }
+                    chomp ($Data{ContentType});
+                    return %Data;
                 }
             }
         }
     }
-    else {
+    if (!%Data) {
         # try database
         foreach (qw(ArticleID)) {
             $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
         }
         my $SQL = "SELECT content_type, content FROM article_attachment ".
-          " WHERE ".
-          " article_id = $Param{ArticleID}";
-        $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Param{FileID});
+            " WHERE ".
+            " article_id = $Param{ArticleID}";
+        $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Param{FileID}, Encode => [1,0]);
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
             $Data{ContentType} = $Row[0];
             # decode attachemnt if it's e. g. a postgresql backend!!!
@@ -529,8 +595,8 @@ sub ArticleAttachment {
         }
         else {
             $Self->{LogObject}->Log(
-              Priority => 'error',
-              Message => "$!: $Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/$Data{Filename}!",
+                Priority => 'error',
+                Message => "$!: $Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/$Data{Filename}!",
             );
             return;
         }
