@@ -2,7 +2,7 @@
 # Ticket/Number/AutoIncrement.pm - a ticket number auto increment generator
 # Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AutoIncrement.pm,v 1.16 2006/12/05 08:04:03 martin Exp $
+# $Id: AutoIncrement.pm,v 1.18 2006/12/21 11:17:05 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -19,16 +19,18 @@ package Kernel::System::Ticket::Number::AutoIncrement;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.16 $';
+$VERSION = '$Revision: 1.18 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-sub CreateTicketNr {
+sub TicketCreateNumber {
     my $Self = shift;
     my $JumpCounter = shift || 0;
     # get needed config options
     my $CounterLog = $Self->{ConfigObject}->Get('Ticket::CounterLog');
     my $SystemID = $Self->{ConfigObject}->Get('SystemID');
-    my $MinSize = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::AutoIncrement::MinCounterSize') || $Self->{ConfigObject}->Get('Ticket::NumberGenerator::MinCounterSize') || 5;
+    my $MinSize = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::AutoIncrement::MinCounterSize')
+        || $Self->{ConfigObject}->Get('Ticket::NumberGenerator::MinCounterSize')
+        || 5;
     # read count
     my $Count = 0;
     if (-f $CounterLog) {
@@ -38,8 +40,8 @@ sub CreateTicketNr {
         close (DATA);
         if ($Self->{Debug} > 0) {
             $Self->{LogObject}->Log(
-              Priority => 'debug',
-              Message => "Read counter from $CounterLog: $Count",
+                Priority => 'debug',
+                Message => "Read counter from $CounterLog: $Count",
             );
         }
     }
@@ -53,8 +55,8 @@ sub CreateTicketNr {
         close (DATA);
         if ($Self->{Debug} > 0) {
             $Self->{LogObject}->Log(
-              Priority => 'debug',
-              Message => "Write counter: $Count",
+                Priority => 'debug',
+                Message => "Write counter: $Count",
             );
         }
     }
@@ -72,35 +74,41 @@ sub CreateTicketNr {
     # create new ticket number
     my $Tn = $SystemID . $Count;
     # Check ticket number. If exists generate new one!
-    if ($Self->CheckTicketNr(Tn=>$Tn)) {
+    if ($Self->TicketCheckNumber(Tn=>$Tn)) {
         $Self->{LoopProtectionCounter}++;
         if ($Self->{LoopProtectionCounter} >= 6000) {
-          # loop protection
-          $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!".
-                   " Stoped CreateTicketNr()!",
-          );
-          return;
+            # loop protection
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!".
+                    " Stoped TicketCreateNumber()!",
+            );
+            return;
         }
         # create new ticket number again
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "Tn ($Tn) exists! Creating new one.",
+            Priority => 'notice',
+            Message => "Tn ($Tn) exists! Creating a new one.",
         );
-        $Tn = $Self->CreateTicketNr($Self->{LoopProtectionCounter});
+        $Tn = $Self->TicketCreateNumber($Self->{LoopProtectionCounter});
     }
     return $Tn;
 }
-# --
+
 sub GetTNByString {
     my $Self = shift;
     my $String = shift || return;
     # get needed config options
-    my $SystemID = $Self->{ConfigObject}->Get('SystemID');
+    my $CheckSystemID = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::CheckSystemID');
+    my $SystemID = '';
+    if ($CheckSystemID) {
+        $SystemID = $Self->{ConfigObject}->Get('SystemID');
+    }
     my $TicketHook = $Self->{ConfigObject}->Get('Ticket::Hook');
     my $TicketHookDivider = $Self->{ConfigObject}->Get('Ticket::HookDivider');
-    my $MinSize = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::AutoIncrement::MinCounterSize') || $Self->{ConfigObject}->Get('Ticket::NumberGenerator::MinCounterSize') || 5;
+    my $MinSize = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::AutoIncrement::MinCounterSize')
+        || $Self->{ConfigObject}->Get('Ticket::NumberGenerator::MinCounterSize')
+        || 5;
     my $MaxSize = $MinSize + 5;
     # check ticket number
     if ($String =~ /\Q$TicketHook$TicketHookDivider\E($SystemID\d{$MinSize,$MaxSize})/i) {
@@ -115,5 +123,5 @@ sub GetTNByString {
         }
     }
 }
-# --
+
 1;
