@@ -1,8 +1,8 @@
 # --
 # Ticket/Number/Date.pm - a date ticket number generator
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Date.pm,v 1.16 2006/12/05 08:04:03 martin Exp $
+# $Id: Date.pm,v 1.20 2007/04/12 23:51:04 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -19,10 +19,10 @@ package Kernel::System::Ticket::Number::Date;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.16 $';
+$VERSION = '$Revision: 1.20 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-sub CreateTicketNr {
+sub TicketCreateNumber {
     my $Self = shift;
     my $JumpCounter = shift || 0;
     # get needed config options
@@ -42,8 +42,8 @@ sub CreateTicketNr {
         # just debug
         if ($Self->{Debug} > 0) {
             $Self->{LogObject}->Log(
-              Priority => 'debug',
-              Message => "Read counter from $CounterLog: $Count",
+                Priority => 'debug',
+                Message => "Read counter from $CounterLog: $Count",
             );
         }
     }
@@ -57,8 +57,8 @@ sub CreateTicketNr {
         close (DATA);
         if ($Self->{Debug} > 0) {
             $Self->{LogObject}->Log(
-              Priority => 'debug',
-              Message => "Write counter: $Count",
+                Priority => 'debug',
+                Message => "Write counter: $Count",
             );
         }
     }
@@ -72,40 +72,45 @@ sub CreateTicketNr {
     # create new ticket number
     my $Tn = $Year.$Month.$Day.$SystemID.$Count;
     # Check ticket number. If exists generate new one!
-    if ($Self->CheckTicketNr(Tn=>$Tn)) {
+    if ($Self->TicketCheckNumber(Tn=>$Tn)) {
         $Self->{LoopProtectionCounter}++;
         if ($Self->{LoopProtectionCounter} >= 6000) {
-          # loop protection
-          $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!".
-                   " Stoped CreateTicketNr()!",
-          );
-          return;
+            # loop protection
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!".
+                    " Stoped TicketCreateNumber()!",
+            );
+            return;
         }
         # create new ticket number again
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "Tn ($Tn) exists! Creating new one.",
+            Priority => 'notice',
+            Message => "Tn ($Tn) exists! Creating a new one.",
         );
-        $Tn = $Self->CreateTicketNr($Self->{LoopProtectionCounter});
+        $Tn = $Self->TicketCreateNumber($Self->{LoopProtectionCounter});
     }
     return $Tn;
 }
-# --
+
 sub GetTNByString {
     my $Self = shift;
     my $String = shift || return;
     # get needed config options
+    my $CheckSystemID = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::CheckSystemID');
+    my $SystemID = '';
+    if ($CheckSystemID) {
+        $SystemID = $Self->{ConfigObject}->Get('SystemID');
+    }
     my $TicketHook = $Self->{ConfigObject}->Get('Ticket::Hook');
     my $TicketHookDivider = $Self->{ConfigObject}->Get('Ticket::HookDivider');
     # check current setting
-    if ($String =~ /\Q$TicketHook$TicketHookDivider\E(\d{8,40})/i) {
+    if ($String =~ /\Q$TicketHook$TicketHookDivider\E(\d{4,10}$SystemID\d{1,40})/i) {
         return $1;
     }
     else {
         # check default setting
-        if ($String =~ /\Q$TicketHook\E:+.{0,1}(\d{8,40})/i) {
+        if ($String =~ /\Q$TicketHook\E:+.{0,2}(\d{4,10}$SystemID\d{1,40})/i) {
             return $1;
         }
         else {
@@ -113,5 +118,5 @@ sub GetTNByString {
         }
     }
 }
-# --
+
 1;
