@@ -1,17 +1,18 @@
 # --
 # Ticket/Number/DateChecksum.pm - a date ticket number generator
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # Copyright (C) 2002 Stefan Schmidt <jsj@jsj.dyndns.org>
 # --
-# $Id: DateChecksum.pm,v 1.17 2006/12/05 08:04:03 martin Exp $
+# $Id: DateChecksum.pm,v 1.21 2007/01/29 16:18:46 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 # --
+
 # Note:
 # available objects are: ConfigObject, LogObject and DBObject
-# --
+#
 # The algorithm to calculate the checksum is derived from the one
 # Deutsche Bundesbahn (german railway company) uses for calculation
 # of the check digit of their vehikel numbering.
@@ -20,19 +21,18 @@
 # vehikel number. The modulus to 10 of this sum is substracted from
 # 10. See: http://www.pruefziffernberechnung.de/F/Fahrzeugnummer.shtml
 # (german)
-# --
+#
 # Generates ticket numbers like yyyymmddssID#####C (e. g. 2002062310100011)
-# --
 
 package Kernel::System::Ticket::Number::DateChecksum;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.17 $';
+$VERSION = '$Revision: 1.21 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-sub CreateTicketNr {
+sub TicketCreateNumber {
     my $Self = shift;
     my $JumpCounter = shift || 0;
     # get needed config options
@@ -53,8 +53,8 @@ sub CreateTicketNr {
         # just debug
         if ($Self->{Debug} > 0) {
             $Self->{LogObject}->Log(
-              Priority => 'debug',
-              Message => "Read counter from $CounterLog: $Count",
+                Priority => 'debug',
+                Message => "Read counter from $CounterLog: $Count",
             );
         }
     }
@@ -73,8 +73,8 @@ sub CreateTicketNr {
         # just debug
         if ($Self->{Debug} > 0) {
             $Self->{LogObject}->Log(
-              Priority => 'debug',
-              Message => "Write counter: $Count",
+                Priority => 'debug',
+                Message => "Write counter: $Count",
             );
         }
     }
@@ -93,58 +93,63 @@ sub CreateTicketNr {
     # create new ticket number
     my $Tn = $Year.$Month.$Day.$SystemID.$Count;
     # calculate a checksum
-    my $chksum = 0;
-    my $mult = 1;
+    my $ChkSum = 0;
+    my $Mult = 1;
     for ( my $i = 0; $i<length($Tn); ++$i ) {
         my $Digit = substr( $Tn, $i, 1 );
-        $chksum = $chksum + ( $mult * $Digit );
-        $mult += 1;
-        if ( $mult == 3 ) {
-          $mult = 1;
+        $ChkSum = $ChkSum + ( $Mult * $Digit );
+        $Mult += 1;
+        if ( $Mult == 3 ) {
+            $Mult = 1;
         }
     }
-    $chksum %= 10;
-    $chksum = 10 - $chksum;
-    if ($chksum == 10) {
-        $chksum = 1;
+    $ChkSum %= 10;
+    $ChkSum = 10 - $ChkSum;
+    if ($ChkSum == 10) {
+        $ChkSum = 1;
     }
     # add checksum to ticket number
-    $Tn = $Tn.$chksum;
+    $Tn = $Tn.$ChkSum;
     # Check ticket number. If exists generate new one!
-    if ($Self->CheckTicketNr(Tn=>$Tn)) {
+    if ($Self->TicketCheckNumber(Tn=>$Tn)) {
         $Self->{LoopProtectionCounter}++;
         if ($Self->{LoopProtectionCounter} >= 6000) {
-          # loop protection
-          $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!".
-                   " Stoped CreateTicketNr()!",
-          );
-          return;
+            # loop protection
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message => "CounterLoopProtection is now $Self->{LoopProtectionCounter}!".
+                    " Stoped TicketCreateNumber()!",
+            );
+            return;
         }
         # create new ticket number again
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "Tn ($Tn) exists! Creating new one.",
+            Priority => 'notice',
+            Message => "Tn ($Tn) exists! Creating a new one.",
         );
-        $Tn = $Self->CreateTicketNr($Self->{LoopProtectionCounter});
+        $Tn = $Self->TicketCreateNumber($Self->{LoopProtectionCounter});
     }
     return $Tn;
 }
-# --
+
 sub GetTNByString {
     my $Self = shift;
     my $String = shift || return;
     # get needed config options
+    my $CheckSystemID = $Self->{ConfigObject}->Get('Ticket::NumberGenerator::CheckSystemID');
+    my $SystemID = '';
+    if ($CheckSystemID) {
+        $SystemID = $Self->{ConfigObject}->Get('SystemID');
+    }
     my $TicketHook = $Self->{ConfigObject}->Get('Ticket::Hook');
     my $TicketHookDivider = $Self->{ConfigObject}->Get('Ticket::HookDivider');
     # check current setting
-    if ($String =~ /\Q$TicketHook$TicketHookDivider\E(\d{8,40})/i) {
+    if ($String =~ /\Q$TicketHook$TicketHookDivider\E(\d{4,10}$SystemID\d{4,40})/i) {
         return $1;
     }
     else {
         # check default setting
-        if ($String =~ /\Q$TicketHook\E:+.{0,1}(\d{8,40})/i) {
+        if ($String =~ /\Q$TicketHook\E:+.{0,2}(\d{4,10}$SystemID\d{4,40})/i) {
             return $1;
         }
         else {
@@ -152,5 +157,5 @@ sub GetTNByString {
         }
     }
 }
-# --
+
 1;
