@@ -2,7 +2,7 @@
 # Kernel/System/Time.pm - time functions
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Time.pm,v 1.18.2.1 2007/01/18 10:37:16 martin Exp $
+# $Id: Time.pm,v 1.29.2.1 2007/11/06 10:38:19 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -16,7 +16,7 @@ use Time::Local;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = '$Revision: 1.18.2.1 $';
+$VERSION = '$Revision: 1.29.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -35,10 +35,10 @@ This module is managing time functions.
 
 =item new()
 
-create a language object
+create a time object
 
     use Kernel::Config;
-    use Kernel::System::Time;
+    use Kernel::System::Log;
 
     my $ConfigObject = Kernel::Config->new();
 
@@ -99,10 +99,10 @@ sub SystemTime {
 returns a time stamp in "yyyy-mm-dd 23:59:59" format.
 
     my $TimeStamp = $TimeObject->SystemTime2TimeStamp(
-        SystemTime => $SystenTime,
+        SystemTime => $SystemTime,
     );
 
-Also if needed a short form "23:59:59" if the date is today (if needed).
+If you need the short format "23:59:59" if the date is today (if needed).
 
     my $TimeStamp = $TimeObject->SystemTime2TimeStamp(
         SystemTime => $SystemTime,
@@ -143,7 +143,7 @@ sub SystemTime2TimeStamp {
 
 returns a time stamp in "yyyy-mm-dd 23:59:59" format.
 
-    my $TimeStamp  = $TimeObject->CurrentTimestamp();
+    my $TimeStamp = $TimeObject->CurrentTimestamp();
 
 =cut
 
@@ -179,15 +179,14 @@ sub SystemTime2Date {
     my ($Sec, $Min, $Hour, $Day, $Month, $Year, $WDay) = localtime($Param{SystemTime});
     $Year = $Year+1900;
     $Month = $Month+1;
-    $Month  = "0$Month" if ($Month <10);
-    $Day  = "0$Day" if ($Day <10);
-    $Hour  = "0$Hour" if ($Hour <10);
-    $Min  = "0$Min" if ($Min <10);
-    $Sec  = "0$Sec" if ($Sec <10);
+    $Month = "0$Month" if ($Month <10);
+    $Day = "0$Day" if ($Day <10);
+    $Hour = "0$Hour" if ($Hour <10);
+    $Min = "0$Min" if ($Min <10);
+    $Sec = "0$Sec" if ($Sec <10);
 
     return ($Sec, $Min, $Hour, $Day, $Month, $Year, $WDay);
 }
-1;
 
 =item TimeStamp2SystemTime()
 
@@ -537,7 +536,7 @@ sub DestinationTime {
     $AYear = $AYear+1900;
     $AMonth = $AMonth+1;
     my $ADate = "$AYear-$AMonth-$ADay";
-$Param{Time}++;
+    $Param{Time}++;
 
     while ($Param{Time} > 1) {
         $Count++;
@@ -629,20 +628,33 @@ $Param{Time}++;
                             );
                         }
 #                        $Param{Time} = $Param{Time} - (60*60);
-                        $DestinationTime = $DestinationTime + (60*60);
+                        if ($Param{Time} > 59) {
+                            $DestinationTime = $DestinationTime + (60*60);
+                        }
 #print STDERR "DD NOHIT DestinationTime : ".$Self->SystemTime2TimeStamp(SystemTime => $DestinationTime)." $Param{Time} \n";
                     }
                 }
             }
         }
-        $CTime = $Self->Date2SystemTime(
-            Year => $Year,
-            Month => $Month,
-            Day => $Day,
-            Hour => 0,
+        # Find the unix time stamp for the next day at 00:00:00 to
+        # start for calculation.
+        my $NewCTime = $Self->Date2SystemTime(
+            Year   => $Year,
+            Month  => $Month,
+            Day    => $Day,
+            Hour   => 0,
             Minute => 0,
             Second => 0,
-        )+(60*60*24);
+        ) + ( 60 * 60 * 24 );
+        # Protect local time zone problems on your machine
+        # (e. g. sommer zeit / winter zeit) and not geting
+        # over to the next day.
+        if ($NewCTime == $CTime) {
+            $CTime = $CTime + ( 60 * 60 * 24 );
+        }
+        else {
+            $CTime = $NewCTime;
+        }
     }
     $DestinationTime = $DestinationTime - $Zone;
     return $DestinationTime;
@@ -654,9 +666,9 @@ check if the selected day is a vacation (it doesn't matter if you
 insert 01 or 1 for month or day in the function or in the SysConfig)
 
     $TimeAccountingObject->VacationCheck(
-        Year  => 2005,
+        Year => 2005,
         Month => 7 || '07',
-        Day   => 13,
+        Day => 13,
     );
 
 =cut
@@ -671,13 +683,13 @@ sub VacationCheck {
         if (!$Param{$_}) {
             $Self->{LogObject}->Log(
                 Priority => 'error',
-                Message  => "VacationCheck: Need $_!"
+                Message => "VacationCheck: Need $_!"
             );
             return;
         }
     }
     $Param{Month} = sprintf("%02d", $Param{Month});
-    $Param{Day}   = sprintf("%02d", $Param{Day});
+    $Param{Day} = sprintf("%02d", $Param{Day});
 
     my $TimeVacationDays = $Self->{ConfigObject}->Get('TimeVacationDays');
     my $TimeVacationDaysOneTime = $Self->{ConfigObject}->Get('TimeVacationDaysOneTime');
@@ -712,6 +724,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.18.2.1 $ $Date: 2007/01/18 10:37:16 $
+$Revision: 1.29.2.1 $ $Date: 2007/11/06 10:38:19 $
 
 =cut
