@@ -2,7 +2,7 @@
 # Kernel/System/User.pm - some user functions
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: User.pm,v 1.55.2.2 2007/03/15 09:42:35 martin Exp $
+# $Id: User.pm,v 1.64 2007/04/24 11:05:19 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,11 +13,12 @@ package Kernel::System::User;
 
 use strict;
 use Kernel::System::CheckItem;
+use Kernel::System::Valid;
 use Digest::MD5;
 use Crypt::PasswdMD5 qw(unix_md5_crypt);
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.55.2.2 $';
+$VERSION = '$Revision: 1.64 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -38,24 +39,37 @@ All user functions. E. g. to add and updated user and other functions.
 
 create a object
 
-  use Kernel::Config;
-  use Kernel::System::Log;
-  use Kernel::System::DB;
-  use Kernel::System::User;
+    use Kernel::Config;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::Time;
+    use Kernel::System::DB;
+    use Kernel::System::User;
 
-  my $ConfigObject = Kernel::Config->new();
-  my $LogObject    = Kernel::System::Log->new(
-      ConfigObject => $ConfigObject,
-  );
-  my $DBObject = Kernel::System::DB->new(
-      ConfigObject => $ConfigObject,
-      LogObject => $LogObject,
-  );
-  my $UserObject = Kernel::System::User->new(
-      ConfigObject => $ConfigObject,
-      LogObject => $LogObject,
-      DBObject => $DBObject,
-  );
+    my $ConfigObject = Kernel::Config->new();
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $TimeObject = Kernel::System::Time->new(
+        MainObject => $MainObject,
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        MainObject => $MainObject,
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+    my $UserObject = Kernel::System::User->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+        MainObject => $MainObject,
+        TimeObject => $TimeObject,
+        DBObject => $DBObject,
+    );
 
 =cut
 
@@ -67,24 +81,20 @@ sub new {
     my $Self = {};
     bless ($Self, $Type);
     # check needed objects
-    foreach (qw(DBObject ConfigObject LogObject)) {
+    foreach (qw(DBObject ConfigObject LogObject TimeObject MainObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
-    # get user table
-    $Self->{UserTable} = $Self->{ConfigObject}->Get('DatabaseUserTable')
-      || 'user';
-    $Self->{UserTableUserID} = $Self->{ConfigObject}->Get('DatabaseUserTableUserID')
-      || 'id';
-    $Self->{UserTableUserPW} = $Self->{ConfigObject}->Get('DatabaseUserTableUserPW')
-      || 'pw';
-    $Self->{UserTableUser} = $Self->{ConfigObject}->Get('DatabaseUserTableUser')
-      || 'login';
-    # load generator customer preferences module
-    my $GeneratorModule = $Self->{ConfigObject}->Get('User::PreferencesModule')
-      || 'Kernel::System::User::Preferences::DB';
-    eval "require $GeneratorModule";
-    $Self->{PreferencesObject} = $GeneratorModule->new(%Param);
+    $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
 
+    # get user table
+    $Self->{UserTable} = $Self->{ConfigObject}->Get('DatabaseUserTable') || 'user';
+    $Self->{UserTableUserID} = $Self->{ConfigObject}->Get('DatabaseUserTableUserID') || 'id';
+    $Self->{UserTableUserPW} = $Self->{ConfigObject}->Get('DatabaseUserTableUserPW') || 'pw';
+    $Self->{UserTableUser} = $Self->{ConfigObject}->Get('DatabaseUserTableUser') || 'login';
+    # load generator customer preferences module
+    my $GeneratorModule = $Self->{ConfigObject}->Get('User::PreferencesModule') || 'Kernel::System::User::Preferences::DB';
+    $Self->{MainObject}->Require($GeneratorModule);
+    $Self->{PreferencesObject} = $GeneratorModule->new(%Param);
     $Self->{CheckItemObject} = Kernel::System::CheckItem->new(%Param);
 
     return $Self;
@@ -126,7 +136,7 @@ sub GetUserData {
         }
     }
     my %Data;
-    # get inital data
+    # get initial data
     my $SQL = "SELECT $Self->{UserTableUserID}, $Self->{UserTableUser}, ".
         " salutation, first_name, last_name, $Self->{UserTableUserPW}, valid_id ".
         " FROM " .
@@ -168,7 +178,7 @@ sub GetUserData {
     # check valid, return if there is locked for valid users
     if ($Param{Valid}) {
         my $Hit = 0;
-        foreach ($Self->{DBObject}->GetValidIDs()) {
+        foreach ($Self->{ValidObject}->ValidIDsGet()) {
             if ($_ eq $Data{ValidID}) {
                 $Hit = 1;
             }
@@ -198,15 +208,15 @@ sub GetUserData {
 
 to add new users
 
-  my $UserID = $UserObject->UserAdd(
-      Firstname => 'Huber',
-      Lastname => 'Manfred',
-      Login => 'mhuber',
-      Pw => 'some-pass', # not required
-      Email => 'email@example.com',
-      ValidID => 1,
-      UserID => 123,
-  );
+    my $UserID = $UserObject->UserAdd(
+        UserFirstname => 'Huber',
+        UserLastname => 'Manfred',
+        UserLogin => 'mhuber',
+        UserPw => 'some-pass', # not required
+        UserEmail => 'email@example.com',
+        ValidID => 1,
+        ChangeUserID => 123,
+    );
 
 =cut
 
@@ -214,48 +224,48 @@ sub UserAdd {
     my $Self = shift;
     my %Param = @_;
     # check needed stuff
-    foreach (qw(Firstname Lastname Login ValidID UserID Email)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+    foreach (qw(UserFirstname UserLastname UserLogin UserEmail ValidID ChangeUserID)) {
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # check email address
-    if ($Param{Email} && !$Self->{CheckItemObject}->CheckEmail(Address => $Param{Email})) {
+    if ($Param{UserEmail} && !$Self->{CheckItemObject}->CheckEmail(Address => $Param{UserEmail})) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message => "Email address ($Param{Email}) not valid (".
-              $Self->{CheckItemObject}->CheckError().")!",
+            Message => "Email address ($Param{UserEmail}) not valid (".
+                $Self->{CheckItemObject}->CheckError().")!",
         );
         return;
     }
     # check password
-    if (!$Param{Pw}) {
-        $Param{Pw} = $Self->GenerateRandomPassword();
+    if (!$Param{UserPw}) {
+        $Param{UserPw} = $Self->GenerateRandomPassword();
     }
     # quote params
-    foreach (qw(Salutation Firstname Lastname Login Pw)) {
+    foreach (qw(UserSalutation UserFirstname UserLastname UserLogin UserPw)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
-    foreach (qw(ValidID UserID)) {
+    foreach (qw(ValidID ChangeUserID)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
     my $SQL = "INSERT INTO $Self->{UserTable} " .
-       "(salutation, " .
-       " first_name, " .
-       " last_name, " .
-       " $Self->{UserTableUser}, " .
-       " $Self->{UserTableUserPW}, " .
-       " valid_id, create_time, create_by, change_time, change_by)" .
-       " VALUES " .
-       " ('$Param{Salutation}', " .
-       " '$Param{Firstname}', " .
-       " '$Param{Lastname}', " .
-       " '$Param{Login}', " .
-       " '$Param{Pw}', " .
-       " $Param{ValidID}, current_timestamp, $Param{UserID}, ".
-       " current_timestamp, $Param{UserID})";
+        "(salutation, " .
+        " first_name, " .
+        " last_name, " .
+        " $Self->{UserTableUser}, " .
+        " $Self->{UserTableUserPW}, " .
+        " valid_id, create_time, create_by, change_time, change_by)" .
+        " VALUES " .
+        " ('$Param{UserSalutation}', " .
+        " '$Param{UserFirstname}', " .
+        " '$Param{UserLastname}', " .
+        " '$Param{UserLogin}', " .
+        " '$Param{UserPw}', " .
+        " $Param{ValidID}, current_timestamp, $Param{ChangeUserID}, ".
+        " current_timestamp, $Param{ChangeUserID})";
 
     if ($Self->{DBObject}->Do(SQL => $SQL)) {
         # get new user id
@@ -263,7 +273,7 @@ sub UserAdd {
             " FROM " .
             " $Self->{UserTable} " .
             " WHERE " .
-            " LOWER($Self->{UserTableUser}) = LOWER('$Param{Login}')";
+            " LOWER($Self->{UserTableUser}) = LOWER('$Param{UserLogin}')";
         my $UserID = '';
         $Self->{DBObject}->Prepare(SQL => $SQL);
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
@@ -272,12 +282,12 @@ sub UserAdd {
         # log notice
         $Self->{LogObject}->Log(
             Priority => 'notice',
-            Message => "User: '$Param{Login}' ID: '$UserID' created successfully ($Param{UserID})!",
+            Message => "User: '$Param{UserLogin}' ID: '$UserID' created successfully ($Param{ChangeUserID})!",
         );
         # set password
-        $Self->SetPassword(UserLogin => $Param{Login}, PW => $Param{Pw});
+        $Self->SetPassword(UserLogin => $Param{UserLogin}, PW => $Param{UserPw});
         # set email address
-        $Self->SetPreferences(UserID => $UserID, Key => 'UserEmail', Value => $Param{Email});
+        $Self->SetPreferences(UserID => $UserID, Key => 'UserEmail', Value => $Param{UserEmail});
         return $UserID;
     }
     else {
@@ -289,16 +299,16 @@ sub UserAdd {
 
 to update users
 
-  $UserObject->UserUpdate(
-      ID => 4321,
-      Firstname => 'Huber',
-      Lastname => 'Manfred',
-      Login => 'mhuber',
-      Pw => 'some-pass', # not required
-      Email => 'email@example.com',
-      ValidID => 1,
-      UserID => 123,
-  );
+    $UserObject->UserUpdate(
+        UserID => 4321,
+        UserFirstname => 'Huber',
+        UserLastname => 'Manfred',
+        UserLogin => 'mhuber',
+        UserPw => 'some-pass', # not required
+        UserEmail => 'email@example.com',
+        ValidID => 1,
+        ChangeUserID => 123,
+    );
 
 =cut
 
@@ -306,53 +316,53 @@ sub UserUpdate {
     my $Self = shift;
     my %Param = @_;
     # check needed stuff
-    foreach (qw(ID Firstname Lastname Login ValidID UserID Email)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+    foreach (qw(UserID UserFirstname UserLastname UserLogin ValidID UserID ChangeUserID)) {
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # check email address
-    if ($Param{Email} && !$Self->{CheckItemObject}->CheckEmail(Address => $Param{Email})) {
+    if ($Param{UserEmail} && !$Self->{CheckItemObject}->CheckEmail(Address => $Param{UserEmail})) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message => "Email address ($Param{Email}) not valid (".
+            Message => "Email address ($Param{UserEmail}) not valid (".
                 $Self->{CheckItemObject}->CheckError().")!",
         );
         return;
     }
     # get old user data (pw)
-    my %UserData = $Self->GetUserData(UserID => $Param{ID});
+    my %UserData = $Self->GetUserData(UserID => $Param{UserID});
     # quote params
-    foreach (qw(Salutation Firstname Lastname)) {
+    foreach (qw(UserSalutation UserFirstname UserLastname)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
-    foreach (qw(ID ValidID UserID)) {
+    foreach (qw(ID ValidID UserID ChangeUserID)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # update db
     my $SQL = "UPDATE $Self->{UserTable} SET " .
-        " salutation = '$Param{Salutation}', " .
-        " first_name = '$Param{Firstname}'," .
-        " last_name = '$Param{Lastname}', " .
-        " $Self->{UserTableUser} = '$Param{Login}', " .
+        " salutation = '$Param{UserSalutation}', " .
+        " first_name = '$Param{UserFirstname}'," .
+        " last_name = '$Param{UserLastname}', " .
+        " $Self->{UserTableUser} = '$Param{UserLogin}', " .
         " valid_id = $Param{ValidID}, " .
         " change_time = current_timestamp, " .
-        " change_by = $Param{UserID} " .
-        " WHERE $Self->{UserTableUserID} = $Param{ID}";
+        " change_by = $Param{ChangeUserID} " .
+        " WHERE $Self->{UserTableUserID} = $Param{UserID}";
 
     if ($Self->{DBObject}->Do(SQL => $SQL)) {
         # log notice
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "User: '$Param{Login}' updated successfully ($Param{UserID})!",
+            Priority => 'notice',
+            Message => "User: '$Param{UserLogin}' updated successfully ($Param{ChangeUserID})!",
         );
         # check pw
-        if ($Param{Pw}) {
-            $Self->SetPassword(UserLogin => $Param{Login}, PW => $Param{Pw});
+        if ($Param{UserPw}) {
+            $Self->SetPassword(UserLogin => $Param{UserLogin}, PW => $Param{UserPw});
         }
         # set email address
-        $Self->SetPreferences(UserID => $Param{ID}, Key => 'UserEmail', Value => $Param{Email});
+        $Self->SetPreferences(UserID => $Param{UserID}, Key => 'UserEmail', Value => $Param{UserEmail});
         return 1;
     }
     else {
@@ -364,20 +374,21 @@ sub UserUpdate {
 
 to search users
 
-  my %List = $UserObject->UserSearch(
-      Search => '*some*', # also 'hans+huber' possible
-      ValidID => 1, # not required
-  );
+    my %List = $UserObject->UserSearch(
+        Search => '*some*', # also 'hans+huber' possible
+        Valid => 1, # not required
+    );
 
-  my %List = $UserObject->UserSearch(
-      UserLogin => '*some*',
-      ValidID => 1, # not required
-  );
+    my %List = $UserObject->UserSearch(
+        UserLogin => '*some*',
+        Limit => 50,
+        Valid => 1, # not required
+    );
 
-  my %List = $UserObject->UserSearch(
-      PostMasterSearch => 'email@example.com',
-      ValidID => 1, # not required
-  );
+    my %List = $UserObject->UserSearch(
+        PostMasterSearch => 'email@example.com',
+        Valid => 1, # not required
+    );
 
 =cut
 
@@ -392,8 +403,8 @@ sub UserSearch {
         return;
     }
     # build SQL string 1/2
-    my $SQL = "SELECT $Self->{UserTableUser} ";
-    my @Fields = ('first_name', 'last_name');
+    my $SQL = "SELECT $Self->{UserTableUserID} ";
+    my @Fields = qw(login first_name last_name);
     if (@Fields) {
         foreach my $Entry (@Fields) {
             $SQL .= ", $Entry";
@@ -401,13 +412,13 @@ sub UserSearch {
     }
     # build SQL string 2/2
     $SQL .= " FROM " .
-      " $Self->{UserTable} ".
-      " WHERE ";
+        " $Self->{UserTable} ".
+        " WHERE ";
     if ($Param{Search}) {
         my $Count = 0;
         my @Parts = split(/\+/, $Param{Search}, 6);
         foreach my $Part (@Parts) {
-            $Part = $Self->{SearchPrefix}.$Part.$Self->{SearchSuffix};
+#            $Part = $Self->{SearchPrefix}.$Part.$Self->{SearchSuffix};
             $Part =~ s/\*/%/g;
             $Part =~ s/%%/%/g;
             if ($Count) {
@@ -450,17 +461,17 @@ sub UserSearch {
     }
     # add valid option
     if ($Valid) {
-        $SQL .= "AND valid_id IN ( ${\(join ', ', $Self->{DBObject}->GetValidIDs())} ) ";
+        $SQL .= "AND valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} ) ";
     }
     # get data
-    $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Self->{UserSearchListLimit});
+    $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Self->{UserSearchListLimit} || $Param{Limit});
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
-         foreach (1..8) {
-             if ($Row[$_]) {
-                  $Users{$Row[0]} .= $Row[$_].' ';
-             }
-         }
-         $Users{$Row[0]} =~ s/^(.*)\s(.+?\@.+?\..+?)(\s|)$/"$1" <$2>/;
+        foreach (1..8) {
+            if ($Row[$_]) {
+                $Users{$Row[0]} .= $Row[$_].' ';
+            }
+        }
+        $Users{$Row[0]} =~ s/^(.*)\s(.+?\@.+?\..+?)(\s|)$/"$1" <$2>/;
     }
     return %Users;
 }
@@ -469,10 +480,10 @@ sub UserSearch {
 
 to set users passwords
 
-  $UserObject->SetPassword(
-      UserLogin => 'some-login',
-      PW => 'some-new-password'
-  );
+    $UserObject->SetPassword(
+        UserLogin => 'some-login',
+        PW => 'some-new-password'
+    );
 
 =cut
 
@@ -495,6 +506,10 @@ sub SetPassword {
     my $CryptedPw = '';
     # md5 pw
     if ($Self->{ConfigObject}->Get('AuthModule::DB::CryptType') &&
+        $Self->{ConfigObject}->Get('AuthModule::DB::CryptType') eq 'plain') {
+        $CryptedPw = $Pw;
+    }
+    elsif ($Self->{ConfigObject}->Get('AuthModule::DB::CryptType') &&
         $Self->{ConfigObject}->Get('AuthModule::DB::CryptType') eq 'md5') {
         $CryptedPw = unix_md5_crypt($Pw, $Param{UserLogin});
     }
@@ -536,11 +551,11 @@ sub SetPassword {
     my $NewPw = $Self->{DBObject}->Quote($CryptedPw);
     # update db
     if ($Self->{DBObject}->Do(
-            SQL => "UPDATE $Self->{UserTable} ".
-               " SET ".
-               " $Self->{UserTableUserPW} = '$NewPw' ".
-               " WHERE ".
-               " LOWER($Self->{UserTableUser}) = LOWER('$Param{UserLogin}')",
+        SQL => "UPDATE $Self->{UserTable} ".
+            " SET ".
+            " $Self->{UserTableUserPW} = '$NewPw' ".
+            " WHERE ".
+            " LOWER($Self->{UserTableUser}) = LOWER('$Param{UserLogin}')",
     )) {
         # log notice
         $Self->{LogObject}->Log(
@@ -558,13 +573,13 @@ sub SetPassword {
 
 user login or id lookup
 
-  my $UserLogin = $UserObject->UserLookup(
-      UserID => 1,
-  );
+    my $UserLogin = $UserObject->UserLookup(
+        UserID => 1,
+    );
 
-  my $UserID = $UserObject->UserLookup(
-      UserLogin => 1,
-  );
+    my $UserID = $UserObject->UserLookup(
+        UserLogin => 1,
+    );
 
 =cut
 
@@ -642,15 +657,15 @@ sub UserLookup {
 
 get user name
 
-  my $Name = $UserObject->UserName(
-      UserLogin => 'some-login',
-  );
+    my $Name = $UserObject->UserName(
+        UserLogin => 'some-login',
+    );
 
-  or
+    or
 
-  my $Name = $UserObject->UserName(
-      UserID => 123,
-  );
+    my $Name = $UserObject->UserName(
+        UserID => 123,
+    );
 
 =cut
 
@@ -670,10 +685,10 @@ sub UserName {
 
 return a hash with all users
 
-  my %List = $UserObject->UserList(
-      Type => 'Short', # Short|Long
-      Valid => 1, # not required
-  );
+    my %List = $UserObject->UserList(
+        Type => 'Short', # Short|Long
+        Valid => 1, # not required
+    );
 
 =cut
 
@@ -704,13 +719,13 @@ sub UserList {
 
 generate a random password
 
-  my $Password = $UserObject->GenerateRandomPassword();
+    my $Password = $UserObject->GenerateRandomPassword();
 
-  or
+    or
 
-  my $Password = $UserObject->GenerateRandomPassword(
-      Size => 16,
-  );
+    my $Password = $UserObject->GenerateRandomPassword(
+        Size => 16,
+    );
 
 =cut
 
@@ -741,11 +756,11 @@ sub GenerateRandomPassword {
 
 set user preferences
 
-  $UserObject->SetPreferences(
-      Key => 'UserComment',
-      Value => 'some comment',
-      UserID => 123,
-  );
+    $UserObject->SetPreferences(
+        Key => 'UserComment',
+        Value => 'some comment',
+        UserID => 123,
+    );
 
 =cut
 
@@ -758,9 +773,9 @@ sub SetPreferences {
 
 get user preferences
 
-  my %Preferences = $UserObject->GetPreferences(
-      UserID => 123,
-  );
+    my %Preferences = $UserObject->GetPreferences(
+        UserID => 123,
+    );
 
 =cut
 
@@ -773,10 +788,10 @@ sub GetPreferences {
 
 search in user preferences
 
-  my %UserList = $Self->SearchPreferences(
-      Key => 'UserEmail',
-      Value => 'email@example.com',
-  );
+    my %UserList = $UserObject->SearchPreferences(
+        Key => 'UserEmail',
+        Value => 'email@example.com',
+    );
 
 =cut
 
@@ -787,6 +802,8 @@ sub SearchPreferences {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -799,6 +816,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.55.2.2 $ $Date: 2007/03/15 09:42:35 $
+$Revision: 1.64 $ $Date: 2007/04/24 11:05:19 $
 
 =cut
