@@ -2,7 +2,7 @@
 # Kernel/System/Web/InterfaceAgent.pm - the agent interface file (incl. auth)
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: InterfaceAgent.pm,v 1.17.2.1 2007/01/04 14:54:11 martin Exp $
+# $Id: InterfaceAgent.pm,v 1.23 2007/09/07 09:12:46 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::System::Web::InterfaceAgent;
 use strict;
 
 use vars qw($VERSION @INC);
-$VERSION = '$Revision: 1.17.2.1 $';
+$VERSION = '$Revision: 1.23 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # all framework needed modules
@@ -29,7 +29,6 @@ use Kernel::System::Auth;
 use Kernel::System::AuthSession;
 use Kernel::System::User;
 use Kernel::System::Group;
-use Kernel::System::Permission;
 use Kernel::Output::HTML::Layout;
 
 =head1 NAME
@@ -50,10 +49,10 @@ the global agent web interface (incl. auth, session, ...)
 
 create agent web interface object
 
-  use Kernel::System::Web::InterfaceAgent;
+    use Kernel::System::Web::InterfaceAgent;
 
-  my $Debug = 0;
-  my $InterfaceAgent = Kernel::System::Web::InterfaceAgent->new(Debug => $Debug);
+    my $Debug = 0;
+    my $InterfaceAgent = Kernel::System::Web::InterfaceAgent->new(Debug => $Debug);
 
 =cut
 
@@ -99,7 +98,7 @@ sub new {
 
 execute the object
 
-  $InterfaceAgent->Run();
+    $InterfaceAgent->Run();
 
 =cut
 
@@ -123,7 +122,7 @@ sub Run {
     };
     foreach my $Key (keys %{$FramworkPrams}) {
         $Param{$Key} = $Self->{ParamObject}->GetParam(Param => $Key)
-          || $FramworkPrams->{$Key};
+            || $FramworkPrams->{$Key};
     }
 
     # Check if the brwoser sends the SessionID cookie and set the SessionID-cookie
@@ -131,12 +130,12 @@ sub Run {
     if ($Self->{ConfigObject}->Get('SessionUseCookie')) {
         $Param{SessionIDCookie} = $Self->{ParamObject}->GetCookie(Key => $Param{SessionName});
         if ($Param{SessionIDCookie}) {
-           $Param{SessionID} = $Param{SessionIDCookie};
+            $Param{SessionID} = $Param{SessionIDCookie};
         }
     }
 
     # create common framework objects 2/3
-        $Self->{LayoutObject} = Kernel::Output::HTML::Layout->new(
+    $Self->{LayoutObject} = Kernel::Output::HTML::Layout->new(
         %{$Self},
         Lang => $Param{Lang},
     );
@@ -144,27 +143,20 @@ sub Run {
     # check common objects
     $Self->{DBObject} = Kernel::System::DB->new(%{$Self});
     if (!$Self->{DBObject}) {
-        print $Self->{LayoutObject}->Header(Area => 'Core', Title => 'Error!');
-        print $Self->{LayoutObject}->Error(
+        $Self->{LayoutObject}->FatalError(
             Comment => 'Please contact your admin'
         );
-        print $Self->{LayoutObject}->Footer();
-        exit (1);
     }
     if ($Self->{ParamObject}->Error()) {
-        print $Self->{LayoutObject}->Header(Area => 'Core', Title => 'Error!');
-        print $Self->{LayoutObject}->Error(
+        $Self->{LayoutObject}->FatalError(
             Message => $Self->{ParamObject}->Error(),
             Comment => 'Please contact your admin'
         );
-         print $Self->{LayoutObject}->Footer();
-        exit (1);
     }
 
     # create common framework objects 3/3
     $Self->{UserObject} = Kernel::System::User->new(%{$Self});
     $Self->{GroupObject} = Kernel::System::Group->new(%{$Self});
-    $Self->{PermissionObject} = Kernel::System::Permission->new(%{$Self});
     $Self->{SessionObject} = Kernel::System::AuthSession->new(%{$Self});
 
     # application and add on application common objects
@@ -175,10 +167,9 @@ sub Run {
         }
         else {
             # print error
-            print $Self->{LayoutObject}->Header(Area => 'Core', Title => 'Error!');
-            print $Self->{LayoutObject}->Error();
-            print $Self->{LayoutObject}->Footer();
-            exit;
+            $Self->{LayoutObject}->FatalError(
+                Comment => 'Please contact your admin'
+            );
         }
     }
 
@@ -212,10 +203,12 @@ sub Run {
                 }
                 else {
                     # show need user data error message
-                    print $Self->{LayoutObject}->Login(
-                        Title => 'Panic!',
-                        Message => 'Panic! No UserData!!!',
-                        %Param,
+                    $Self->{LayoutObject}->Print(
+                        Output =>  \$Self->{LayoutObject}->Login(
+                            Title => 'Panic!',
+                            Message => 'Panic! No UserData!!!',
+                            %Param,
+                        ),
                     );
                     exit (0);
                 }
@@ -306,27 +299,28 @@ sub Run {
                 # redirect to alternate login
                 $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
                 print $Self->{LayoutObject}->Redirect(
-                     ExtURL => $Self->{ConfigObject}->Get('LoginURL').
-                       "?Reason=LoginFailed&RequestedURL=$Param{RequestedURL}",
+                    ExtURL => $Self->{ConfigObject}->Get('LoginURL').
+                        "?Reason=LoginFailed&RequestedURL=$Param{RequestedURL}",
                 );
             }
             else {
                 # show normal login
-                print $Self->{LayoutObject}->Login(
-                    Title => 'Login',
-                    Message => $Self->{LogObject}->GetLogEntry(
-                        Type => 'Info',
-                        What => 'Message',
-                        ) || 'Login failed! Your username or password was entered incorrectly.',
-                    User => $User,
-                    %Param,
+                $Self->{LayoutObject}->Print(
+                    Output =>  \$Self->{LayoutObject}->Login(
+                        Title => 'Login',
+                        Message => $Self->{LogObject}->GetLogEntry(
+                            Type => 'Info',
+                            What => 'Message',
+                            ) || 'Login failed! Your username or password was entered incorrectly.',
+                        User => $User,
+                        %Param,
+                    ),
                 );
             }
         }
     }
-
     # Logout
-    elsif ($Param{Action} eq "Logout"){
+    elsif ($Param{Action} eq "Logout") {
         if ($Self->{SessionObject}->CheckSessionID(SessionID => $Param{SessionID})) {
             # get session data
             my %UserData = $Self->{SessionObject}->GetSessionIDData(
@@ -334,44 +328,40 @@ sub Run {
             );
             # create new LayoutObject with new '%Param' and '%UserData'
             $Self->{LayoutObject} = Kernel::Output::HTML::Layout->new(
-              SetCookies => {
-                  SessionIDCookie => $Self->{ParamObject}->SetCookie(
-                      Key => $Param{SessionName},
-                      Value => '',
-                  ),
-              },
-              %{$Self},
-              %Param,
-              %UserData,
+                SetCookies => {
+                    SessionIDCookie => $Self->{ParamObject}->SetCookie(
+                        Key => $Param{SessionName},
+                        Value => '',
+                    ),
+                },
+                %{$Self},
+                %Param,
+                %UserData,
             );
             # remove session id
             if ($Self->{SessionObject}->RemoveSessionID(SessionID => $Param{SessionID})) {
                 if ($Self->{ConfigObject}->Get('LogoutURL')) {
                     # redirect to alternate login
                     print $Self->{LayoutObject}->Redirect(
-                         ExtURL => $Self->{ConfigObject}->Get('LogoutURL')."?Reason=Logout",
+                        ExtURL => $Self->{ConfigObject}->Get('LogoutURL')."?Reason=Logout",
                     );
                 }
                 else {
                     # show logout screen
-                    print $Self->{LayoutObject}->Login(
-                        Title => 'Logout',
-                        Message => 'Logout successful. Thank you for using OTRS!',
-                        %Param,
+                    $Self->{LayoutObject}->Print(
+                        Output =>  \$Self->{LayoutObject}->Login(
+                            Title => 'Logout',
+                            Message => 'Logout successful. Thank you for using OTRS!',
+                            %Param,
+                        ),
                     );
                 }
             }
             else {
-                print $Self->{LayoutObject}->Header(Title => 'Logout');
-                print $Self->{LayoutObject}->Error(
+                $Self->{LayoutObject}->FatalError(
                     Message => 'Can`t remove SessionID',
-                    Comment => 'Please contact your admin!'
+                    Comment => 'Please contact your admin'
                 );
-                $Self->{LogObject}->Log(
-                    Message => 'Can`t remove SessionID',
-                    Priority => 'error',
-                );
-                print $Self->{LayoutObject}->Footer();
             }
         }
         else {
@@ -380,28 +370,31 @@ sub Run {
                 $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
                 print $Self->{LayoutObject}->Redirect(
                     ExtURL => $Self->{ConfigObject}->Get('LoginURL').
-                      "?Reason=InvalidSessionID&RequestedURL=$Param{RequestedURL}",
+                        "?Reason=InvalidSessionID&RequestedURL=$Param{RequestedURL}",
                 );
             }
             else {
                 # show login screen
-                print $Self->{LayoutObject}->Login(
-                    Title => 'Logout',
-                    Message => 'Invalid SessionID!',
-                    %Param,
+                $Self->{LayoutObject}->Print(
+                    Output =>  \$Self->{LayoutObject}->Login(
+                        Title => 'Logout',
+                        Message => 'Invalid SessionID!',
+                        %Param,
+                    ),
                 );
             }
         }
     }
-
     # user lost password
-    elsif ($Param{Action} eq "LostPassword"){
+    elsif ($Param{Action} eq "LostPassword") {
         # check feature
         if (! $Self->{ConfigObject}->Get('LostPassword')) {
             # show normal login
-            print $Self->{LayoutObject}->Login(
-               Title => 'Login',
-               Message => 'Feature not active!',
+            $Self->{LayoutObject}->Print(
+                Output =>  \$Self->{LayoutObject}->Login(
+                    Title => 'Login',
+                    Message => 'Feature not active!',
+                ),
             );
             exit 0;
         }
@@ -411,10 +404,12 @@ sub Run {
         my %UserData = $Self->{UserObject}->GetUserData(User => $User, Valid => 1);
         if (! $UserData{UserID}) {
             # show normal login
-            print $Self->{LayoutObject}->Login(
-                Title => 'Login',
-                Message => 'There is no account with that login name.',
-                %Param,
+            $Self->{LayoutObject}->Print(
+                Output =>  \$Self->{LayoutObject}->Login(
+                    Title => 'Login',
+                    Message => 'There is no account with that login name.',
+                    %Param,
+                ),
             );
             exit 0;
         }
@@ -426,9 +421,9 @@ sub Run {
             # send notify email
             my $EmailObject = Kernel::System::Email->new(%{$Self});
             my $Body = $Self->{ConfigObject}->Get('NotificationBodyLostPassword')
-              || "New Password is: <OTRS_NEWPW>";
+                || "New Password is: <OTRS_NEWPW>";
             my $Subject = $Self->{ConfigObject}->Get('NotificationSubjectLostPassword')
-              || 'New Password!';
+                || 'New Password!';
             foreach (keys %UserData) {
                 $Body =~ s/<OTRS_$_>/$UserData{$_}/gi;
             }
@@ -437,24 +432,25 @@ sub Run {
                 Subject => $Subject,
                 Charset => 'iso-8859-15',
                 Type => 'text/plain',
-                Body => $Body)) {
-                    print $Self->{LayoutObject}->Login(
+                Body => $Body)
+            ) {
+                $Self->{LayoutObject}->Print(
+                    Output =>  \$Self->{LayoutObject}->Login(
                         Title => 'Login',
                         Message => "Sent new password to: ".$UserData{"UserEmail"},
                         User => $User,
                         %Param,
-                    );
-                    exit 0;
+                    ),
+                );
+                exit 0;
             }
             else {
-                print $Self->{LayoutObject}->Header(Area => 'Core', Title => 'Error!');
-                print $Self->{LayoutObject}->Error();
-                print $Self->{LayoutObject}->Footer();
-                exit 0;
+                $Self->{LayoutObject}->FatalError(
+                    Comment => 'Please contact your admin'
+                );
             }
         }
     }
-
     # show login site
     elsif (!$Param{SessionID}) {
         # create AuthObject
@@ -471,60 +467,62 @@ sub Run {
             $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
             print $Self->{LayoutObject}->Redirect(
                 ExtURL => $Self->{ConfigObject}->Get('LoginURL').
-                 "?RequestedURL=$Param{RequestedURL}",
+                    "?RequestedURL=$Param{RequestedURL}",
             );
         }
         else {
             # login screen
-            print $Self->{LayoutObject}->Login(
-                Title => 'Login',
-                %Param,
+            $Self->{LayoutObject}->Print(
+                Output =>  \$Self->{LayoutObject}->Login(
+                    Title => 'Login',
+                    %Param,
+                ),
             );
         }
     }
-
     # run modules if exists a version value
     elsif ($Self->{MainObject}->Require("Kernel::Modules::$Param{Action}")) {
         # check session id
         if ( !$Self->{SessionObject}->CheckSessionID(SessionID => $Param{SessionID}) ) {
             # create new LayoutObject with new '%Param'
             $Self->{LayoutObject} = Kernel::Output::HTML::Layout->new(
-              SetCookies => {
-                  SessionIDCookie => $Self->{ParamObject}->SetCookie(
-                      Key => $Param{SessionName},
-                      Value => '',
-                  ),
-              },
-              %{$Self},
-              %Param,
+                SetCookies => {
+                    SessionIDCookie => $Self->{ParamObject}->SetCookie(
+                        Key => $Param{SessionName},
+                        Value => '',
+                    ),
+                },
+                %{$Self},
+                %Param,
             );
             # create AuthObject
             my $AuthObject = Kernel::System::Auth->new(%{$Self});
             if ($AuthObject->GetOption(What => 'PreAuth')) {
                 # automatic re-login
                 $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
-                 print $Self->{LayoutObject}->Redirect(
-                      OP => "?Action=Login&RequestedURL=$Param{RequestedURL}",
-                 );
+                print $Self->{LayoutObject}->Redirect(
+                    OP => "?Action=Login&RequestedURL=$Param{RequestedURL}",
+                );
             }
             elsif ($Self->{ConfigObject}->Get('LoginURL')) {
                 # redirect to alternate login
                 $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
                 print $Self->{LayoutObject}->Redirect(
-                     ExtURL => $Self->{ConfigObject}->Get('LoginURL').
-                       "?Reason=InvalidSessionID&RequestedURL=$Param{RequestedURL}",
+                    ExtURL => $Self->{ConfigObject}->Get('LoginURL').
+                        "?Reason=InvalidSessionID&RequestedURL=$Param{RequestedURL}",
                 );
             }
             else {
                 # show login
-                print $Self->{LayoutObject}->Login(
-                    Title => 'Login',
-                    Message => $Self->{SessionObject}->CheckSessionIDMessage(),
-                    %Param,
+                $Self->{LayoutObject}->Print(
+                    Output =>  \$Self->{LayoutObject}->Login(
+                        Title => 'Login',
+                        Message => $Self->{SessionObject}->CheckSessionIDMessage(),
+                        %Param,
+                    ),
                 );
             }
         }
-
         # run module
         else {
             # get session data
@@ -541,10 +539,12 @@ sub Run {
                 }
                 else {
                     # show login screen
-                    print $Self->{LayoutObject}->Login(
-                        Title => 'Panic!',
-                        Message => 'Panic! Invalid Session!!!',
-                        %Param,
+                    $Self->{LayoutObject}->Print(
+                        Output =>  \$Self->{LayoutObject}->Login(
+                            Title => 'Panic!',
+                            Message => 'Panic! Invalid Session!!!',
+                            %Param,
+                        ),
                     );
                     exit (0);
                 }
@@ -556,10 +556,9 @@ sub Run {
                     Priority => 'error',
                     Message => "Module Kernel::Modules::$Param{Action} not registered in Kernel/Config.pm!",
                 );
-                print $Self->{LayoutObject}->Header(Area => 'Core', Title => 'Error!');
-                print $Self->{LayoutObject}->Error();
-                print $Self->{LayoutObject}->Footer();
-                exit 0;
+                $Self->{LayoutObject}->FatalError(
+                    Comment => 'Please contact your admin'
+                );
             }
             # module permisson check
             if (!$ModuleReg->{GroupRo} && !$ModuleReg->{Group}) {
@@ -640,7 +639,7 @@ sub Run {
                         );
                         my $Output = $PreModuleObject->PreRun();
                         if ($Output) {
-                            print $PreModuleObject->PreRun();
+                            $Self->{LayoutObject}->Print(Output => \$Output);
                             exit (0);
                         }
                     }
@@ -668,7 +667,7 @@ sub Run {
                 );
             }
             # ->Run $Action with $GenericObject
-            print $GenericObject->Run();
+            $Self->{LayoutObject}->Print(Output => \$GenericObject->Run());
             # log request time
             if ($Self->{ConfigObject}->Get('PerformanceLog')) {
                 if ((!$QueryString && $Param{Action}) || ($QueryString !~ /Action=/)) {
@@ -692,7 +691,6 @@ sub Run {
             }
         }
     }
-
     # else print an error screen
     else {
         # create new LayoutObject with '%Param'
@@ -705,11 +703,10 @@ sub Run {
             %Data,
         );
         # print error
-        print $Self->{LayoutObject}->Header(Area => 'Core', Title => 'Error!');
-        print $Self->{LayoutObject}->Error();
-        print $Self->{LayoutObject}->Footer();
+        $Self->{LayoutObject}->FatalError(
+            Comment => 'Please contact your admin'
+        );
     }
-
     # debug info
     if ($Self->{Debug}) {
         $Self->{LogObject}->Log(
@@ -717,7 +714,6 @@ sub Run {
             Message => 'Global handle stopped.',
         );
     }
-
     # db disconnect && undef %Param
     $Self->{DBObject}->Disconnect();
     undef %Param;
@@ -725,6 +721,8 @@ sub Run {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -737,6 +735,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.17.2.1 $ $Date: 2007/01/04 14:54:11 $
+$Revision: 1.23 $ $Date: 2007/09/07 09:12:46 $
 
 =cut
