@@ -2,7 +2,7 @@
 # Kernel/System/Web/UploadCache/DB.pm - a db upload cache
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: DB.pm,v 1.6.2.1 2007/03/12 23:55:51 martin Exp $
+# $Id: DB.pm,v 1.9 2007/05/07 08:29:23 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -16,7 +16,7 @@ use MIME::Base64;
 
 use vars qw($VERSION);
 
-$VERSION = '$Revision: 1.6.2.1 $ ';
+$VERSION = '$Revision: 1.9 $ ';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -47,10 +47,10 @@ sub FormIDRemove {
     my $Self = shift;
     my %Param = @_;
     foreach (qw(FormID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     return $Self->{DBObject}->Do(
         SQL => "DELETE FROM web_upload_cache WHERE form_id = '$Param{FormID}'",
@@ -61,10 +61,10 @@ sub FormIDAddFile {
     my $Self = shift;
     my %Param = @_;
     foreach (qw(FormID Filename Content ContentType)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # get file size
     {
@@ -73,13 +73,13 @@ sub FormIDAddFile {
         no bytes;
     }
     # encode attachemnt if it's a postgresql backend!!!
-    $Self->{EncodeObject}->EncodeOutput(\$Param{Content});
     if (!$Self->{DBObject}->GetDatabaseFunction('DirectBlob')) {
+        $Self->{EncodeObject}->EncodeOutput(\$Param{Content});
         $Param{Content} = encode_base64($Param{Content});
     }
     # db quote (just not Content, use db Bind values)
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) if ($_ ne 'Content');
+    foreach (qw(FormID Filename ContentType Filesize)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
     }
     my $SQL = "INSERT INTO web_upload_cache ".
         " (form_id, filename, content_type, content_size, content, ".
@@ -95,19 +95,20 @@ sub FormIDRemoveFile {
     my $Self = shift;
     my %Param = @_;
     foreach (qw(FormID FileID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     my @Index = @{$Self->FormIDGetAllFilesMeta(%Param)};
     my $ID = $Param{FileID}-1;
+    $Param{Filename} = $Index[$ID]->{Filename};
     # db quote
-    foreach (keys %Param) {
+    foreach (qw(FormID Filename)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
     }
     return $Self->{DBObject}->Do(
-        SQL => "DELETE FROM web_upload_cache WHERE form_id = '$Param{FormID}' AND filename = '$Index[$ID]->{Filename}'",
+        SQL => "DELETE FROM web_upload_cache WHERE form_id = '$Param{FormID}' AND filename = '$Param{Filename}'",
     );
 }
 
@@ -117,16 +118,16 @@ sub FormIDGetAllFilesData {
     my $Counter = 0;
     my @Data = ();
     foreach (qw(FormID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     my $SQL = "SELECT filename, content_type, content_size, content FROM web_upload_cache ".
         " WHERE ".
         " form_id = '".$Self->{DBObject}->Quote($Param{FormID})."'".
         " ORDER BY create_time_unix";
-    $Self->{DBObject}->Prepare(SQL => $SQL);
+    $Self->{DBObject}->Prepare(SQL => $SQL, Encode => [1,1,1,0]);
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
         $Counter++;
         # human readable file size
@@ -144,7 +145,6 @@ sub FormIDGetAllFilesData {
         # encode attachemnt if it's a postgresql backend!!!
         if (!$Self->{DBObject}->GetDatabaseFunction('DirectBlob')) {
             $Row[3] = decode_base64($Row[3]);
-            $Self->{EncodeObject}->Encode(\$Row[3]);
         }
         # add the info
         push (@Data, {
@@ -164,10 +164,10 @@ sub FormIDGetAllFilesMeta {
     my $Counter = 0;
     my @Data = ();
     foreach (qw(FormID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     my $SQL = "SELECT filename, content_type, content_size FROM web_upload_cache ".
         " WHERE ".
