@@ -17,7 +17,6 @@ use Apache::Registry ();       # for things in the "/programs" URL
 use CGI (); CGI->compile(':cgi');
 use CGI::Carp ();
 
-#use Apache ();
 #use Apache::DBI ();
 #Apache::DBI->connect_on_init('DBI:mysql:otrs', 'otrs', 'some-pass');
 use DBI ();
@@ -48,7 +47,6 @@ use Kernel::System::AuthSession::DB;
 #use Kernel::System::AuthSession::FS;
 use Kernel::System::User;
 use Kernel::System::User::Preferences::DB;
-use Kernel::System::Permission;
 #use Kernel::System::PDF;
 use Kernel::System::XML;
 use Kernel::System::Log;
