@@ -1,10 +1,13 @@
 # ----------------------------------------------------------
-#  database: mysql, generated: Mon Aug 28 00:13:13 2006
+#  driver: mysql, generated: 2007-06-12 16:52:19
 # ----------------------------------------------------------
 ALTER TABLE valid ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
 ALTER TABLE valid ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
 ALTER TABLE ticket_priority ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
 ALTER TABLE ticket_priority ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
+ALTER TABLE ticket_type ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
+ALTER TABLE ticket_type ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
+ALTER TABLE ticket_type ADD FOREIGN KEY (valid_id) REFERENCES `valid(id)`;
 ALTER TABLE ticket_lock_type ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
 ALTER TABLE ticket_lock_type ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
 ALTER TABLE ticket_lock_type ADD FOREIGN KEY (valid_id) REFERENCES `valid(id)`;
@@ -64,14 +67,17 @@ ALTER TABLE queue ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
 ALTER TABLE queue ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
 ALTER TABLE queue ADD FOREIGN KEY (valid_id) REFERENCES `valid(id)`;
 ALTER TABLE ticket ADD FOREIGN KEY (ticket_lock_id) REFERENCES `ticket_lock_type(id)`;
-ALTER TABLE ticket ADD FOREIGN KEY (ticket_state_id) REFERENCES `ticket_state(id)`;
 ALTER TABLE ticket ADD FOREIGN KEY (ticket_priority_id) REFERENCES `ticket_priority(id)`;
-ALTER TABLE ticket ADD FOREIGN KEY (queue_id) REFERENCES `queue(id)`;
 ALTER TABLE ticket ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
 ALTER TABLE ticket ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
 ALTER TABLE ticket ADD FOREIGN KEY (user_id) REFERENCES `system_user(id)`;
 ALTER TABLE ticket ADD FOREIGN KEY (responsible_user_id) REFERENCES `system_user(id)`;
+ALTER TABLE ticket ADD FOREIGN KEY (service_id) REFERENCES `service(id)`;
 ALTER TABLE ticket ADD FOREIGN KEY (valid_id) REFERENCES `valid(id)`;
+ALTER TABLE ticket ADD FOREIGN KEY (sla_id) REFERENCES `sla(id)`;
+ALTER TABLE ticket ADD FOREIGN KEY (ticket_state_id) REFERENCES `ticket_state(id)`;
+ALTER TABLE ticket ADD FOREIGN KEY (queue_id) REFERENCES `queue(id)`;
+ALTER TABLE ticket ADD FOREIGN KEY (type_id) REFERENCES `ticket_type(id)`;
 ALTER TABLE ticket_history ADD FOREIGN KEY (priority_id) REFERENCES `ticket_priority(id)`;
 ALTER TABLE ticket_history ADD FOREIGN KEY (owner_id) REFERENCES `system_user(id)`;
 ALTER TABLE ticket_history ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
@@ -81,6 +87,7 @@ ALTER TABLE ticket_history ADD FOREIGN KEY (state_id) REFERENCES `ticket_state(i
 ALTER TABLE ticket_history ADD FOREIGN KEY (history_type_id) REFERENCES `ticket_history_type(id)`;
 ALTER TABLE ticket_history ADD FOREIGN KEY (article_id) REFERENCES `article(id)`;
 ALTER TABLE ticket_history ADD FOREIGN KEY (queue_id) REFERENCES `queue(id)`;
+ALTER TABLE ticket_history ADD FOREIGN KEY (type_id) REFERENCES `ticket_type(id)`;
 ALTER TABLE ticket_history ADD FOREIGN KEY (ticket_id) REFERENCES `ticket(id)`;
 ALTER TABLE ticket_history_type ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
 ALTER TABLE ticket_history_type ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
@@ -134,6 +141,12 @@ ALTER TABLE time_accounting ADD FOREIGN KEY (create_by) REFERENCES `system_user(
 ALTER TABLE time_accounting ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
 ALTER TABLE time_accounting ADD FOREIGN KEY (article_id) REFERENCES `article(id)`;
 ALTER TABLE time_accounting ADD FOREIGN KEY (ticket_id) REFERENCES `ticket(id)`;
+ALTER TABLE service ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
+ALTER TABLE service ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
+ALTER TABLE service_customer_user ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
+ALTER TABLE sla ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
+ALTER TABLE sla ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
+ALTER TABLE sla ADD FOREIGN KEY (service_id) REFERENCES `service(id)`;
 ALTER TABLE customer_user ADD FOREIGN KEY (create_by) REFERENCES `system_user(id)`;
 ALTER TABLE customer_user ADD FOREIGN KEY (change_by) REFERENCES `system_user(id)`;
 ALTER TABLE customer_user ADD FOREIGN KEY (valid_id) REFERENCES `valid(id)`;
