@@ -1,5 +1,5 @@
 -- ----------------------------------------------------------
---  database: mssql, generated: Wed Mar 14 10:37:53 2007
+--  driver: mssql, generated: 2007-07-26 15:10:15
 -- ----------------------------------------------------------
 -- ----------------------------------------------------------
 --  create table valid
@@ -20,6 +20,21 @@ CREATE TABLE valid (
 CREATE TABLE ticket_priority (
     id SMALLINT NOT NULL IDENTITY(1,1) ,
     name VARCHAR (50) NOT NULL,
+    valid_id SMALLINT NOT NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (name)
+);
+-- ----------------------------------------------------------
+--  create table ticket_type
+-- ----------------------------------------------------------
+CREATE TABLE ticket_type (
+    id SMALLINT NOT NULL IDENTITY(1,1) ,
+    name VARCHAR (50) NOT NULL,
+    valid_id SMALLINT NOT NULL,
     create_time DATETIME NOT NULL,
     create_by INTEGER NOT NULL,
     change_time DATETIME NOT NULL,
@@ -272,7 +287,9 @@ CREATE TABLE queue (
     name VARCHAR (200) NOT NULL,
     group_id INTEGER NOT NULL,
     unlock_timeout INTEGER,
-    escalation_time INTEGER,
+    first_response_time INTEGER,
+    update_time INTEGER,
+    solution_time INTEGER,
     system_address_id SMALLINT NOT NULL,
     calendar_name VARCHAR (100),
     default_sign_key VARCHAR (100),
@@ -303,6 +320,9 @@ CREATE TABLE ticket (
     queue_id INTEGER NOT NULL,
     ticket_lock_id SMALLINT NOT NULL,
     ticket_answered SMALLINT NOT NULL,
+    type_id SMALLINT,
+    service_id INTEGER,
+    sla_id INTEGER,
     user_id INTEGER NOT NULL,
     responsible_user_id INTEGER NOT NULL,
     group_id INTEGER NOT NULL,
@@ -317,6 +337,8 @@ CREATE TABLE ticket (
     timeout INTEGER,
     until_time INTEGER,
     escalation_start_time INTEGER NOT NULL,
+    escalation_response_time INTEGER NOT NULL,
+    escalation_solution_time INTEGER NOT NULL,
     freekey1 VARCHAR (80),
     freetext1 VARCHAR (150),
     freekey2 VARCHAR (80),
@@ -351,6 +373,10 @@ CREATE TABLE ticket (
     freetext16 VARCHAR (150),
     freetime1 DATETIME,
     freetime2 DATETIME,
+    freetime3 DATETIME,
+    freetime4 DATETIME,
+    freetime5 DATETIME,
+    freetime6 DATETIME,
     valid_id SMALLINT NOT NULL,
     create_time_unix BIGINT NOT NULL,
     create_time DATETIME NOT NULL,
@@ -361,6 +387,7 @@ CREATE TABLE ticket (
     UNIQUE (tn)
 );
 CREATE INDEX index_ticket_user ON ticket (user_id);
+CREATE INDEX index_ticket_type ON ticket (type_id);
 CREATE INDEX index_ticket_queue_view ON ticket (ticket_state_id, ticket_lock_id, group_id);
 CREATE INDEX index_ticket_answered ON ticket (ticket_answered);
 -- ----------------------------------------------------------
@@ -382,6 +409,7 @@ CREATE TABLE ticket_history (
     history_type_id SMALLINT NOT NULL,
     ticket_id BIGINT NOT NULL,
     article_id BIGINT,
+    type_id SMALLINT NOT NULL,
     queue_id INTEGER NOT NULL,
     owner_id INTEGER NOT NULL,
     priority_id SMALLINT NOT NULL,
@@ -546,7 +574,7 @@ CREATE TABLE queue_standard_response (
 --  create table standard_attachment
 -- ----------------------------------------------------------
 CREATE TABLE standard_attachment (
-    id SMALLINT NOT NULL IDENTITY(1,1) ,
+    id INTEGER NOT NULL IDENTITY(1,1) ,
     name VARCHAR (150) NOT NULL,
     content_type VARCHAR (150) NOT NULL,
     content TEXT NOT NULL,
@@ -592,7 +620,7 @@ CREATE TABLE auto_response_type (
 --  create table auto_response
 -- ----------------------------------------------------------
 CREATE TABLE auto_response (
-    id SMALLINT NOT NULL IDENTITY(1,1) ,
+    id INTEGER NOT NULL IDENTITY(1,1) ,
     name VARCHAR (100) NOT NULL,
     text0 VARCHAR (6000),
     text1 VARCHAR (6000),
@@ -648,7 +676,53 @@ CREATE TABLE ticket_watcher (
     change_time DATETIME NOT NULL,
     change_by INTEGER NOT NULL
 );
-CREATE INDEX ticket_id ON ticket_watcher (ticket_id);
+CREATE INDEX ticket_watcher_ticket_id ON ticket_watcher (ticket_id);
+-- ----------------------------------------------------------
+--  create table service
+-- ----------------------------------------------------------
+CREATE TABLE service (
+    id INTEGER NOT NULL IDENTITY(1,1) ,
+    name VARCHAR (200) NOT NULL,
+    valid_id SMALLINT NOT NULL,
+    comments VARCHAR (200),
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (name)
+);
+-- ----------------------------------------------------------
+--  create table service_customer_user
+-- ----------------------------------------------------------
+CREATE TABLE service_customer_user (
+    customer_user_login VARCHAR (100) NOT NULL,
+    service_id INTEGER NOT NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL
+);
+CREATE INDEX service_customer_user_customer_user_login ON service_customer_user (customer_user_login);
+CREATE INDEX service_customer_user_service_id ON service_customer_user (service_id);
+-- ----------------------------------------------------------
+--  create table sla
+-- ----------------------------------------------------------
+CREATE TABLE sla (
+    id INTEGER NOT NULL IDENTITY(1,1) ,
+    service_id INTEGER NOT NULL,
+    name VARCHAR (200) NOT NULL,
+    calendar_name VARCHAR (100),
+    first_response_time INTEGER NOT NULL,
+    update_time INTEGER NOT NULL,
+    solution_time INTEGER NOT NULL,
+    valid_id SMALLINT NOT NULL,
+    comments VARCHAR (200),
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (name)
+);
 -- ----------------------------------------------------------
 --  create table sessions
 -- ----------------------------------------------------------
@@ -708,6 +782,26 @@ CREATE TABLE customer_preferences (
 );
 CREATE INDEX index_customer_preferences_user_id ON customer_preferences (user_id);
 -- ----------------------------------------------------------
+--  create table customer_company
+-- ----------------------------------------------------------
+CREATE TABLE customer_company (
+    customer_id VARCHAR (100) NOT NULL,
+    name VARCHAR (100) NOT NULL,
+    street VARCHAR (200),
+    zip VARCHAR (200),
+    city VARCHAR (200),
+    country VARCHAR (200),
+    url VARCHAR (200),
+    comments VARCHAR (250),
+    valid_id SMALLINT NOT NULL,
+    create_time DATETIME NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time DATETIME NOT NULL,
+    change_by INTEGER NOT NULL,
+    UNIQUE (name),
+    UNIQUE (customer_id)
+);
+-- ----------------------------------------------------------
 --  create table ticket_loop_protection
 -- ----------------------------------------------------------
 CREATE TABLE ticket_loop_protection (
@@ -749,7 +843,7 @@ CREATE TABLE postmaster_filter (
 CREATE TABLE generic_agent_jobs (
     job_name VARCHAR (200) NOT NULL,
     job_key VARCHAR (200) NOT NULL,
-    job_value VARCHAR (200) NOT NULL
+    job_value VARCHAR (200)
 );
 -- ----------------------------------------------------------
 --  create table search_profile
@@ -806,9 +900,8 @@ CREATE TABLE xml_storage (
     xml_content_key VARCHAR (250) NOT NULL,
     xml_content_value TEXT
 );
-CREATE INDEX xml_content_key ON xml_storage (xml_content_key);
-CREATE INDEX xml_type ON xml_storage (xml_type);
-CREATE INDEX xml_key ON xml_storage (xml_key);
+CREATE INDEX xml_storage_xml_content_key ON xml_storage (xml_content_key);
+CREATE INDEX xml_storage_key_type ON xml_storage (xml_key, xml_type);
 -- ----------------------------------------------------------
 --  create table package_repository
 -- ----------------------------------------------------------
